@@ -19,8 +19,8 @@
 /// 
 /// =========================================================================
 //! @examplefile diffusion_isotropic.h Tensor diffusion -- isotropic case
-struct a {
+struct A {
   tensor operator() (const point& x) const { return tensor::eye(d); }
-  a(size_t d1) : d(d1) {}
+  A(size_t d1) : d(d1) {}
   size_t d;
 };
