@@ -28,8 +28,8 @@ int main(int argc, char**argv) {
   space Xh (omega, argv[2]);
   Xh.block ("boundary");
   trial u (Xh); test v (Xh);
-  form  a  = integrate (dot(grad(u),grad(v)));
-  field lh = integrate (v);
+  form  a  = lazy_integrate (dot(grad(u),grad(v)));
+  field lh = lazy_integrate (v);
   field uh (Xh);
   uh ["boundary"] = 0;
   problem p (a);
