@@ -30,7 +30,7 @@ int main (int argc, char**argv) {
   opts.split_to_triangle
     = (argc > 2 && argv[2] == std::string("-tq")) ? false : true;
   space Xh (lambda, "P1");
-  field phi_h = interpolate(Xh, phi);
+  field phi_h = lazy_interpolate(Xh, phi);
   geo gamma = level_set (phi_h, opts);
   dout << gamma;
 }
