@@ -30,6 +30,6 @@ int main(int argc, char**argv) {
   din >> catchmark("Bi")    >> Bi 
       >> catchmark("sigma") >> sigma_h;
   space Th = sigma_h.get_space();
-  space Th1 (Th.get_geo(), "P" + itos(4*(Th.degree()+1)) + "d");
-  dout << interpolate (Th1, norm(sigma_h)-Bi);
+  space Th1 (Th.get_geo(), "P" + to_string(4*(Th.degree()+1)) + "d");
+  dout << lazy_interpolate (Th1, norm(sigma_h)-Bi);
 }
