@@ -26,7 +26,7 @@ struct oldroyd_cavity: cavity {
     geo omega = Xh.get_geo();
     space Wh (omega["top"], Xh.get_approx());
     field uh (Xh, 0.);
-    uh[0]["top"] = interpolate (Wh, u0_top);
+    uh[0]["top"] = lazy_interpolate (Wh, u0_top);
     return uh;
   }
   struct tau_upstream {
