@@ -33,5 +33,5 @@ int main (int argc, char**argv) {
   din >> catchmark("u") >> uh;
   space Wh (gamma_h.level_set(), "P1");
   gamma_h.level_set().save();
-  dout << interpolate (Wh, uh);
+  dout << lazy_interpolate (Wh, uh);
 }
