@@ -27,9 +27,9 @@ int main(int argc, char** argv) {
   field uh;
   din >> uh;
   const space& Xh = uh.get_space();
-  string grad_approx = "P" + itos(Xh.degree()-1) + "d";
+  string grad_approx = "P" + to_string(Xh.degree()-1) + "d";
   string valued = (uh.get_geo().dimension() == 3) ? "vector" : "scalar";
   space Lh  (uh.get_geo(), grad_approx, valued);
-  field curl_uh = interpolate (Lh, curl(uh));
+  field curl_uh = lazy_interpolate (Lh, curl(uh));
   dout << catchmark("w") << curl_uh;
 }
