@@ -32,6 +32,7 @@ int main(int argc, char**argv) {
   branch event ("t","phi");
   for (size_t n = 0; n <= n_max; n++) {
     Float t = n*delta_t;
-    dout << event (t, interpolate(Xh, phi_exact(t)));
+    field pi_h_phi = lazy_interpolate (Xh, phi_exact(t));
+    dout << event (t, pi_h_phi);
   }
 }
