@@ -241,7 +241,9 @@ public:
   size_type nnod (reference_element hat_K) const {
     return _first_inod_by_dimension [hat_K.variant()][hat_K.dimension()+1];
   }
-  // accessors to subgeo ndof & nnod by dimension (not available for basis_sides)
+  // accessors to subgeo ndof & nnod by dimension (not available for basis_trace)
+  // numbering: dofs & nodes are organized by variant and dimension=0..3 of subgeos, for each hat_K
+  // in the discontinous case, this distinction remains in xxx_internal
   size_type ndof_on_subgeo (size_type map_dim, size_type subgeo_variant) const {
     return _ndof_on_subgeo [map_dim][subgeo_variant];
   }
@@ -254,6 +256,28 @@ public:
   size_type first_inod_by_dimension (reference_element hat_K, size_type dim) const {
     return _first_inod_by_dimension [hat_K.variant()][dim];
   }
+  // internal accessors to subgeo ndof & nnod by dimension (not available for basis_trace)
+  // differs only for discontinuous elements: internals conserve the subgeo structure
+  size_type ndof_internal (reference_element hat_K) const {
+    return _first_idof_by_dimension_internal [hat_K.variant()][hat_K.dimension()+1];
+  }
+  size_type nnod_internal (reference_element hat_K) const {
+    return _first_inod_by_dimension_internal [hat_K.variant()][hat_K.dimension()+1];
+  }
+  // accessors to subgeo ndof & nnod by dimension (not available for basis_trace)
+  size_type ndof_on_subgeo_internal (size_type map_dim, size_type subgeo_variant) const {
+    return _ndof_on_subgeo_internal [map_dim][subgeo_variant];
+  }
+  size_type nnod_on_subgeo_internal (size_type map_dim, size_type subgeo_variant) const {
+    return _nnod_on_subgeo_internal [map_dim][subgeo_variant];
+  }
+  size_type first_idof_by_dimension_internal (reference_element hat_K, size_type dim) const {
+    return _first_idof_by_dimension_internal [hat_K.variant()][dim];
+  }
+  size_type first_inod_by_dimension_internal (reference_element hat_K, size_type dim) const {
+    return _first_inod_by_dimension_internal [hat_K.variant()][dim];
+  }
+
   // used by DG, HDG:
   virtual size_type local_ndof_on_side (
         reference_element            hat_K,
@@ -373,8 +397,14 @@ _RHEOLEF_compute_dofs("tensor",tensor_basic<T>)
               ,5>
             ,reference_element::max_variant>&       _first_ixxx_by_dimension);
   // 2) inplace change nxxx_on_subgeo for discontinuous elements
-  static void _helper_discontinuous_ndof_on_subgeo_inplace_change (
+  static void _helper_make_discontinuous_ndof_on_subgeo (
       bool is_continuous,
+      const 
+      std::array<
+        std::array<
+          size_type
+         ,reference_element::max_variant>
+            ,4>&                                    nxxx_on_subgeo_internal,
       std::array<
         std::array<
           size_type
@@ -395,13 +425,17 @@ protected:
              std::array<
                size_type
               ,reference_element::max_variant>
-             ,4>                                    _ndof_on_subgeo,
+             ,4>                                    _ndof_on_subgeo_internal,
+                                                    _ndof_on_subgeo,
+                                                    _nnod_on_subgeo_internal,
                                                     _nnod_on_subgeo;
   mutable std::array<
             std::array<
               size_type
              ,5>
-           ,reference_element::max_variant>         _first_idof_by_dimension,
+           ,reference_element::max_variant>         _first_idof_by_dimension_internal,
+						    _first_idof_by_dimension,
+						    _first_inod_by_dimension_internal,
 						    _first_inod_by_dimension;
 };
 // -----------------------------------------------------------
@@ -577,6 +611,11 @@ public:
   size_type first_inod_by_dimension (reference_element hat_K, size_type dim) const;
   size_type first_idof_by_dimension (reference_element hat_K, size_type dim) const;
 
+  size_type ndof_on_subgeo_internal (size_type map_dim, size_type subgeo_variant) const;
+  size_type nnod_on_subgeo_internal (size_type map_dim, size_type subgeo_variant) const;
+  size_type first_inod_by_dimension_internal (reference_element hat_K, size_type dim) const;
+  size_type first_idof_by_dimension_internal (reference_element hat_K, size_type dim) const;
+
   // evaluate the basis:
   template<class Value>
   void evaluate (
@@ -800,33 +839,61 @@ basis_basic<T>::valued() const
 template<class T>
 inline
 typename basis_basic<T>::size_type
-basis_basic<T>::ndof_on_subgeo (size_type map_dim, size_type subgeo_variant) const
+      basis_basic<T>::ndof_on_subgeo (size_type map_dim, size_type subgeo_variant) const
 {
   return base::data().ndof_on_subgeo (map_dim, subgeo_variant);
 }
 template<class T>
 inline
 typename basis_basic<T>::size_type
-basis_basic<T>::nnod_on_subgeo (size_type map_dim, size_type subgeo_variant) const
+      basis_basic<T>::nnod_on_subgeo (size_type map_dim, size_type subgeo_variant) const
 {
   return base::data().nnod_on_subgeo (map_dim, subgeo_variant);
 }
 template<class T>
 inline
 typename basis_basic<T>::size_type
-basis_basic<T>::first_idof_by_dimension (reference_element hat_K, size_type dim) const
+      basis_basic<T>::first_idof_by_dimension (reference_element hat_K, size_type dim) const
 {
   return base::data().first_idof_by_dimension (hat_K, dim);
 }
 template<class T>
 inline
 typename basis_basic<T>::size_type
-basis_basic<T>::first_inod_by_dimension (reference_element hat_K, size_type dim) const
+      basis_basic<T>::first_inod_by_dimension (reference_element hat_K, size_type dim) const
 {
   return base::data().first_inod_by_dimension (hat_K, dim);
 }
 template<class T>
 inline
+typename basis_basic<T>::size_type
+      basis_basic<T>::ndof_on_subgeo_internal (size_type map_dim, size_type subgeo_variant) const
+{
+  return base::data().ndof_on_subgeo_internal (map_dim, subgeo_variant);
+}
+template<class T>
+inline
+typename basis_basic<T>::size_type
+      basis_basic<T>::nnod_on_subgeo_internal (size_type map_dim, size_type subgeo_variant) const
+{
+  return base::data().nnod_on_subgeo_internal (map_dim, subgeo_variant);
+}
+template<class T>
+inline
+typename basis_basic<T>::size_type
+      basis_basic<T>::first_idof_by_dimension_internal (reference_element hat_K, size_type dim) const
+{
+  return base::data().first_idof_by_dimension_internal (hat_K, dim);
+}
+template<class T>
+inline
+typename basis_basic<T>::size_type
+      basis_basic<T>::first_inod_by_dimension_internal (reference_element hat_K, size_type dim) const
+{
+  return base::data().first_inod_by_dimension_internal (hat_K, dim);
+}
+template<class T>
+inline
 const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>&
 basis_basic<T>::vdm (reference_element hat_K) const
 {
