@@ -42,7 +42,6 @@ basis_fem_RTk<T>::~basis_fem_RTk()
 template<class T>
 basis_fem_RTk<T>::basis_fem_RTk (size_type k, const basis_option& sopt) 
   : basis_rep<T> (sopt),
-    _nnod_on_subgeo_remainder(),
     _b_pre_kp1(),
     _hat_node(),
     _vdm(),
@@ -51,15 +50,12 @@ basis_fem_RTk<T>::basis_fem_RTk (size_type k, const basis_option& sopt)
     _bar_a(),
     _bkm1_node_internal_d()
 {
-#ifdef TO_CLEAN
-  base::_sopt.set_raw_polynomial (basis_option::monomial);
-#endif // TO_CLEAN
   base::_name = base::standard_naming (family_name(), k, base::_sopt);
   // requieres a hierarchical pre basis => Dubiner or monomial
   // - monomial is ill conditionned, but easier to decompose
   // - dubiner: TODO project the tilde_psi basis on it
   // note: the internal dof basis is independent 
-  _b_pre_kp1 = basis_raw_basic<T> ("M"+itos(k+1));
+  _b_pre_kp1 = basis_raw_basic<T> ("M"+std::to_string(k+1));
   _initialize_cstor_sizes();
 
   // piola FEM transformation:
@@ -93,26 +89,26 @@ basis_fem_RTk<T>::_initialize_cstor_sizes() const
 {
   size_type k = degree()-1;
   for (size_type map_d = 0; map_d < 4; ++map_d) {
-    base::_ndof_on_subgeo [map_d].fill (0);
-    base::_nnod_on_subgeo [map_d].fill (0);
+    base::_ndof_on_subgeo_internal [map_d].fill (0);
   }
   // --------------------------------------------------------------------------
   // 1. compute ndof and dof pointers:
   // --------------------------------------------------------------------------
   // see BreFor-1991 p. 116 for K=t,T & p. 119 for K=q,H ; BerDur-2013 for K=P
-  base::_ndof_on_subgeo [0][reference_element::p] = 1;
-  base::_ndof_on_subgeo [1][reference_element::p] = 1;
-  base::_ndof_on_subgeo [1][reference_element::e] = k; // RT0 is P1 on 1d with K=e
-  base::_ndof_on_subgeo [2][reference_element::e] = k+1;
-  base::_ndof_on_subgeo [2][reference_element::t] = k*(k+1);
-  base::_ndof_on_subgeo [2][reference_element::q] = 2*k*(k+1); // Rav-1981, p. 23
-  base::_ndof_on_subgeo [3][reference_element::t] = (k+1)*(k+2)/2;
-  base::_ndof_on_subgeo [3][reference_element::q] = sqr(k+1);
-  base::_ndof_on_subgeo [3][reference_element::T] = 3*k*(k+1)*(k+2)/6;
-  base::_ndof_on_subgeo [3][reference_element::P] = sqr(k)*(k+1)/2; // see BerDur-2013
-  base::_ndof_on_subgeo [3][reference_element::H] = 3*k*sqr(k+1);
-  base::_helper_discontinuous_ndof_on_subgeo_inplace_change (base::is_continuous(), base::_ndof_on_subgeo);
-  base::_helper_initialize_first_ixxx_by_dimension_from_nxxx_on_subgeo (base::_ndof_on_subgeo, base::_first_idof_by_dimension);
+  base::_ndof_on_subgeo_internal [0][reference_element::p] = 1;
+  base::_ndof_on_subgeo_internal [1][reference_element::p] = 1;
+  base::_ndof_on_subgeo_internal [1][reference_element::e] = k; // RT0 is P1 on 1d with K=e
+  base::_ndof_on_subgeo_internal [2][reference_element::e] = k+1;
+  base::_ndof_on_subgeo_internal [2][reference_element::t] = k*(k+1);
+  base::_ndof_on_subgeo_internal [2][reference_element::q] = 2*k*(k+1); // Rav-1981, p. 23
+  base::_ndof_on_subgeo_internal [3][reference_element::t] = (k+1)*(k+2)/2;
+  base::_ndof_on_subgeo_internal [3][reference_element::q] = sqr(k+1);
+  base::_ndof_on_subgeo_internal [3][reference_element::T] = 3*k*(k+1)*(k+2)/6;
+  base::_ndof_on_subgeo_internal [3][reference_element::P] = sqr(k)*(k+1)/2; // see BerDur-2013
+  base::_ndof_on_subgeo_internal [3][reference_element::H] = 3*k*sqr(k+1);
+  base::_helper_make_discontinuous_ndof_on_subgeo (base::is_continuous(), base::_ndof_on_subgeo_internal, base::_ndof_on_subgeo);
+  base::_helper_initialize_first_ixxx_by_dimension_from_nxxx_on_subgeo (base::_ndof_on_subgeo_internal, base::_first_idof_by_dimension_internal);
+  base::_helper_initialize_first_ixxx_by_dimension_from_nxxx_on_subgeo (base::_ndof_on_subgeo,          base::_first_idof_by_dimension);
   // --------------------------------------------------------------------------
   // 2. nodes for dofs : interpolate v.n on sides + internal quadrature nodes
   // --------------------------------------------------------------------------
@@ -124,20 +120,23 @@ basis_fem_RTk<T>::_initialize_cstor_sizes() const
   //       = 2*k      for P_{k-1,k,k} internal modes for non-simplicial elts hat_K=qHP
   qopt.set_order  (2*(k+2)); // takes the max to have an uniform quadrature for any cases TODO: too much ? min-adjust=2*k to converge
   _quad = quadrature<T> (qopt);
-  base::_nnod_on_subgeo [0][reference_element::p] = 1;
-  base::_nnod_on_subgeo [1][reference_element::p] = 1;
-  base::_nnod_on_subgeo [1][reference_element::e] = k == 0 ? 0 : _quad.size (reference_element::e);
-  base::_nnod_on_subgeo [2][reference_element::e] = k+1;
-  base::_nnod_on_subgeo [2][reference_element::t] = k*(k+1)/2; // k == 0 ? 0 : _quad.size (reference_element::t);
-  base::_nnod_on_subgeo [2][reference_element::q] = k == 0 ? 0 : _quad.size (reference_element::q);
-  base::_nnod_on_subgeo [3][reference_element::t] = (k+1)*(k+2)/2;
-  base::_nnod_on_subgeo [3][reference_element::q] = sqr(k+1);
-  base::_nnod_on_subgeo [3][reference_element::T] = k == 0 ? 0 : _quad.size (reference_element::T);
-  base::_nnod_on_subgeo [3][reference_element::P] = k == 0 ? 0 : _quad.size (reference_element::P);
-  base::_nnod_on_subgeo [3][reference_element::H] = k == 0 ? 0 : _quad.size (reference_element::H);
-  _nnod_on_subgeo_remainder = base::_nnod_on_subgeo; // used for node table indexing
-  base::_helper_discontinuous_ndof_on_subgeo_inplace_change (base::is_continuous(), base::_nnod_on_subgeo);
-  base::_helper_initialize_first_ixxx_by_dimension_from_nxxx_on_subgeo (base::_nnod_on_subgeo, base::_first_inod_by_dimension);
+  for (size_type map_d = 0; map_d < 4; ++map_d) {
+    base::_nnod_on_subgeo_internal [map_d].fill (0);
+  }
+  base::_nnod_on_subgeo_internal [0][reference_element::p] = 1;
+  base::_nnod_on_subgeo_internal [1][reference_element::p] = 1;
+  base::_nnod_on_subgeo_internal [1][reference_element::e] = k == 0 ? 0 : _quad.size (reference_element::e);
+  base::_nnod_on_subgeo_internal [2][reference_element::e] = k+1;
+  base::_nnod_on_subgeo_internal [2][reference_element::t] = k*(k+1)/2; // k == 0 ? 0 : _quad.size (reference_element::t);
+  base::_nnod_on_subgeo_internal [2][reference_element::q] = k == 0 ? 0 : _quad.size (reference_element::q);
+  base::_nnod_on_subgeo_internal [3][reference_element::t] = (k+1)*(k+2)/2;
+  base::_nnod_on_subgeo_internal [3][reference_element::q] = sqr(k+1);
+  base::_nnod_on_subgeo_internal [3][reference_element::T] = k == 0 ? 0 : _quad.size (reference_element::T);
+  base::_nnod_on_subgeo_internal [3][reference_element::P] = k == 0 ? 0 : _quad.size (reference_element::P);
+  base::_nnod_on_subgeo_internal [3][reference_element::H] = k == 0 ? 0 : _quad.size (reference_element::H);
+  base::_helper_make_discontinuous_ndof_on_subgeo (base::is_continuous(), base::_nnod_on_subgeo_internal, base::_nnod_on_subgeo);
+  base::_helper_initialize_first_ixxx_by_dimension_from_nxxx_on_subgeo (base::_nnod_on_subgeo_internal, base::_first_inod_by_dimension_internal);
+  base::_helper_initialize_first_ixxx_by_dimension_from_nxxx_on_subgeo (base::_nnod_on_subgeo,          base::_first_inod_by_dimension);
 }
 template<class T>
 void
@@ -247,7 +246,7 @@ basis_fem_RTk<T>::_initialize_data (reference_element hat_K) const
   for (size_type loc_isid = 0, loc_nsid = hat_K.n_subgeo(d-1); loc_isid < loc_nsid; ++loc_isid) {
     reference_element hat_S = hat_K.subgeo (d-1, loc_isid);
     // dofs on sides are Lagrange dofs, associated to nodes:
-    loc_ndof_sid_tot += _nnod_on_subgeo_remainder [d][hat_S.variant()];
+    loc_ndof_sid_tot += base::_nnod_on_subgeo_internal [d][hat_S.variant()];
   }
   size_type loc_ndof = base::_first_idof_by_dimension [variant][d+1];
   size_type loc_nnod_sid_tot = loc_ndof_sid_tot; // dofs on sides are Lagrange one, associated to nodes
@@ -440,7 +439,7 @@ trace_macro("basis_dof_name="<<basis_dof_name);
       case reference_element::t: 
       case reference_element::T: { 
         // int_K b*v dx with v=[p,0],[0,p] and p in P_{k-1}
-        basis_raw_basic<T> b_dof_km1 (basis_dof_name+itos(k-1));
+        basis_raw_basic<T> b_dof_km1 (basis_dof_name+std::to_string(k-1));
         details::basis_on_pointset_evaluate (b_dof_km1, hat_K, hat_node_internal, bkm1_node_internal_d[0]);
         for (size_type alpha = 1; alpha < d; ++alpha) {
           bkm1_node_internal_d [alpha] = bkm1_node_internal_d [0];
@@ -450,8 +449,8 @@ trace_macro("basis_dof_name="<<basis_dof_name);
       case reference_element::q:
       case reference_element::H: {
         // int_K b*v dx with v=[p,0],[0,q] and p in P_{k-1,k}, q in P_{k,k-1}
-        basis_raw_basic<T> b_dof_km1 (basis_dof_name+itos(k-1)),
-                           b_dof_k   (basis_dof_name+itos(k));
+        basis_raw_basic<T> b_dof_km1 (basis_dof_name+std::to_string(k-1)),
+                           b_dof_k   (basis_dof_name+std::to_string(k));
         std::array<Eigen::Matrix<point_basic<T>,Eigen::Dynamic,1>,3> hat_node_internal_comp;
         std::array<
           Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
@@ -537,11 +536,6 @@ trace_macro("basis_dof_name="<<basis_dof_name);
   Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& inv_vdm = _inv_vdm[hat_K.variant()];
   vdm = bkp1d_dof*a.transpose(); // = trans(a*trans(bkp1d_dof));
   bool invert_ok = invert(vdm, inv_vdm);
-#ifdef TO_CLEAN
-  if (!invert_ok) {
-    warning_macro ("unisolvence failed for " << base::name() <<"(" << hat_K.name() << ") basis");
-  }
-#endif // TO_CLEAN
   check_macro (invert_ok,
         "unisolvence failed for " << base::name() <<"(" << hat_K.name() << ") basis");
   // -----------------------------------------
@@ -674,7 +668,7 @@ trace_macro ("_compute_dofs (hat_K="<<hat_K.name()<<")...");
     point_basic<Float> hat_n; 
     Float hat_S_meas = hat_K.side_measure (loc_isid);
     hat_K.side_normal (loc_isid, hat_n);
-    size_type loc_ndof_sid = _nnod_on_subgeo_remainder [d][hat_S.variant()];
+    size_type loc_ndof_sid = base::_nnod_on_subgeo_internal [d][hat_S.variant()];
     for (size_type loc_idof_sid = 0; loc_idof_sid < loc_ndof_sid; ++loc_idof_sid) {
       dof[loc_idof] = hat_S_meas*dot(f_xnod[loc_inod],hat_n);
       loc_idof++;
