@@ -399,22 +399,20 @@ basis_on_pointset_rep<T>::_sid_initialize_continued (
   size_type ori_idx = (sid.orient == 1) ? 0 : 1;
   switch (_b.valued_tag()) {
     case space_constant::scalar: {
-      if (!_b.option().is_restricted_to_sides()) {
+      if (! _b.option().is_trace_n()) {
         details::basis_on_pointset_evaluate      (_b, tilde_L, hat_node, _sid_scalar_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
         details::basis_on_pointset_grad_evaluate (_b, tilde_L, hat_node, _sid_vector_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
-      } else { // e.g. "Pkd[sides]"
+      } else { // e.g. "trace_n(RTkd)"
         details::basis_on_pointset_evaluate_on_side (_b, tilde_L, sid, hat_node, _sid_scalar_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
-#ifdef TODO
-#endif // TODO
       }
       break;
     }
     case space_constant::vector: {
-      if (!_b.option().is_restricted_to_sides()) {
+      if (! _b.option().is_trace_n()) {
         details::basis_on_pointset_evaluate      (_b, tilde_L, hat_node, _sid_vector_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
         details::basis_on_pointset_grad_evaluate (_b, tilde_L, hat_node, _sid_tensor_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
       } else {
-	fatal_macro ("basis_sides: not yet");
+	fatal_macro ("basis_trace_n(vector): not yet");
 #ifdef TODO
         details::basis_on_pointset_evaluate_on_sides (_b, tilde_L, hat_node, _sid_vector_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
 #endif // TODO
@@ -422,11 +420,11 @@ basis_on_pointset_rep<T>::_sid_initialize_continued (
       break;
     }
     case space_constant::tensor: {
-      if (!_b.option().is_restricted_to_sides()) {
+      if (! _b.option().is_trace_n()) {
         details::basis_on_pointset_evaluate      (_b, tilde_L, hat_node,  _sid_tensor_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
         details::basis_on_pointset_grad_evaluate (_b, tilde_L, hat_node, _sid_tensor3_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
       } else {
-	fatal_macro ("basis_sides: not yet");
+	fatal_macro ("basis_trace_n(tensor): not yet");
 #ifdef TODO
         details::basis_on_pointset_evaluate_on_sides (_b, tilde_L, hat_node, _sid_tensor_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
 #endif // TODO
@@ -434,11 +432,11 @@ basis_on_pointset_rep<T>::_sid_initialize_continued (
       break;
     }
     case space_constant::tensor3: {
-      if (!_b.option().is_restricted_to_sides()) {
+      if (! _b.option().is_trace_n()) {
         details::basis_on_pointset_evaluate      (_b, tilde_L, hat_node, _sid_tensor3_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
         details::basis_on_pointset_grad_evaluate (_b, tilde_L, hat_node, _sid_tensor4_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
       } else {
-	fatal_macro ("basis_sides: not yet");
+	fatal_macro ("basis_trace_n(tensor3): not yet");
 #ifdef TODO
         details::basis_on_pointset_evaluate_on_sides (_b, tilde_L, hat_node, _sid_tensor_val[L_variant][sid.loc_isid][ori_idx][sid.shift]);
 #endif // TODO
@@ -465,13 +463,13 @@ basis_on_pointset_rep<T>::_sid_initialize (reference_element tilde_L, const side
     hat_node = _nb.hat_node (sid.hat); // ... on its Lagrange nodes.
   }
   tilde_node.resize (hat_node.size());
-  if (!_b.option().is_restricted_to_sides()) {
+  if (! _b.option().is_trace_n()) {
     // transform hat_xq on side hat_S to tilde_xq on partial tilde_L
     for (size_type q = 0, nq = hat_node.size(); q < nq; ++q) {
       tilde_node[q] = reference_element_face_transformation (tilde_L, sid, hat_node[q]);
     }
   } else {
-    // else e.g. "Pkd[sides]": hat_nodes remains on side hat_S
+    // else e.g. "trace_n(RTkd)": hat_nodes remains on side hat_S
     tilde_node = hat_node;
   } 
   _sid_initialize_continued (tilde_L, sid, tilde_node);
