@@ -372,17 +372,25 @@ basis_symbolic_nodal::put_cxx_body(ostream& out) const
       out << "  basis_fem_Pk_lagrange<T>::initialize_local_first (" << endl
           << "    " << degree() << "," << endl
           << "    base::is_continuous()," << endl
+          << "    base::_ndof_on_subgeo_internal," << endl
           << "    base::_ndof_on_subgeo," << endl
+          << "    base::_nnod_on_subgeo_internal," << endl
           << "    base::_nnod_on_subgeo," << endl
+          << "    base::_first_idof_by_dimension_internal," << endl
           << "    base::_first_idof_by_dimension," << endl
+          << "    base::_first_inod_by_dimension_internal," << endl
           << "    base::_first_inod_by_dimension);" << endl;
     } else if (name() == "bubble") {
       out << "  basis_fem_Pk_lagrange<T>::initialize_local_first (" << endl
           << "    0," << endl
           << "    false," << endl
+          << "    base::_ndof_on_subgeo_internal," << endl
           << "    base::_ndof_on_subgeo," << endl
+          << "    base::_nnod_on_subgeo_internal," << endl
           << "    base::_nnod_on_subgeo," << endl
+          << "    base::_first_idof_by_dimension_internal," << endl
           << "    base::_first_idof_by_dimension," << endl
+          << "    base::_first_inod_by_dimension_internal," << endl
           << "    base::_first_inod_by_dimension);" << endl;
     } else {
       out << "  fatal_macro(\"::_initialize_cstor_sizes: not yet\"); /* TODO */" << endl;
