@@ -236,7 +236,7 @@ void
 csr_rep<T,distributed>::dump (const string& name) const
 {
     odiststream ops;
-    std::string filename = name + itos(comm().rank());
+    std::string filename = name + std::to_string(comm().rank());
     ops.open (filename, "mtx", comm());
     check_macro(ops.good(), "\"" << filename << "[.mtx]\" cannot be created.");
     ops << "%%MatrixMarket matrix coordinate real general" << std::endl
@@ -267,7 +267,7 @@ csr_rep<T,distributed>::mult(
         _buffer.begin().operator->(),
 	_from,
         _to, 
-	set_op<T,T>(), 
+	details::generic_set_op(), 
         tag, 
 	row_ownership().comm());
 
@@ -276,7 +276,7 @@ csr_rep<T,distributed>::mult(
         base::begin(), 
         base::end(), 
         x.begin(), 
-        set_op<T,T>(), 
+	details::generic_set_op(), 
         y.begin());
 
     // receive tmp from others
@@ -285,12 +285,12 @@ csr_rep<T,distributed>::mult(
         _buffer.begin(), 
 	_from,
         _to,
-	set_op<T,T>(), 
+	details::generic_set_op(), 
 	tag, 
 	row_ownership().comm());
 
     // y += ext*tmp
-    csr_amux (_ext.begin(), _ext.end(), _buffer.begin(), set_add_op<T,T>(), y.begin());
+    csr_amux (_ext.begin(), _ext.end(), _buffer.begin(), details::generic_set_plus_op(), y.begin());
 }
 template<class T>
 void
@@ -312,7 +312,7 @@ csr_rep<T,distributed>::trans_mult(
         base::begin(), 
         base::end(), 
         x.begin(), 
-        set_add_op<T,T>(),
+        details::generic_set_plus_op(),
         y.begin());
 
     // buffer = ext*x
@@ -321,7 +321,7 @@ csr_rep<T,distributed>::trans_mult(
         _ext.begin(),
         _ext.end(),
         x.begin(), 
-        set_add_op<T,T>(),
+        details::generic_set_plus_op(),
         _buffer.begin());
 
     // send buffer to others parts of y (+=)
@@ -331,7 +331,7 @@ csr_rep<T,distributed>::trans_mult(
 	y.begin().operator->(),
         _to,  // reverse mode
 	_from,
-	set_add_op<T,T>(), // += 
+        details::generic_set_plus_op(),
         tag, 
 	col_ownership().comm());
 
@@ -341,7 +341,7 @@ csr_rep<T,distributed>::trans_mult(
 	y.begin(),
         _to, // reverse mode
 	_from,
-	set_add_op<T,T>(), // +=
+        details::generic_set_plus_op(),
 	tag, 
 	col_ownership().comm());
 }
@@ -683,18 +683,20 @@ csr_rep<T,distributed>::assign_mult (
   c_asr_zip.dis_entry_assembly();
   // 5.2) copy c_zip intro c_asr_zip
   build_from_asr (c_asr_zip);
+  // 5.*) propagate flags ; cannot stat yet for symmetry and positive_definite
+  set_pattern_dimension (std::max(a.pattern_dimension(), b.pattern_dimension()));
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-#ifdef _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#ifndef _RHEOLEF_USE_HEAP_ALLOCATOR
 #define _RHEOLEF_instanciate_class(T) \
 template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,std::allocator<T> >&); 
-#else  // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#else  // _RHEOLEF_USE_HEAP_ALLOCATOR
 #define _RHEOLEF_instanciate_class(T) \
 template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,std::allocator<T> >&); \
 template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,heap_allocator<T> >&);
-#endif // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#endif // _RHEOLEF_USE_HEAP_ALLOCATOR
 
 #define _RHEOLEF_istanciate(T) 								\
 template class csr_rep<T,distributed>;							\
