@@ -183,7 +183,7 @@ csr_rep<T,sequential>::mult(
         vector_of_iterator<pair_type>::begin(), 
         vector_of_iterator<pair_type>::end(), 
         x.begin(), 
-        set_op<T,T>(),
+        details::generic_set_op(),
         y.begin());
 }
 template<class T>
@@ -200,7 +200,7 @@ csr_rep<T,sequential>::trans_mult(
         vector_of_iterator<pair_type>::begin(), 
         vector_of_iterator<pair_type>::end(), 
         x.begin(), 
-        set_add_op<T,T>(),
+        details::generic_set_plus_op(),
         y.begin());
 }
 template<class T>
@@ -463,6 +463,8 @@ csr_csr_mult (
 	*cp = *iter_y;
     }
   }
+  // propagate flags ; cannot stat yet for symmetry and positive_definite
+  c.set_pattern_dimension (std::max(a.pattern_dimension(), b.pattern_dimension()));
 }
 template<class T>
 void
@@ -477,14 +479,14 @@ csr_rep<T,sequential>::assign_mult (
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-#ifdef _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#ifndef _RHEOLEF_USE_HEAP_ALLOCATOR
 #define _RHEOLEF_instanciate_class(T) \
 template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,std::allocator<T> >&);
-#else // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#else // _RHEOLEF_USE_HEAP_ALLOCATOR
 #define _RHEOLEF_instanciate_class(T) \
 template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,std::allocator<T> >&);	\
 template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,heap_allocator<T> >&);
-#endif // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#endif // _RHEOLEF_USE_HEAP_ALLOCATOR
 
 #define _RHEOLEF_instanciate(T) \
 template class csr_rep<T,sequential>;					\
