@@ -175,12 +175,11 @@ Misc notes:
 
 */
 
-#include "rheolef/distributed.h"
+#include "rheolef/communicator.h"
 #include "rheolef/distributor.h"
 #include "rheolef/diststream.h"
 #include "rheolef/heap_allocator.h"
 #include "rheolef/msg_util.h"
-#include "rheolef/container_traits.h"
 #ifdef _RHEOLEF_HAVE_MPI
 #include "rheolef/mpi_pair_datatype.h"
 #endif // _RHEOLEF_HAVE_MPI
@@ -249,9 +248,9 @@ public:
     reference dis_entry     (size_type dis_i) { return operator[](dis_i); }
     void get_dis_indexes (std::set<size_type>& ext_idx_set) const;
     void reset_dis_indexes() const {}
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_begin (SetOp = SetOp()) {}
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_end (SetOp = SetOp()) {}
     void repartition (					      // old_numbering for *this
         const disarray_rep<size_type,sequential,A>& partition,	      // old_ownership
@@ -279,42 +278,26 @@ protected:
 // the distributed representation
 // -------------------------------------------------------------
 #ifdef _RHEOLEF_HAVE_MPI
+template <class T, class A> struct disarray_dis_reference; /// forward decl
+
 template <class T, class A>
 class disarray_rep<T,distributed,A> : public disarray_rep<T,sequential,A> {
 public:
 
 // typedefs:
 
-    typedef disarray_rep<T,sequential,A>     	base;
-    typedef typename base::value_type     	value_type;
-    typedef typename base::size_type      	size_type;
-    typedef typename base::difference_type      difference_type;
-    typedef typename base::reference      	reference;
-    typedef typename base::const_reference      const_reference;
-    typedef typename base::iterator       	iterator;
-    typedef typename base::const_iterator 	const_iterator;
-    typedef distributor::communicator_type      communicator_type;
-    typedef distributed                         memory_type;
-    typedef std::map <size_type, T> 	        scatter_map_type; // TODO: map<T,A> for heap_alloc
-
-    struct dis_reference {
-      dis_reference (disarray_rep<T,distributed,A>& x, size_type dis_i)
-       : _x(x), _dis_i(dis_i) {}
-
-      dis_reference& operator= (const T& value) {
-        _x.set_dis_entry (_dis_i, value);
-        return *this;
-      }
-      template<class U>
-      dis_reference& operator+= (const U& value) {
-        _x.set_add_dis_entry (_dis_i, value);
-        return *this;
-      }
-    // data:
-    protected:
-      disarray_rep<T,distributed,A>& _x;
-      size_type                      _dis_i;
-    };
+    using base = disarray_rep<T,sequential,A>;
+    using size_type       = typename base::size_type;
+    using value_type      = typename base::value_type;
+    using memory_type     = distributed;
+    using iterator        = typename base::iterator;
+    using const_iterator  = typename base::const_iterator;
+    using reference       = typename base::reference;
+    using const_reference = typename base::const_reference;
+    using difference_type = typename base::difference_type;
+    using communicator_type = distributor::communicator_type;
+    using scatter_map_type  = std::map <size_type, T>; // TODO: map<T,A> for heap_alloc
+    using dis_reference   = disarray_dis_reference<T,A>;
 
 // allocators:
 
@@ -337,11 +320,11 @@ public:
 
     dis_reference dis_entry (size_type dis_i) { return dis_reference (*this, dis_i); }
 
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_begin (SetOp my_set_op = SetOp());
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_end   (SetOp my_set_op = SetOp());
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly       (SetOp my_set_op = SetOp())
    		{ dis_entry_assembly_begin (my_set_op); dis_entry_assembly_end (my_set_op); }
 
@@ -391,10 +374,15 @@ public:
     template <class PutFunction, class A2> odiststream& permuted_put_values (odiststream& ops, const disarray_rep<size_type,distributed,A2>& perm,
 		PutFunction put_element) const;
     void dump (std::string name) const;
-protected:
-    void set_dis_entry (size_type dis_i, const T& val);
-    template<class U>
-    void set_add_dis_entry (size_type dis_i, const U& val);
+//protected:
+    template<class U, class SetOp>
+    void set_dis_entry       (size_type dis_i, const U& val, const SetOp& set_op);
+#ifdef TO_CLEAN
+    template<class U, class SetOp>
+    void set_plus_dis_entry  (size_type dis_i, const U& val, const SetOp& set_op);
+    template<class U, class SetOp>
+    void set_minus_dis_entry (size_type dis_i, const U& val, const SetOp& set_op);
+#endif // TO_CLEAN
 // typedefs:
     /** 1) stash: store data before assembly() communications:
       *   select multimap<U> when T=set<U> and map<T> otherwise
@@ -419,7 +407,7 @@ protected:
         typedef typename remove_const_in_pair<typename U::value_type>::type mapped_type;
         typedef std::multimap <size_type, mapped_type>   map_type; // TODO: map<T,A> for heap_alloc
     };
-    typedef typename is_container_of_mpi_datatype<T>::type     is_container;
+    typedef typename details::is_container_of_mpi_datatype<T>::type     is_container;
     typedef typename stash_traits<T,is_container>::mapped_type stash_value;
     typedef typename stash_traits<T,is_container>::map_type    stash_map_type;
 
@@ -444,6 +432,56 @@ protected:
     size_type        _receive_max_size;
     mutable scatter_map_type _ext_x;		// for ext values (scatter)
 };
+// custom reference that interacts with stach
+// for ext values on others partitions
+template <class T, class A>
+struct disarray_dis_reference
+{
+  using size_type = typename disarray_rep<T,distributed,A>::size_type;
+
+  disarray_dis_reference (disarray_rep<T,distributed,A>& x, size_type dis_i)
+    : _x(x), _dis_i(dis_i) {}
+
+#ifndef TO_CLEAN // not usefull: default behavior
+  disarray_dis_reference (const disarray_dis_reference<T,A>& r)
+    : _x(r._x), _dis_i(r._dis_i) {}
+
+  disarray_dis_reference<T,A>&
+  operator= (const disarray_dis_reference<T,A>& r) {
+    _x = r._x; _dis_i = r._dis_i; return *this; }
+#endif // TO_CLEAN
+
+  disarray_dis_reference<T,A>&
+  operator= (const T& value) {
+    trace_macro("_x.set_dis_entry (dis_i="<<_dis_i<<", value="<<value<<", op=)");
+    _x.set_dis_entry (_dis_i, value, details::generic_set_op());
+    return *this;
+  }
+  template<class U>
+  disarray_dis_reference<T,A>&
+  operator+= (const U& value) {
+    trace_macro("_x.set_dis_entry (dis_i="<<_dis_i<<", value="<<value<<", op+=)");
+    _x.set_dis_entry (_dis_i, value, details::generic_set_plus_op());
+    return *this;
+  }
+  template<class U>
+  disarray_dis_reference<T,A>&
+  operator-= (const U& value) {
+    trace_macro("_x.set_dis_entry (dis_i="<<_dis_i<<", value="<<value<<", op-=)");
+    _x.set_dis_entry (_dis_i, value, details::generic_set_minus_op());
+    return *this;
+  }
+// data:
+protected:
+  disarray_rep<T,distributed,A>& _x;
+  size_type                      _dis_i;
+};
+
+namespace details {
+template <class T, class A>
+struct is_class_reference<disarray_dis_reference<T,A>> : std::true_type {};
+} // namespace details
+
 #endif // _RHEOLEF_HAVE_MPI
 // -------------------------------------------------------------
 // the basic class with a smart pointer to representation
@@ -507,11 +545,11 @@ public:
 // global modifiers (for compatibility with distributed interface):
 
     dis_reference dis_entry (size_type dis_i) { return base::data().dis_entry(dis_i); }
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly (SetOp my_set_op = SetOp()) {}
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_begin (SetOp my_set_op = SetOp()) {}
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_end (SetOp my_set_op = SetOp()) {}
 
     void dis_entry_assembly_begin() {}
@@ -599,7 +637,7 @@ public:
 
 // typedefs:
 
-    typedef disarray_rep<T,distributed,A>    rep;
+    typedef disarray_rep<T,distributed,A> rep;
     typedef smart_pointer<rep> 		  base;
 
     typedef distributed 		  memory_type;
@@ -661,15 +699,15 @@ public:
 
     dis_reference dis_entry (size_type dis_i) { return base::data().dis_entry(dis_i); }
 
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_begin (SetOp my_set_op = SetOp()) { base::data().dis_entry_assembly_begin (my_set_op); }
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly_end   (SetOp my_set_op = SetOp()) { base::data().dis_entry_assembly_end   (my_set_op); }
-    template<class SetOp = typename default_set_op<T>::type>
+    template<class SetOp = typename details::default_set_op_traits<T>::type>
     void dis_entry_assembly       (SetOp my_set_op = SetOp()) { base::data().dis_entry_assembly       (my_set_op); }
 
-    void dis_entry_assembly_begin() { base::data().template dis_entry_assembly_begin<typename default_set_op<T>::type>(); }
-    void dis_entry_assembly_end()   { base::data().template dis_entry_assembly_end<typename default_set_op<T>::type>(); }
+    void dis_entry_assembly_begin() { base::data().template dis_entry_assembly_begin<typename details::default_set_op_traits<T>::type>(); }
+    void dis_entry_assembly_end()   { base::data().template dis_entry_assembly_end<typename details::default_set_op_traits<T>::type>(); }
     void dis_entry_assembly()       { dis_entry_assembly_begin(); dis_entry_assembly_end(); }
 
 // apply a partition:
@@ -761,6 +799,7 @@ operator << (odiststream& ops, const disarray<T,distributed,A>& x)
 }
 #endif // _RHEOLEF_HAVE_MPI
 } // namespace rheolef
+
 // -------------------------------------------------------------
 // not inlined : longer code
 // -------------------------------------------------------------
