@@ -20,13 +20,18 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // =========================================================================
-#include "rheolef/distributed.h"
+#include "rheolef/communicator.h"
 #include "rheolef/pretty_name.h"
-#include "rheolef/container_traits.h"
+#include "rheolef/msg_util.h"
 
 #ifdef _RHEOLEF_HAVE_MPI
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wparentheses"
+#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
 #include <boost/serialization/set.hpp>
 #include <boost/serialization/base_object.hpp>
+#pragma GCC diagnostic pop
 #endif // _RHEOLEF_HAVE_MPI
 
 #include "rheolef/index_set_header.icc"
