@@ -379,7 +379,10 @@ solver_mumps_rep<T,M>::update_values (const csr<T,M>& a)
     _row.resize (dia_nnz);
     _col.resize (dia_nnz);
     csr2mumps_struct_seq (a, _row, _col, use_symmetry);
+    _mumps_par.nz      = dia_nnz;
+#if (_RHEOLEF_MUMPS_VERSION_MAJOR >= 5)
     _mumps_par.nnz     = dia_nnz;
+#endif
     _mumps_par.irn     = _row.begin().operator->();
     _mumps_par.jcn     = _col.begin().operator->();
   }
