@@ -18,9 +18,10 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-# include "rheolef/distributed.h"
-# include "rheolef/disarray.h"
-# include "rheolef/index_set.h"
+#include "rheolef/communicator.h"
+#include "rheolef/disarray.h"
+#include "rheolef/index_set.h"
+#include "rheolef/environment.h"
 using namespace rheolef;
 int main(int argc, char**argv) {
     environment rheolef(argc, argv);
@@ -28,7 +29,9 @@ int main(int argc, char**argv) {
     size_t dis_n;
     din >> dis_n;
     disarray<index_set> x (dis_n);
+warning_macro("main(1)");
     x.get_values (din);
+warning_macro("main(2)");
     dout << x.dis_size() << std::endl
          << x            << std::endl;
 }
