@@ -256,15 +256,19 @@ Others options
 >	on the topographic data.
 
 @addindex projection
-@addindex approximation P0
 @addindex approximation P1
-
+`-proj` *approx*
 `-proj`
->	Performs a `P1` projection on the fly.
->	This option is useful when rendering `P0` data
->	while the `paraview` render requires `P1` description.
+>       Convert all selected fields to approximation *approx* by using a L2 projection.
+>       When argument is omitted, `P1` approximation is assumed.
 `-lumped-proj`
->       Force P1 approximation for L2 projection and use a lumped mass matrix for it.
+>       Force `P1` approximation for L2 projection and use a lumped mass matrix for it.
+`-round` [*float*]
+>       Round the input up to the specified precision.
+>       This option, combined with `-field`, leads to a round filter.
+>       Useful for non-regression test purpose, in order
+> 	to compare numerical results between files with a limited precision,
+>       since the full double precision is machine-dependent.
 
 `-[no]verbose`
 >       Print messages related to graphic files created and
@@ -391,7 +395,7 @@ void usage()
 	   << "[-index int|-extract int] "
            << "[-[catch]mark string] "
 	   << "[-ndigit int] "
-	   << "[-proj] "
+	   << "[-proj [string]] "
            << "[-lumped-proj] "
            << "[-if {branch,vtk}] "
 	   << "[-paraview|-gnuplot] "
@@ -418,54 +422,86 @@ void usage()
 	   << endl;
       exit (1);
 }
+
 typedef field::size_type size_type;
 
+typedef enum {
+	text_render,
+	paraview_render,
+	vtk_render,
+	plotmtv_render,
+	gnuplot_render,
+	toc_render
+} render_type;
+
+struct reuse_proj_form_type {
+  vector<form_basic<Float,sequential>> m, p;
+  vector<bool>                         done;
+  reuse_proj_form_type() : m(), p(), done() {}
+  size_t size() const { return m.size(); }
+  void resize(size_t n) { m.resize(n); p.resize(n); done.resize(n,false); }
+};
+
 field_basic<Float,sequential>
-proj (const field_basic<Float,sequential>& uh, bool do_lumped_mass) {
+proj (
+        size_t                               extract_id,
+	const field_basic<Float,sequential>& uh,
+	bool                                 do_lumped_mass,
+        string	            		     use_proj_approx,
+        reuse_proj_form_type                 reuse)
+{
   const space_basic<Float,sequential>& Uh = uh.get_space();
   size_t k = Uh.degree();
   if (k == 0) k++;
-  std::string approx = "P" + itos(k);
+  std::string approx = (do_lumped_mass || use_proj_approx == "") ? "P1" : use_proj_approx;
   space_basic<Float,sequential> Vh (uh.get_geo(), approx, uh.valued());
   test_basic<Float,sequential,details::vf_tag_10> u (Uh), v (Vh);
   test_basic<Float,sequential,details::vf_tag_01> vt (Vh);
   integrate_option fopt;
   fopt.lump = do_lumped_mass;
-  form_basic<Float,sequential> m, p;
-  switch (Uh.valued_tag()) {
-    case space_constant::scalar:
-	  m = integrate(v*vt, fopt);
-	  p = integrate(u*vt);
+  if (!reuse.done[extract_id] || !(reuse.m[extract_id].get_geo() == uh.get_geo())) { 
+    switch (Uh.valued_tag()) {
+      case space_constant::scalar:
+	  reuse.m[extract_id] = integrate(v*vt, fopt);
+	  reuse.p[extract_id] = integrate(u*vt);
 	  break;
-    case space_constant::vector:
-	  m = integrate(dot(v,vt), fopt);
-	  p = integrate(dot(u,vt));
+      case space_constant::vector:
+	  reuse.m[extract_id] = integrate(dot(v,vt), fopt);
+	  reuse.p[extract_id] = integrate(dot(u,vt));
 	  break;
-    case space_constant::tensor:
-    case space_constant::unsymmetric_tensor:
-	  m = integrate(ddot(v,vt), fopt);
-	  p = integrate(ddot(u,vt));
+      case space_constant::tensor:
+      case space_constant::unsymmetric_tensor:
+	  reuse.m[extract_id] = integrate(ddot(v,vt), fopt);
+	  reuse.p[extract_id] = integrate(ddot(u,vt));
 	  break;
-    default:
+      default:
 	  error_macro ("proj: unexpected valued field: " << Uh.valued());
+    }
+    reuse.done[extract_id] = true;
   }
-  solver_basic<Float,sequential> sm (m.uu());
+  solver_basic<Float,sequential> sm (reuse.m[extract_id].uu());
   field_basic<Float,sequential> vh (Vh);
-  vh.set_u() = sm.solve((p*uh).u());
+  vh.set_u() = sm.solve((reuse.p[extract_id]*uh).u());
   return vh;
 }
 void
-extract (idiststream& in, odiststream& out, bool do_proj, bool do_lumped_mass, size_type extract_id,const Float& scale_value)
+extract (
+	idiststream&                  in,
+	odiststream&                  out,
+	bool                          do_proj,
+	bool                          do_lumped_mass,
+        string			      use_proj_approx,
+	size_type                     extract_id,
+        const Float&                  scale_value,
+        reuse_proj_form_type          reuse)
 {
     branch_basic<Float,sequential> event;
     in  >> event.header();
     out << event.header();
-    size_t i = 0;
-    do {
-        in >> catchmark (event.parameter_name());
-	i++;
-    } while (i <= extract_id);
-    if (!in) return;
+    if (reuse.size() == 0) reuse.resize(event.size());
+    for (size_t id = 0; (in >> catchmark (event.parameter_name())) && (id < extract_id); ++id)
+      true;
+    check_macro (in.good(), "extract: index="<<extract_id<<" not found"); 
 
     Float t;
     in >> t;
@@ -475,8 +511,8 @@ extract (idiststream& in, odiststream& out, bool do_proj, bool do_lumped_mass, s
        in >> catchmark (event[i].first) >> event[i].second;
     }
     field_basic<Float,sequential> uh = event[0].second;
-    if (do_proj && uh.get_space().get_basis().have_compact_support_inside_element()) {
-      uh = proj (uh, do_lumped_mass);
+    if (do_proj) {
+      uh = proj (extract_id, uh, do_lumped_mass, use_proj_approx, reuse);
     }
     if (scale_value != Float(1)) {
       uh *= scale_value;
@@ -484,28 +520,23 @@ extract (idiststream& in, odiststream& out, bool do_proj, bool do_lumped_mass, s
     out << event(t,uh);
     out << event.finalize();
 }
-typedef enum {
-	text_render,
-	paraview_render,
-	vtk_render,
-	plotmtv_render,
-	gnuplot_render,
-	toc_render
-} render_type;
+
 void
 put (
 	idiststream&                  in,
 	odiststream&                  out,
 	bool                          do_proj,
 	bool                          do_lumped_mass,
+        string			      use_proj_approx,
 	bool                          def_fill_opt,
 	size_type                     extract_id,
 	const Float&                  scale_value,
 	const std::pair<Float,Float>& u_range,
-	render_type		      render)
+	render_type		      render,
+        reuse_proj_form_type          reuse)
 {
     if (extract_id != numeric_limits<size_type>::max()) {
-      extract (in, out, do_proj, do_lumped_mass, extract_id, scale_value);
+      extract (in, out, do_proj, do_lumped_mass, use_proj_approx, extract_id, scale_value, reuse);
       return;
     }
     Float t = 0;
@@ -515,6 +546,7 @@ put (
       event.set_range (u_range);
     }
     in  >> event.header();
+    if (reuse.size() == 0) reuse.resize(event.size());
     if (render == toc_render) {
       in.is() >> noverbose;
       out << setprecision(numeric_limits<Float>::digits10)
@@ -549,8 +581,8 @@ put (
           }
           out << event.header();
         }
-        if (do_proj && uh.get_space().get_basis().have_compact_support_inside_element()) {
-          uh = proj (uh, do_lumped_mass); // TODO: avoid recomputing/inverting the mass at all step !
+        if (do_proj) {
+          uh = proj (i, uh, do_lumped_mass, use_proj_approx, reuse);
         }
         if (scale_value != Float(1)) {
           uh *= scale_value;
@@ -578,8 +610,10 @@ int main(int argc, char**argv)
     clog << verbose;
     dout.os() << noelevation;
     bool on_stdin = false;
-    bool do_proj  = false;
+    bool do_proj = false;
+    string use_proj_approx = "";
     bool do_lumped_mass = false;
+    reuse_proj_form_type reuse;
     bool do_cut  = false;
     bool def_fill_opt = false;
     int digits10 = numeric_limits<Float>::digits10;
@@ -606,8 +640,12 @@ int main(int argc, char**argv)
         else if (strcmp (argv[i], "-gnuplot") == 0)   { render = gnuplot_render; dout.os() << gnuplot; }
         else if (strcmp (argv[i], "-paraview") == 0)  { render = paraview_render; dout.os() << paraview; }
         else if (strcmp (argv[i], "-skipvtk") == 0)   { dout.os() << skipvtk; }
-        else if (strcmp (argv[i], "-proj") == 0)      { do_proj = true; }
-        else if (strcmp (argv[i], "-lumped-proj") == 0){ do_proj = do_lumped_mass = true; }
+        else if (strcmp (argv[i], "-proj") == 0)      { do_proj = true; 
+                                                        if (i+1 < argc && argv[i+1][0] != '-') {
+                                                          use_proj_approx = argv[++i];
+                                                        }
+                                                      }
+        else if (strcmp (argv[i], "-lumped-proj") == 0){ do_proj = do_lumped_mass = true; use_proj_approx = "P1"; }
         else if (strcmp (argv[i], "-elevation") == 0) { dout.os() << elevation; }
         else if (strcmp (argv[i], "-noelevation") == 0) { dout.os() << noelevation; }
         else if (strcmp (argv[i], "-color") == 0)           { dout.os() << color; }
@@ -703,7 +741,6 @@ int main(int argc, char**argv)
                 cout << setorigin(x);
             } else {
                 cout << setnormal(x);
-warning_macro("normal="<<x);
             }
         } else if (strcmp (argv[i], "-image-format") == 0) {
             if (i == argc-1) {
@@ -770,11 +807,11 @@ warning_macro("normal="<<x);
 
     if (on_stdin) {
         set_input_format (din, input_format);
-        put(din,dout, do_proj, do_lumped_mass, def_fill_opt, extract_id, scale_value, u_range, render);
+        put(din,dout, do_proj, do_lumped_mass, use_proj_approx, def_fill_opt, extract_id, scale_value, u_range, render, reuse);
     } else {
         idiststream in (file_name, "branch");
         check_macro(in.good(), "\"" << file_name << "[.branch[.gz]]\" not found.");
         set_input_format (in, input_format);
-        put(in, dout, do_proj, do_lumped_mass, def_fill_opt, extract_id, scale_value, u_range, render);
+        put(in, dout, do_proj, do_lumped_mass, use_proj_approx, def_fill_opt, extract_id, scale_value, u_range, render, reuse);
     }
 }
