@@ -222,11 +222,11 @@ Rendering options
 >       functions, where the sign of the field is representative.
 
 @addindex projection
+@addindex approximation P1
 `-proj` *approx*
->       Convert all selected fields to approximation *approx* by using a L2 projection.
 `-proj`
->       Convert all selected fields to the Pk Lagrange continuous approximation by using a L2 projection,
->       where *k* is the current polynomial degree.
+>       Convert all selected fields to approximation *approx* by using a L2 projection.
+>       When argument is omitted, `P1` approximation is assumed.
 `-lumped-proj`
 >       Force `P1` approximation for L2 projection and use a lumped mass matrix for it.
 `-round` [*float*]
@@ -687,7 +687,7 @@ int main(int argc, char**argv) {
       const space_basic<Float,sequential>& Uh = uh.get_space();
       size_t k = Uh.degree();
       if (k == 0) k++;
-      std::string approx = (use_proj_approx == "") ? "P" + itos(k) : use_proj_approx;
+      std::string approx = (do_lumped_mass || use_proj_approx == "") ? "P1" : use_proj_approx;
       space_basic<Float,sequential> Vh (uh.get_geo(), approx, uh.valued());
       test_basic<Float,sequential,details::vf_tag_10> u (Uh), v (Vh);
       test_basic<Float,sequential,details::vf_tag_01> vt (Vh);
