@@ -430,6 +430,35 @@ Implementation
 
 # include "rheolef.h"
 # include "rheolef/iofem.h"
+
+#ifdef TO_CLEAN
+// ****************************************************************
+namespace rheolef {
+// output all small objects that do not have 
+//   ostdistream& operator<<
+// but have
+//   ostream&     operator<< 
+template <class T>
+typename std::enable_if<
+  std::is_pointer<
+    decltype(
+      static_cast
+        <std::ostream& (*)(std::ostream&, const T&)>
+        (operator<<)
+    )
+  >::value
+ ,odiststream&
+>::type
+operator<< (odiststream& s, T x)
+{
+    if (s.nop()) return s;
+    s.os() << x;
+    return s;
+}
+} // namespace rheolef {
+// ****************************************************************
+#endif // TO_CLEAN
+
 using namespace rheolef;
 void usage() {
       std::cerr
