@@ -52,6 +52,7 @@ as described by the @ref geo_2 class.
     ------------------------+----------------------------------------------
     dot(u,v)                | u.v = sum_i u_i v_i   
     ddot(sigma,tau)         | sigma:tau = sum_ij sigma_ij tau_ij   
+    dddot(sigma,tau)        | A:.B = sum_ijk A_ijk B_ijk   
     tr(sigma)               | sum_i sigma_ii
     trans(sigma)            | sigma^T the transpose
     sqr(phi), norm2(phi)    | phi^2
@@ -142,7 +143,7 @@ OVERVIEW:
     2.1. binary function helper
     2.2. binary operators: x+y, x-y, x*y, x/y
     2.3. binary standard maths: pow(x,y), atan2(x,y),...
-    2.4. binary extensions: dot(x,y), ddot(x,y)
+    2.4. binary extensions: dot(x,y), ddot(x,y), dddot(x,y)
  3. binders
     3.1. binder_first
     3.2. binder_second
@@ -1437,7 +1438,7 @@ _RHEOLEF_generic_binary_scalar(min)
 _RHEOLEF_generic_binary_scalar(max)
 #undef _RHEOLEF_generic_binary_scalar
 // ----------------------------------------------------------------------------
-// chap 2.4. binary extensions: dot(x,y), ddot(x,y)
+// chap 2.4. binary extensions: dot(x,y), ddot(x,y), dddot(x,y)
 // ----------------------------------------------------------------------------
 // dot(x,y)
 // ------------
@@ -1667,6 +1668,119 @@ struct generic_binary_traits<ddot_> {
   };
   typedef std::true_type is_symmetric;
 };
+// ------------
+// dddot(x,y)
+// ------------
+/*
+    result: when arg1 & arg2 are given
+      1\2 t3 
+       t3  s
+*/
+struct dddot_;
+template <class A1, class A2>
+struct dddot_result {
+    typedef typename promote<typename float_traits<A1>::type, typename float_traits<A2>::type>::type S;
+    typedef binop_error<dddot_,A1,A2,undeterminated_basic<S> > type;
+};
+template <class A1, class A2>
+struct dddot_result<tensor3_basic<A1>,tensor3_basic<A2> > {
+    typedef typename promote<typename float_traits<A1>::type, typename float_traits<A2>::type>::type S;
+    typedef S type;
+};
+struct dddot_ {
+  template<class A1, class A2>
+  typename dddot_result<A1,A2>::type
+  operator() (const A1& x, const A2& y) const { return dddot(x,y); }
+};
+template<>
+struct generic_binary_traits<dddot_> {
+  static space_constant::valued_type
+  valued_tag (space_constant::valued_type tag1, space_constant::valued_type tag2) { 
+    return space_constant::scalar;
+  }
+  template <class A1, class A2, class R>
+  struct hint {
+    typedef binop_error<dddot_,A1,A2,R> T;
+    typedef typename std::conditional<is_undeterminated<A1>::value,T,A1>::type first_argument_type;
+    typedef typename std::conditional<is_undeterminated<A2>::value,T,A2>::type second_argument_type;
+    typedef typename std::conditional<is_undeterminated<R>::value, T,R> ::type result_type;
+  };
+  // a:.b -> ?
+  template <class A1, class A2, class R>
+  struct hint<A1,A2,undeterminated_basic<R> > {
+    typedef typename dddot_result<A1,A2>::type result_type;
+    typedef typename std::conditional<
+	     is_undeterminated<A1>::value
+          && is_error<result_type>::value
+       ,result_type
+       ,A1>::type                             first_argument_type;
+    typedef typename std::conditional<
+             is_undeterminated<A2>::value
+          && is_error<result_type>::value
+       ,result_type
+       ,A2>::type                             second_argument_type;
+  };
+  // ====================
+  // A1 xor A2 is unknown
+  // ====================
+  // ?:.t3 -> s => a=t3
+  template <class A1, class A2, class R>
+  struct hint<undeterminated_basic<A1>,tensor3_basic<A2>,R> {
+    typedef binop_error<dddot_,A1,A2,R> E;
+    typedef typename std::conditional<is_scalar<R>::value,tensor3_basic<A1>,E>::type
+                                              first_argument_type;
+    typedef tensor3_basic<A2>                 second_argument_type;
+    typedef R                                 result_type;
+  };
+  // t3:.? -> s => b=t3
+  template <class A1, class A2, class R>
+  struct hint<tensor3_basic<A1>,undeterminated_basic<A2>,R> {
+    typedef binop_error<dddot_,A1,A2,R> E;
+    typedef tensor3_basic<A1>                 first_argument_type;
+    typedef typename std::conditional<is_scalar<R>::value,tensor3_basic<A2>,E>::type
+                                              second_argument_type;
+    typedef R                                 result_type;
+  };
+  // =====================
+  // A1 and A2 are unknown
+  // =====================
+  // ?:.? -> s => a=b=t3
+  template <class A1, class A2, class R>
+  struct hint<undeterminated_basic<A1>,undeterminated_basic<A2>,R> {
+    typedef binop_error<dddot_,A1,A2,R> E;
+    typedef typename std::conditional<is_scalar<R>::value,tensor3_basic<A1>,E>::type
+                                              first_argument_type;
+    typedef typename std::conditional<is_scalar<R>::value,tensor3_basic<A2>,E>::type
+                                              second_argument_type;
+    typedef R                                 result_type;
+  };
+  // =====================
+  // A2 and R are unknown
+  // =====================
+  // t3:.?  -> ? => (b,r)={(t3,s)}
+  template <class A1, class A2, class R>
+  struct hint<tensor3_basic<A1>,undeterminated_basic<A2>,undeterminated_basic<R> > {
+    typedef tensor3_basic<A1>                 first_argument_type;
+    typedef tensor3_basic<A2>                 second_argument_type;
+    typedef R                                 result_type;
+  };
+  // ========================
+  // A1, A2 and R are unknown
+  // ========================
+  // ?:.? -> ? => a,b,r=?
+  template <class A1, class A2, class R>
+  struct hint<undeterminated_basic<A1>,undeterminated_basic<A2>,undeterminated_basic<R> > {
+    typedef tensor3_basic<A1>                 first_argument_type;
+    typedef tensor3_basic<A2>                 second_argument_type;
+    typedef R                                 result_type;
+  };
+  // short interface
+  template <class Arg1, class Arg2>
+  struct result_hint {
+    typedef typename hint<Arg1,Arg2,undeterminated_basic<Float> >::result_type type;
+  };
+  typedef std::true_type is_symmetric;
+};
 // ===========================================================================
 // part 3. binders
 // ===========================================================================
