@@ -18,6 +18,7 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /// 
 /// =========================================================================
+#include "rheolef/field_wdof_sliced.h" // TODO: should be cleaned after rdof
 #include "rheolef/field.h"
 #include "rheolef/rheostream.h"
 #include "rheolef/iorheo.h"
@@ -74,11 +75,11 @@ get_field_recursive (
   typedef distributor::size_type size_type;
   if (! constit.is_hierarchical()) {
     // non-hierarchical case:
-    const space_scalar_constitution<T,M>& scalar_constit = constit.get_scalar();
+    const space_constitution_terminal<T,M>& terminal_constit = constit.get_terminal();
     size_type comp_dis_ndof = constit.dis_ndof();
 #ifdef TODO
     // conserve a copy of V[i_comp].ios_ownership()
-    const distributor& comp_ios_ownership = scalar_constit.ios_ownership();
+    const distributor& comp_ios_ownership = terminal_constit.ios_ownership();
     size_type comp_ios_ndof = comp_ios_ownership.size();
 #else // TODO
     // recompute V[i_comp].ios_ownership() with comms and risks of errors
@@ -256,7 +257,7 @@ put_field_recursive (
     size_type     comp_ndof = constit.ndof();
     size_type comp_dis_ndof = constit.dis_ndof();
     communicator comm       = constit.comm();
-    const space_scalar_constitution<T,M>& scalar_constit = constit.get_scalar();
+    const space_constitution_terminal<T,M>& terminal_constit = constit.get_terminal();
     size_type io_proc = odiststream::io_proc();
     size_type my_proc = comm.rank();
     distributor comp_ios_ownership (comp_dis_ndof, comm, (my_proc == io_proc ? comp_dis_ndof : 0));
@@ -276,8 +277,8 @@ put_field_recursive (
     if (write_header) {
       ods << "field" << endl
           << "1 " << comp_dis_ndof << endl 
-          << scalar_constit.get_geo().name() << endl
-          << scalar_constit.get_basis().name() << endl
+          << terminal_constit.get_geo().name() << endl
+          << terminal_constit.get_basis().name() << endl
           << endl;
     }
     ods << comp_u_io
@@ -314,11 +315,11 @@ field_basic<T,M>::put_field (odiststream& ods) const
         << endl;
   } else {
     // scalar-field header and equispaced node set
-    const space_scalar_constitution<T,M>& scalar_constit = get_space().get_constitution().get_scalar();
+    const space_constitution_terminal<T,M>& terminal_constit = get_space().get_constitution().get_terminal();
     ods << "field" << endl
         << "1 " << dis_ndof() << endl 
-        << scalar_constit.get_geo().name() << endl
-        << scalar_constit.get_basis().name() << endl
+        << terminal_constit.get_geo().name() << endl
+        << terminal_constit.get_basis().name() << endl
         << endl;
   }
   size_type comp_start_idof     = 0;
@@ -405,28 +406,6 @@ field_basic<T,M>::dis_dof_entry (size_type dis_idof)
     return _b.dis_entry (dis_iub);
   }
 }
-template <class T, class M>
-void
-field_basic<T,M>::dis_dof_update() const
-{
-#ifdef _RHEOLEF_HAVE_MPI
-  std::size_t nproc = ownership().comm().size();
-  if (is_distributed<M>::value && nproc > 1) {
-    std::size_t do_assembly = mpi::all_reduce (ownership().comm(), size_t(_dis_dof_assembly_requires_update), std::plus<std::size_t>());
-    std::size_t do_indexes  = mpi::all_reduce (ownership().comm(), size_t(_dis_dof_indexes_requires_update),  std::plus<std::size_t>());
-    if (do_assembly) {
-      _u.dis_entry_assembly();
-      _b.dis_entry_assembly();
-    }
-    if (do_indexes) {
-      _u.set_dis_indexes (_V.ext_iu_set());
-      _b.set_dis_indexes (_V.ext_ib_set());
-    }
-  }
-#endif // _RHEOLEF_HAVE_MPI
-  _dis_dof_indexes_requires_update = false;
-  _dis_dof_assembly_requires_update = false;
-}
 // ----------------------------------------------------------------------------
 // evaluation
 // ----------------------------------------------------------------------------
@@ -495,22 +474,24 @@ field_basic<T,M>::dis_vector_evaluate (const point_basic<T>& x) const
 // ----------------------------------------------------------------------------
 // tensor component access: sigma_h(i,j)
 // ----------------------------------------------------------------------------
+#ifdef TO_CLEAN
 template <class T, class M>
-field_component_const<T,M>
+details::field_rdof_sliced_const<field_basic<T,M>>
 field_basic<T,M>::operator() (size_type i_comp, size_type j_comp) const
 {
   space_constant::coordinate_type sys_coord = get_geo().coordinate_system();
   size_type ij_comp = space_constant::tensor_index (valued_tag(), sys_coord, i_comp, j_comp);
-  return field_component_const<T,M> (*this, ij_comp);
+  return details::field_rdof_sliced_const<field_basic<T,M>> (*this, ij_comp);
 }
 template <class T, class M>
-field_component<T,M>
+details::field_wdof_sliced<field_basic<T,M>>
 field_basic<T,M>::operator() (size_type i_comp, size_type j_comp)
 {
   space_constant::coordinate_type sys_coord = get_geo().coordinate_system();
   size_type ij_comp = space_constant::tensor_index (valued_tag(), sys_coord, i_comp, j_comp);
-  return field_component<T,M> (*this, ij_comp);
+  return details::field_wdof_sliced<field_basic<T,M>> (*this, ij_comp);
 }
+#endif // TO_CLEAN
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
