@@ -99,6 +99,11 @@ the boundary:
         space Xh (omega, "P1");
         uh["boundary"] = 0;
 
+A possible alternative uses a @ref geo_2 domain as index:
+
+        geo boundary = omega["boundary"];
+        uh[boundary] = 0;
+
 Multi-valued fields
 ===================
 A vector-valued field contains several components, as:
@@ -185,193 +190,261 @@ to a vector data container:
 */
 } // namespace rheolef
 
-#include "rheolef/linalg.h"
-#include "rheolef/space.h"
-#include "rheolef/undeterminated.h"
-#include "rheolef/misc_algo.h" // copy_n
-#include "rheolef/quadrature.h"
-#include "rheolef/integrate_option.h"
+#include "rheolef/field_rdof.icc"
+#include "rheolef/field_wdof.icc"
+#include "rheolef/integrate_option.h" // TO_CLEAN with old interface
 
 namespace rheolef {
 
-// forward declaration:
-template <class T, class M> class field_indirect;
-template <class T, class M> class field_indirect_const;
-template <class T, class M> class field_component;
-template <class T, class M> class field_component_const;
-template <class T, class M> class band_basic;
 namespace details {
+
+// forward declarations:
 template <class T, class M> class field_concat_value;
-} // namespace details
-
-namespace details {
-
-// Define a trait type for constants
-template <class Value>
-struct is_field_expr_v2_constant
-: or_type<
-     is_rheolef_arithmetic<Value>
-    ,is_point<Value>
-    ,is_tensor<Value>
-    ,is_tensor3<Value>
-    ,is_tensor4<Value>
-  >
-{};
-
-// Define traits for field_expressions:
-template <class Expr> struct is_field;
-template<class T, class Sfinae = void> struct is_field_expr_affine_homogeneous: std::false_type {};
+template <class FieldWdof> class field_wdof_sliced;
+template <class FieldRdof> class field_rdof_sliced_const;
 
 } // namespace details
 
+// ----------------------------------------------------------------------------
+// main class
+// ----------------------------------------------------------------------------
 // [verbatim_field_basic]
 template <class T, class M = rheo_default_memory_model>
-class field_basic {
+class field_basic: public details::field_wdof_base<field_basic<T,M>> {
 public :
 // typedefs:
 
-    using size_type     = std::size_t;
-    using memory_type   = M;
-    using value_type    = T; // TODO: run-time dependent
-    using result_type   = T; // TODO: run-time dependent
-    // using value_type = undeterminated_basic<T>; // TODO
-    using scalar_type   = T;
-    using float_type    = typename float_traits<T>::type;
-    using valued_type   = space_constant::valued_type;
-    using geo_type      = geo_basic  <float_type,M>;
-    using space_type    = space_basic<float_type,M>;
-    using dis_reference = typename vec<T,M>::dis_reference;
-    class iterator;
-    class const_iterator;
+  using wdof_base     = details::field_wdof_base<field_basic<T,M>>;
+  using rdof_base     = details::field_rdof_base<field_basic<T,M>>;
+  using size_type     = std::size_t;
+  using scalar_type   = T;
+  using memory_type   = M;
+  using float_type    = typename float_traits<T>::type;
+  using geo_type      = geo_basic  <float_type,memory_type>;
+  using space_type    = space_basic<float_type,memory_type>;
+  using dis_reference = typename vec<scalar_type,memory_type>::dis_reference;
+  using valued_type   = space_constant::valued_type;
+  using value_type    = T; // TODO: run-time dependent, set it to undeterminated<T>
+  using result_type   = T; // TODO: run-time dependent, set it to undeterminated<T>
+  class iterator;
+  class const_iterator;
 
 // allocator/deallocator:
   
-    field_basic();
+  field_basic();
 
-    explicit field_basic (
-	const space_type& V, 
-	const T& init_value = std::numeric_limits<T>::max());
+  explicit field_basic (
+    const space_type& V, 
+    const T& init_value = std::numeric_limits<T>::max());
    
-    void resize (
-	const space_type& V, 
-	const T& init_value = std::numeric_limits<T>::max());
+  void resize (
+    const space_type& V, 
+    const T& init_value = std::numeric_limits<T>::max());
 
-    // expressions:
-    template <class Expr, class Sfinae =
+  // expressions: field_expr or field_lazy are accepted here
+  // TODO: merge with FieldLazy piecewise_poly
+  template <class Expr, class Sfinae =
     typename std::enable_if<
-           details::is_field_expr_affine_homogeneous<Expr>::value
-      && ! details::is_field<Expr>::value>::type>
-    field_basic (const Expr& expr);
+      (      details::is_field_expr_affine_homogeneous<Expr>::value
+        && ! details::is_field<Expr>::value
+      )
+      ||   details::is_field_lazy<Expr>::value
+    >::type>
+  field_basic (const Expr& expr);
 
-    // initializer list (c++ 2011):
-    field_basic (const std::initializer_list<details::field_concat_value<T,M> >& init_list);
+  field_basic (const std::initializer_list<details::field_concat_value<T,M> >& init_list);
 
 // assignments:
 
-    field_basic<T,M>& operator=  (const field_basic<T,M>&);
-
-    template <class Value>
-    typename std::enable_if<
-      details::is_rheolef_arithmetic<Value>::value
-     ,field_basic<T,M>&
-    >::type
-    operator=  (const Value& value);
-
-
-    template <class Expr>
-    typename std::enable_if<
-           details::is_field_expr_affine_homogeneous<Expr>::value
-      && ! details::is_field_expr_v2_constant       <Expr>::value
-      && ! details::is_field                        <Expr>::value
-     ,field_basic<T, M>&>::type
-    operator=  (const Expr&);
-
-    // initializer list (c++ 2011):
-    field_basic<T,M>& operator= (const std::initializer_list<details::field_concat_value<T,M> >& init_list);
+  field_basic<T,M>& operator= (const field_basic<T,M>&);
+  field_basic<T,M>& operator= (const std::initializer_list<details::field_concat_value<T,M> >& init_list);
 
 // accessors:
 
-    const space_type&  get_space()  const { return _V; }
-    const geo_type&    get_geo()    const { return _V.get_geo(); }
-    std::string        name()      const { return _V.name(); }
-    std::string        get_approx() const { return _V.get_approx(); }
-    valued_type        valued_tag() const { return _V.valued_tag(); }
-    const std::string& valued()     const { return _V.valued(); }
-    bool have_homogeneous_space (space_basic<T,M>& Xh) const { Xh = get_space(); return true; }
+  const space_type&  get_space()  const { return _V; }
+  const geo_type&    get_geo()    const { return _V.get_geo(); }
+  std::string        get_approx() const { return _V.get_approx(); }
+  valued_type        valued_tag() const { return _V.valued_tag(); }
+  const std::string& valued()     const { return _V.valued(); }
+#ifdef TO_CLEAN
+  std::string        name()      const { return _V.name(); }
+  bool have_homogeneous_space (space_basic<T,M>& Xh) const { Xh = get_space(); return true; }
+#endif // TO_CLEAN
 
 // accessors & modifiers to unknown & blocked parts:
 
-    const vec<T,M>&     u() const { return _u; }
-    const vec<T,M>&     b() const { return _b; }
-          vec<T,M>& set_u()       { dis_dof_indexes_requires_update(); return _u; }
-          vec<T,M>& set_b()       { dis_dof_indexes_requires_update(); return _b; }
+  const vec<T,M>&     u() const { return _u; }
+  const vec<T,M>&     b() const { return _b; }
+        vec<T,M>& set_u()       { dis_dof_indexes_requires_update(); return _u; }
+        vec<T,M>& set_b()       { dis_dof_indexes_requires_update(); return _b; }
 
 // accessors to extremas:
 
-    T min() const;
-    T max() const;
-    T max_abs() const;
-    T min_abs() const;
-
-// accessors by domains:
-
-    field_indirect<T,M>        operator[] (const geo_basic<T,M>& dom);
-    field_indirect_const<T,M>  operator[] (const geo_basic<T,M>& dom) const;
-    field_indirect<T,M>        operator[] (std::string dom_name);
-    field_indirect_const<T,M>  operator[] (std::string dom_name) const;
-
-// accessors by components:
-
-    size_type size() const { return _V.size(); }
-    field_component<T,M>       operator[] (size_type i_comp);
-    field_component_const<T,M> operator[] (size_type i_comp) const;
-    field_component<T,M>       operator() (size_type i_comp, size_type j_comp);
-    field_component_const<T,M> operator() (size_type i_comp, size_type j_comp) const;
+  T min() const;
+  T max() const;
+  T max_abs() const;
+  T min_abs() const;
 
 // accessors by degrees-of-freedom (dof):
 
-    const distributor& ownership() const { return get_space().ownership(); }
-    const communicator& comm() const { return ownership().comm(); }
-    size_type     ndof() const { return ownership().size(); }
-    size_type dis_ndof() const { return ownership().dis_size(); }
-          T& dof (size_type idof);
-    const T& dof (size_type idof) const;
-    const T& dis_dof (size_type dis_idof) const;
-    // write access to non-local dis_idof changes to others procs
-    dis_reference dis_dof_entry (size_type dis_idof);
+  const distributor& ownership() const { return get_space().ownership(); }
+  const communicator& comm() const { return ownership().comm(); }
+  size_type     ndof() const { return ownership().size(); }
+  size_type dis_ndof() const { return ownership().dis_size(); }
+        T& dof (size_type idof);
+  const T& dof (size_type idof) const;
+  const T& dis_dof (size_type dis_idof) const;
+  // write access to non-local dis_idof changes to others procs
+  dis_reference dis_dof_entry (size_type dis_idof);
 
-    iterator begin_dof();
-    iterator end_dof();
-    const_iterator begin_dof() const;
-    const_iterator end_dof() const;
+  iterator begin_dof();
+  iterator end_dof();
+  const_iterator begin_dof() const;
+  const_iterator end_dof() const;
 
 // input/output:
 
-    idiststream& get (idiststream& ips);
-    odiststream& put (odiststream& ops) const;
-    odiststream& put_field (odiststream& ops) const;
+  idiststream& get (idiststream& ips);
+  odiststream& put (odiststream& ops) const;
+  odiststream& put_field (odiststream& ops) const;
 
 // evaluate uh(x) where x is given locally as hat_x in K:
 
-    T dis_evaluate (const point_basic<T>& x, size_type i_comp = 0) const;
-    T operator()   (const point_basic<T>& x) const { return dis_evaluate (x,0); }
-    point_basic<T> dis_vector_evaluate (const point_basic<T>& x) const;
+  T dis_evaluate (const point_basic<T>& x, size_type i_comp = 0) const;
+  T operator()   (const point_basic<T>& x) const { return dis_evaluate (x,0); }
+  point_basic<T> dis_vector_evaluate (const point_basic<T>& x) const;
 
 // [verbatim_field_basic]
 // internals:
-    int constraint_process_rank() const { return u().constraint_process_rank(); }
+  int constraint_process_rank() const { return u().constraint_process_rank(); }
 public:
 
-    // evaluate uh(x) where x is given locally as hat_x in K:
-    // requiers to call field::dis_dof_upgrade() before.
-    T evaluate (const geo_element& K, const point_basic<T>& hat_xq, size_type i_comp = 0) const;
+  // evaluate uh(x) where x is given locally as hat_x in K:
+  // requiers to call field::dis_dof_upgrade() before.
+  T evaluate (const geo_element& K, const point_basic<T>& hat_xq, size_type i_comp = 0) const;
 
-    // propagate changed values shared at partition boundaries to others procs
-    void dis_dof_update() const;
+  // propagate changed values shared at partition boundaries to others procs
+  template <class SetOp = details::generic_set_op>
+  void dis_dof_update (const SetOp& = SetOp()) const;
 
-    // new interface
+  // assignments from expressions
+  template <class Value>
+  typename std::enable_if<
+    details::is_rheolef_arithmetic<Value>::value
+   ,field_basic<T,M>&
+  >::type
+  operator=  (const Value& value)
+  {
+trace_macro("op=(value)...");
+    check_macro (get_space().name() != "", "field=constant : uninitialized field in affectation");
+    wdof_base::operator= (value);
+trace_macro("op=(value) done");
+    return *this;
+  }
+  // TODO: merge with FieldRdof/Lazy && piecewise_polynomial
+  template <class Expr>
+  typename std::enable_if<
+         details::is_field_expr_affine_homogeneous<Expr>::value
+    && ! details::has_field_rdof_interface        <Expr>::value
+    && ! details::is_field_expr_v2_constant       <Expr>::value
+    && ! details::is_field                        <Expr>::value
+   ,field_basic<T, M>&
+  >::type
+  operator=  (const Expr& expr)
+  {
+trace_macro("op=(expr)...");
+    space_type Xh;
+    check_macro (expr.have_homogeneous_space (Xh),
+      "field = expr; expr should have homogeneous space. HINT: use field = interpolate(Xh, expr)");
+    if (get_space().name() != Xh.name()) resize (Xh, 0);
+    details::assign_with_operator (begin_dof(), end_dof(), expr.begin_dof(), details::assign_op());
+trace_macro("op=(expr) done");
+    return *this;
+  }
+  // TODO: FieldRdof && piecewise_polynomial only: filter
+  template<class FieldRdof>
+  typename std::enable_if<
+         details::has_field_rdof_interface<FieldRdof>::value
+    && ! details::is_field                <FieldRdof>::value
+   ,field_basic<T, M>&
+  >::type
+  operator= (const FieldRdof& rdof)
+  {
+trace_macro("op=(rdof)...");
+    const space_type& Xh = rdof.get_space();
+    if (get_space().name() != Xh.name()) resize (Xh, 0);
+    wdof_base::operator= (rdof);
+trace_macro("op=(rdof) done");
+    return *this;
+  }
+  // TODO: FieldLazy && piecewise_polynomial only: filter
+  template<class FieldLazy>
+  typename std::enable_if<
+         details::has_field_lazy_interface<FieldLazy>::value
+    && ! details::has_field_rdof_interface<FieldLazy>::value
+   ,field_basic<T, M>&
+  >::type
+  operator= (const FieldLazy& lazy)
+  {
+trace_macro("op=(lazy)...");
+    const space_type& Xh = lazy.get_space();
+    if (get_space().name() != Xh.name()) resize (Xh, 0);
+    wdof_base::operator= (lazy);
+trace_macro("op=(lazy) done");
+    return *this;
+  }
+
+#ifdef TO_CLEAN
+  // TODO: move in field_wdof
+  template<class Expr>
+  typename std::enable_if<
+    details::is_field_lazy<Expr>::value
+   ,field_basic<T, M>&
+  >::type
+  operator+= (const Expr&);
+
+  // TODO: move in field_wdof
+  template<class Expr>
+  typename std::enable_if<
+    details::is_field_lazy<Expr>::value
+   ,field_basic<T, M>&
+  >::type
+  operator-= (const Expr&);
+
+  template<class FieldLazy, class SetPlusOp>
+  typename std::enable_if<
+    details::is_field_lazy<FieldLazy>::value
+   ,void
+  >::type
+  convert_from_field_lazy (const FieldLazy& expr, const SetPlusOp& set_plus_op);
+#endif // TO_CLEAN
+
+// accessors by domains and indexes:
+
+  // TODO: why is it necessary to explicit them while its done implicitely in field_wdof_indirect ?
+  details::field_wdof_indirect<field_basic<T,M>>       operator[] (const geo_type& dom)
+                                                       { return wdof_base::operator[] (dom); }
+  details::field_wdof_indirect<field_basic<T,M>>       operator[] (std::string dom_name)
+                                                       { return wdof_base::operator[] (dom_name); }
+  details::field_rdof_indirect_const<field_basic<T,M>> operator[] (const geo_type& dom) const
+                                                       { return rdof_base::operator[] (dom); }
+  details::field_rdof_indirect_const<field_basic<T,M>> operator[] (std::string dom_name) const
+                                                       { return rdof_base::operator[] (dom_name); }
+
+
+  size_type size() const { return _V.size(); }
+  details::field_wdof_sliced<field_basic<T,M>>       operator[] (size_type i_comp)
+                                                     { return wdof_base::operator[] (i_comp); }
+  details::field_wdof_sliced<field_basic<T,M>>       operator() (size_type i_comp, size_type j_comp)
+                                                     { return wdof_base::operator() (i_comp, j_comp); }
+  details::field_rdof_sliced_const<field_basic<T,M>> operator[] (size_type i_comp) const
+                                                     { return rdof_base::operator[] (i_comp); }
+  details::field_rdof_sliced_const<field_basic<T,M>> operator() (size_type i_comp, size_type j_comp) const
+                                                     { return rdof_base::operator() (i_comp, j_comp); }
+
+    // old interface
     template <class Expr>
-    void assembly_internal (
+    void do_integrate_internal (
         const geo_basic<T,M>&         dom,
         const geo_basic<T,M>&         band,
         const band_basic<T,M>&        gh,
@@ -379,12 +452,12 @@ public:
         const integrate_option&       qopt,
         bool                          is_on_band);
     template <class Expr>
-    void assembly (
+    void do_integrate (
         const geo_basic<T,M>&         dom,
         const Expr&                   expr,
         const integrate_option&       iopt);
     template <class Expr>
-    void assembly (
+    void do_integrate (
         const band_basic<T,M>&        gh,
         const Expr&                   expr,
         const integrate_option&       iopt);
@@ -401,6 +474,25 @@ protected:
     mutable bool         _dis_dof_assembly_requires_update;
 // [verbatim_field_basic_cont]
 };
+
+namespace details {
+
+// concepts:
+template<class T, class M>
+struct is_field<field_basic<T,M>> : std::true_type {};
+
+// field class is not an ordinary function/functor : for compose(field,args...) filtering
+template <typename T, typename M>  struct function_traits <field_basic<T,M> > {};
+
+template<class T, class M> 
+struct field_traits<field_basic<T,M>> {
+  using size_type     = std::size_t;
+  using scalar_type   = T;
+  using memory_type   = M;
+};
+
+} // namespace details
+
 // [verbatim_field_basic_cont]
 template <class T, class M>
 idiststream& operator >> (odiststream& ips, field_basic<T,M>& u);
@@ -412,11 +504,13 @@ odiststream& operator << (odiststream& ops, const field_basic<T,M>& uh);
 //! @brief see the @ref field_2 page for the full documentation
 typedef field_basic<Float> field;
 // [verbatim_field]
+
 typedef field_basic<Float,sequential> field_sequential;
 
 // =================================================================================
 // field::iterator
 // =================================================================================
+// TODO: use field_wdof_sliced iterators
 template <class T, class M>
 class field_basic<T,M>::iterator {
 protected:
@@ -471,7 +565,7 @@ public:
       return (!blk) ? _u[iub] : _b[iub];
   }
   iterator& operator++ () { _blk_dis_iub_iter += _blk_dis_iub_incr; return *this; }
-  iterator  operator++ (int) { iterator tmp = *this; operator++(); return *this; }
+  iterator  operator++ (int) { iterator tmp = *this; operator++(); return tmp; }
   iterator& operator+= (difference_type n) { _blk_dis_iub_iter += n*_blk_dis_iub_incr; return *this; }
   iterator  operator+  (difference_type n) const { iterator tmp = *this; return tmp += n; }
   reference operator[] (size_type n) const { return *(*this + n); }
@@ -561,7 +655,7 @@ public:
       return (!blk) ? _u[iub] : _b[iub];
   }
   const_iterator& operator++ () { _blk_dis_iub_iter += _blk_dis_iub_incr; return *this; }
-  const_iterator  operator++ (int) { const_iterator tmp = *this; operator++(); return *this; }
+  const_iterator  operator++ (int) { const_iterator tmp = *this; operator++(); return tmp; }
   const_iterator& operator+= (difference_type n) { _blk_dis_iub_iter += n*_blk_dis_iub_incr; return *this; }
   const_iterator  operator+  (difference_type n) const { const_iterator tmp = *this; return tmp += n; }
   reference operator[] (size_type n) const { return *(*this + n); }
@@ -607,17 +701,18 @@ field_basic<T,M>::field_basic ()
    _dis_dof_assembly_requires_update(false)
 {
 }
-template <class T, class M>
+// TODO: merge Expr with Fieldlazy
+template<class T, class M>
+template<class Expr, class Sfinae>
 inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_basic<T,M>& x)
+field_basic<T,M>::field_basic (const Expr& expr)
+ : _V (),
+   _u (),
+   _b (),
+   _dis_dof_indexes_requires_update(true),
+   _dis_dof_assembly_requires_update(false)
 {
-  _V.operator= (x._V);
-  _u.operator= (x._u);
-  _b.operator= (x._b);
-   _dis_dof_indexes_requires_update =  x._dis_dof_indexes_requires_update;
-  _dis_dof_assembly_requires_update = x._dis_dof_assembly_requires_update;
-  return *this;
+    operator= (expr);
 }
 template <class T, class M>
 void
@@ -631,21 +726,6 @@ field_basic<T,M>::dis_dof_assembly_requires_update() const
 {
   _dis_dof_assembly_requires_update = true;
 }
-// TODO: DVT_EXPR_CTE_VEC : value as point or tensor
-template<class T, class M>
-template <class Value>
-inline
-typename std::enable_if<
-  details::is_rheolef_arithmetic<Value>::value
- ,field_basic<T,M>&
->::type
-field_basic<T,M>::operator=  (const Value& value)
-{
-  check_macro (name() != "", "field=constant : uninitialized field in affectation");
-  std::fill (begin_dof(), end_dof(), value);
-  dis_dof_indexes_requires_update();
-  return *this;
-}
 template <class T, class M>
 inline
 T& 
@@ -672,6 +752,29 @@ field_basic<T,M>::dof (size_type idof) const
   return (!blk) ? _u.dis_at(dis_iub) : _b.dis_at(dis_iub);
 }
 template <class T, class M>
+template <class SetOp>
+void
+field_basic<T,M>::dis_dof_update (const SetOp& set_op) const
+{
+#ifdef _RHEOLEF_HAVE_MPI
+  std::size_t nproc = ownership().comm().size();
+  if (is_distributed<M>::value && nproc > 1) {
+    std::size_t do_assembly = mpi::all_reduce (ownership().comm(), size_t(_dis_dof_assembly_requires_update), std::plus<std::size_t>());
+    std::size_t do_indexes  = mpi::all_reduce (ownership().comm(), size_t(_dis_dof_indexes_requires_update),  std::plus<std::size_t>());
+    if (do_assembly) {
+      _u.dis_entry_assembly (set_op);
+      _b.dis_entry_assembly (set_op);
+    }
+    if (do_indexes) {
+      _u.set_dis_indexes (_V.ext_iu_set());
+      _b.set_dis_indexes (_V.ext_ib_set());
+    }
+  }
+#endif // _RHEOLEF_HAVE_MPI
+  _dis_dof_indexes_requires_update = false;
+  _dis_dof_assembly_requires_update = false;
+}
+template <class T, class M>
 inline
 T
 field_basic<T,M>::min () const
@@ -749,6 +852,183 @@ operator << (odiststream& ops, const field_basic<T,M>& uh)
 {
   return uh.put (ops);
 }
+// ----------------------------------
+// special interpolate with field arg
+// ----------------------------------
+// re-interpolation of fields and linear field expressions
+//      for change of mesh, of approx, ect
+// not truly lazy, but here for the completeness of the interpolate interface
+//! @brief see the @ref interpolate_3 page for the full documentation
+template<class T, class M>
+inline
+field_basic<T,M>
+lazy_interpolate (const space_basic<T,M>& X2h, const field_basic<T,M>& u1h)
+{
+  return interpolate (X2h, u1h);
+}
+// interpolate e.g. uh[0] or uh["boundary"], i.e. a FieldRdof
+//! @brief see the @ref interpolate_3 page for the full documentation
+template <class T, class M, class FieldRdof>
+inline
+typename std::enable_if<
+       details::has_field_rdof_interface<FieldRdof>::value
+  && ! details::is_field<FieldRdof>::value
+ ,field_basic<T,M>
+>::type
+lazy_interpolate (const space_basic<T,M>& Xh, const FieldRdof& uh)
+{
+  return interpolate (Xh, field_basic<T,M>(uh));
+}
+// --------------------------
+// operator=
+// --------------------------
+template <class T, class M>
+inline
+field_basic<T,M>&
+field_basic<T,M>::operator=  (const field_basic<T,M>& x)
+{
+  _V.operator= (x._V);
+  _u.operator= (x._u);
+  _b.operator= (x._b);
+  _dis_dof_indexes_requires_update =  x._dis_dof_indexes_requires_update;
+  _dis_dof_assembly_requires_update = x._dis_dof_assembly_requires_update;
+  return *this;
+}
+#ifdef TO_CLEAN
+template<class T, class M>
+template <class Value>
+inline
+typename std::enable_if<
+  details::is_rheolef_arithmetic<Value>::value
+ ,field_basic<T,M>&
+>::type
+field_basic<T,M>::operator=  (const Value& value)
+{
+  check_macro (name() != "", "field=constant : uninitialized field in affectation");
+  std::fill (begin_dof(), end_dof(), value);
+  return *this;
+}
+template<class T, class M>
+template<class FieldLazy>
+typename std::enable_if<
+  details::is_field_lazy<FieldLazy>::value
+ ,field_basic<T, M>&
+>::type
+field_basic<T,M>::operator+= (const FieldLazy& expr)
+{
+  const space_basic<T,M>& Xh = expr.get_space();
+  convert_from_field_lazy (expr, details::generic_set_plus_op());
+  return *this;
+}
+template<class T, class M>
+template<class FieldLazy>
+typename std::enable_if<
+  details::is_field_lazy<FieldLazy>::value
+ ,field_basic<T, M>&
+>::type
+field_basic<T,M>::operator-= (const FieldLazy& expr)
+{
+  const space_basic<T,M>& Xh = expr.get_space();
+  convert_from_field_lazy (expr, details::generic_set_minus_op());
+  return *this;
+}
+#endif // TO_CLEAN
+// --------------------------------------
+// io
+// --------------------------------------
+// TODO: one output for all rdof or lazy & one input for all wdof
+template<class FieldLazy>
+typename std::enable_if<
+  details::has_field_lazy_interface<FieldLazy>::value
+  && ! details::is_field<FieldLazy>::value
+  // details::is_field_lazy<FieldLazy>::value
+ ,odiststream&
+>::type
+operator<< (odiststream& out, const FieldLazy& expr)
+{
+  using T = typename FieldLazy::scalar_type;
+  using M = typename FieldLazy::memory_type;
+  field_basic<T,M> uh = expr;
+  return out << uh;
+}
+#ifdef TODO
+// TODO: as: field vh; din >> vh ; uh[i_comp] = vh;
+template<class FieldWdof>
+inline
+idiststream&
+operator>> (odiststream& ids, details::field_wdof_sliced<FieldWdof>& u);
+#endif // TODO
+// --------------------------------------
+// interaction with field_indirect
+// --------------------------------------
+// TODO: use a template FieldRdof and a dof-based convert function
+// => interaction=convert from field_rdof
+#ifdef TO_CLEAN
+template<class T, class M>
+inline
+details::field_wdof_indirect<field_basic<T,M>>
+field_basic<T,M>::operator[] (const geo_type& dom)
+{
+  dis_dof_indexes_requires_update();
+  return details::field_wdof_indirect<field_basic<T,M>> (*this, dom);
+}
+template<class T, class M>
+inline
+details::field_wdof_indirect<field_basic<T,M>>
+field_basic<T,M>::operator[] (std::string dom_name)
+{
+  dis_dof_indexes_requires_update();
+  return operator[] (get_space().get_geo().operator[] (dom_name));
+}
+template<class T, class M>
+inline
+details::field_rdof_indirect_const<field_basic<T,M>>
+field_basic<T,M>::operator[] (const geo_type& dom) const
+{
+  return details::field_rdof_indirect_const<field_basic<T,M>> (*this, dom);
+}
+template<class T, class M>
+inline
+details::field_rdof_indirect_const<field_basic<T,M>>
+field_basic<T,M>::operator[] (std::string dom_name) const
+{
+  return operator[] (get_space().get_geo().operator[] (dom_name));
+}
+#endif // TO_CLEAN
+// --------------------------------------
+// interaction with field_wdof_sliced
+// --------------------------------------
+#ifdef TO_CLEAN
+template<class T, class M>
+inline
+details::field_rdof_sliced_const<field_basic<T,M>>
+field_basic<T,M>::operator[] (size_type i_comp) const
+{
+  return details::field_rdof_sliced_const<field_basic<T,M>> (*this, i_comp);
+}
+template<class T, class M>
+inline
+details::field_wdof_sliced<field_basic<T,M>>
+field_basic<T,M>::operator[] (size_type i_comp)
+{
+  dis_dof_indexes_requires_update();
+  return details::field_wdof_sliced<field_basic<T,M>> (*this, i_comp);
+}
+// --------------------------------------
+// convert from field_lazy
+// --------------------------------------
+template<class T, class M>
+template<class FieldLazy, class SetPlusOp>
+inline
+typename std::enable_if<
+  details::is_field_lazy<FieldLazy>::value
+ ,void
+>::type
+field_basic<T,M>::convert_from_field_lazy (const FieldLazy& expr, const SetPlusOp& set_plus_op)
+{
+  details::convert_lazy2wdof (expr, set_plus_op, *this);
+}
+#endif // TO_CLEAN
 
 }// namespace rheolef
 # endif /* _RHEOLEF_FIELD_H */
