@@ -74,7 +74,8 @@ public:
   typedef typename Expr::value_type                     value_type;
   typedef typename scalar_traits<value_type>::type  	scalar_type;
   typedef typename  float_traits<value_type>::type 	float_type;
-  typedef space_basic<scalar_type,memory_type>		space_type;
+  typedef space_basic<float_type,memory_type>		space_type;
+  typedef geo_basic  <float_type,memory_type>		geo_type;
   typedef typename Expr::vf_tag_type                    vf_tag_type;
   typedef typename details::dual_vf_tag<vf_tag_type>::type
                                                         vf_dual_tag_type;
@@ -90,8 +91,8 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) const;
-  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) const;
+  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt);
+  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt);
 
 // accessors:
 
@@ -130,7 +131,7 @@ template<class Expr>
 void
 field_expr_quadrature_on_element<Expr>::initialize (
   const geo_basic<float_type,memory_type>& omega_K,
-  const integrate_option&                  iopt) const
+  const integrate_option&                  iopt)
 {
   integrate_option new_iopt   = expr_quadrature_init_iopt (omega_K, get_vf_space(), n_derivative(), iopt);
   quadrature<float_type> quad = expr_quadrature_init_quad<float_type> (new_iopt);
@@ -141,7 +142,7 @@ template<class Expr>
 void
 field_expr_quadrature_on_element<Expr>::initialize (
   const band_basic<float_type,memory_type>& gh,
-  const integrate_option&                   iopt) const
+  const integrate_option&                   iopt)
 {  
   integrate_option new_iopt   = expr_quadrature_init_iopt (gh.band(), get_vf_space(), n_derivative(), iopt);
   quadrature<float_type> quad = expr_quadrature_init_quad<float_type> (new_iopt);
@@ -190,7 +191,8 @@ public:
   typedef typename Expr::value_type                     value_type;
   typedef typename scalar_traits<value_type>::type  	scalar_type;
   typedef typename  float_traits<value_type>::type 	float_type;
-  typedef space_basic<scalar_type,memory_type>          space_type;
+  typedef space_basic<float_type,memory_type>           space_type;
+  typedef geo_basic  <float_type,memory_type>		geo_type;
   typedef typename Expr::vf_tag_type                    vf_tag_type;
   typedef typename details::dual_vf_tag<vf_tag_type>::type
                                                         vf_dual_tag_type;
@@ -211,8 +213,8 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) const;
-  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) const;
+  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt);
+  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt);
 
   template<class Value>
   void evaluate (
@@ -254,7 +256,7 @@ field_expr_quadrature_on_sides<Expr>::field_expr_quadrature_on_sides (const Expr
 }
 template<class Expr>
 void
-field_expr_quadrature_on_sides<Expr>::initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) const
+field_expr_quadrature_on_sides<Expr>::initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt)
 {
   _ignore_sys_coord = iopt.ignore_sys_coord;
   integrate_option new_iopt   = expr_quadrature_init_iopt (omega_K, get_vf_space(), n_derivative(), iopt);
@@ -265,7 +267,7 @@ field_expr_quadrature_on_sides<Expr>::initialize (const geo_basic<float_type,mem
 }
 template<class Expr>
 void
-field_expr_quadrature_on_sides<Expr>::initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) const
+field_expr_quadrature_on_sides<Expr>::initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt)
 {
   _ignore_sys_coord = iopt.ignore_sys_coord;
   integrate_option new_iopt   = expr_quadrature_init_iopt (gh.band(), get_vf_space(), n_derivative(), iopt);
@@ -345,7 +347,8 @@ public:
 	 ,result_hint>::result_type                     value_type;
   typedef typename scalar_traits<value_type>::type  	scalar_type;
   typedef typename  float_traits<value_type>::type 	float_type;
-  typedef space_basic<scalar_type,memory_type>		space_type;
+  typedef space_basic<float_type,memory_type>           space_type;
+  typedef geo_basic  <float_type,memory_type>		geo_type;
   typedef typename Expr::vf_tag_type                    vf_tag_type;
   typedef typename details::dual_vf_tag<vf_tag_type>::type
                                                         vf_dual_tag_type;
@@ -368,9 +371,9 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) const {
+  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) {
     return _expr.initialize (omega_K, iopt); }
-  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) const {
+  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) {
     return _expr.initialize (gh,  iopt); }
 
   template<class Value>
@@ -447,7 +450,8 @@ public:
 	 ,result_hint>::result_type                     value_type;
   typedef typename scalar_traits<value_type>::type  	scalar_type;
   typedef typename  float_traits<value_type>::type 	float_type;
-  typedef space_basic<scalar_type,memory_type>		space_type; // TODO: deduce from Exprs
+  typedef space_basic<float_type,memory_type>           space_type;
+  typedef geo_basic  <float_type,memory_type>		geo_type;
   typedef typename details::bf_vf_tag<BinaryFunction,
 	typename Expr1::vf_tag_type,
 	typename Expr2::vf_tag_type>::type              vf_tag_type;
@@ -479,11 +483,11 @@ public:
   size_type n_derivative() const          { return std::min(_expr1.n_derivative(), _expr2.n_derivative()); }
 
 // mutable modifiers:
-  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) const {
+  void initialize (const geo_basic<float_type,memory_type>& omega_K, const integrate_option& iopt) {
     _expr1.initialize (omega_K, iopt);
     _expr2.initialize (omega_K, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) const {
+  void initialize (const band_basic<float_type,memory_type>& gh, const integrate_option& iopt) {
     _expr1.initialize (gh,  iopt);
     _expr2.initialize (gh,  iopt);
   }
