@@ -66,6 +66,9 @@ public:
   using value_type  = result_type;
   using scalar_type = typename scalar_traits<value_type>::type;
   using float_type  = typename  float_traits<scalar_type>::type;
+  using geo_type    = geo_basic<float_type,memory_type>;
+  using band_type   = band_basic<float_type,memory_type>;
+  using space_type  = space_basic<float_type,memory_type>;
   using self_type   = field_expr_v2_nonlinear_node_unary<UnaryFunction,Expr>;
 
 // alocators:
@@ -119,23 +122,35 @@ public:
 // accessors:
 
   static const space_constant::valued_type valued_hint = space_constant::valued_tag_traits<result_type>::value;
-  const Expr& expr() const { return _expr; }
+  const Expr&       expr()      const { return _expr; }
 
   space_constant::valued_type valued_tag() const {
     return details::generic_unary_traits<UnaryFunction>::valued_tag (_expr.valued_tag());
   }
 
+#ifdef TO_CLEAN
+// field_lazy interface:
+
+  const geo_type&   get_geo()   const { return _expr.get_geo(); }
+  const band_type&  get_band()  const { return _expr.get_band(); }
+  const space_type& get_space() const { return _expr.get_space(); }
+  bool is_on_band () const { return _expr.is_on_band(); }
+  void initialize (const geo_type& omega_K) { _expr.initialize (omega_K); }
+#endif // TO_CLEAN
+
 // initializators:
 
+  // field_lazy interface:
+	
   void initialize (
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   		{ _expr.initialize (pops, iopt); }
 
   void initialize (
     const space_basic<float_type,memory_type>&       Xh,
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   		{ _expr.initialize (Xh, pops, iopt); }
 
 // -------------------------
@@ -148,7 +163,7 @@ public:
       const self_type&                         obj,
       const geo_basic<float_type,M>&           omega_K,
       const geo_element&                       K,
-      Eigen::Matrix<Result,Eigen::Dynamic,1>&  value) const
+      Eigen::Matrix<Result,Eigen::Dynamic,1>&  value)
     {
       fatal_macro ("invalid type resolution: Result="<<typename_macro(Result)
           << ", Arg="<<typename_macro(Arg)
@@ -399,15 +414,20 @@ field_expr_v2_nonlinear_node_unary<UnaryFunction,Expr>::field_expr_v2_nonlinear_
 }
 
 template<class F, class Expr> struct is_field_expr_v2_nonlinear_arg  <field_expr_v2_nonlinear_node_unary<F,Expr>> : std::true_type {};
+//template<class F, class Expr> struct has_field_lazy_interface        <field_expr_v2_nonlinear_node_unary<F,Expr>> : std::true_type {};
 template<class F, class Expr> struct is_field_expr_affine_homogeneous<field_expr_v2_nonlinear_node_unary<F,Expr>, typename std::enable_if<
                                                                       field_expr_v2_nonlinear_node_unary<F,Expr>::is_affine_homogeneous::value>::type>: std::true_type {};
 
+
 } // namespace details
 // -------------------------------------------
 // 1.2. unary calls
 // -------------------------------------------
 // unary operators +- and std::math
 
+// ------------------------
+// standard unary operators
+// ------------------------
 #define _RHEOLEF_make_field_expr_v2_nonlinear_unary_operator(FUNCTION,FUNCTOR)	\
 template<class Expr>								\
 inline										\
@@ -415,6 +435,7 @@ typename									\
 std::enable_if<									\
        details::is_field_expr_v2_nonlinear_arg<Expr>::value			\
   && ! details::is_field_expr_v2_constant     <Expr>::value			\
+  && ! details::has_field_rdof_interface      <Expr>::value			\
  ,details::field_expr_v2_nonlinear_node_unary<					\
     FUNCTOR									\
    ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type \
@@ -426,13 +447,34 @@ FUNCTION (const Expr& expr)							\
   return details::field_expr_v2_nonlinear_node_unary <FUNCTOR,wrap_t> (FUNCTOR(), wrap_t(expr)); \
 }
 
+_RHEOLEF_make_field_expr_v2_nonlinear_unary_operator (operator+, details::unary_plus)
+_RHEOLEF_make_field_expr_v2_nonlinear_unary_operator (operator-, details::negate)
+#undef _RHEOLEF_make_field_expr_v2_nonlinear_unary_operator
+
+// ------------------------
+// std::cmath
+// ------------------------
+#define _RHEOLEF_make_field_expr_v2_nonlinear_unary_operator(FUNCTION,FUNCTOR)	\
+template<class Expr>								\
+inline										\
+typename									\
+std::enable_if<									\
+  (    details::is_field_expr_v2_nonlinear_arg<Expr>::value			\
+  ||   details::is_field<Expr>::value)						\
+  && ! details::is_field_expr_v2_constant     <Expr>::value			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    FUNCTOR									\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr& expr)							\
+{										\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type wrap_t;  \
+  return details::field_expr_v2_nonlinear_node_unary <FUNCTOR,wrap_t> (FUNCTOR(), wrap_t(expr)); \
+}
 #define _RHEOLEF_make_field_expr_v2_nonlinear_unary_function(FUNCTION)		\
         _RHEOLEF_make_field_expr_v2_nonlinear_unary_operator(FUNCTION, details::FUNCTION##_)
 
-// standard unary operators
-_RHEOLEF_make_field_expr_v2_nonlinear_unary_operator (operator+, details::unary_plus)
-_RHEOLEF_make_field_expr_v2_nonlinear_unary_operator (operator-, details::negate)
-// std::cmath
 _RHEOLEF_make_field_expr_v2_nonlinear_unary_function (cos)
 _RHEOLEF_make_field_expr_v2_nonlinear_unary_function (sin)
 _RHEOLEF_make_field_expr_v2_nonlinear_unary_function (tan)
@@ -584,7 +626,7 @@ public:
 
   void initialize (
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   {
     _expr1.initialize (pops, iopt);
     _expr2.initialize (pops, iopt);
@@ -592,7 +634,7 @@ public:
   void initialize (
     const space_basic<float_type,memory_type>&       Xh,
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   {
     _expr1.initialize (Xh, pops, iopt);
     _expr2.initialize (Xh, pops, iopt);
@@ -945,6 +987,7 @@ field_expr_v2_nonlinear_node_binary<BinaryFunction,Expr1,Expr2>::field_expr_v2_n
 }
 
 template<class F, class Expr1, class Expr2> struct is_field_expr_v2_nonlinear_arg  <field_expr_v2_nonlinear_node_binary<F,Expr1,Expr2>> : std::true_type {};
+//template<class F, class Expr1, class Expr2> struct has_field_lazy_interface        <field_expr_v2_nonlinear_node_binary<F,Expr1,Expr2>> : std::true_type {};
 template<class F, class Expr1, class Expr2> struct is_field_expr_affine_homogeneous<field_expr_v2_nonlinear_node_binary<F,Expr1,Expr2>, typename std::enable_if<
                                                                                     field_expr_v2_nonlinear_node_binary<F,Expr1,Expr2>::is_affine_homogeneous::value>::type>: std::true_type {};
 
@@ -975,7 +1018,7 @@ template<class F, class Expr1, class Expr2> struct is_field_expr_affine_homogene
 
     argument:
       c : constant, as scalar, point, tensor, ect
-      l : affine homogeneous expr argument: as field, field_indirect or field_expr_node::is_affine_homogeneous
+      l : affine homogeneous expr argument: as field, field_rdof_indirect or field_expr_node::is_affine_homogeneous
       n : function, functor or ! field_expr_node::is_affine_homogeneous
     result:
       C : constant : this combination is not implemented here
@@ -994,6 +1037,280 @@ template<class F, class Expr1, class Expr2> struct is_field_expr_affine_homogene
         2) one  arg  is a field_expr_v2_nonlinear or a function and the second argument is a constant
 */
 
+// -------------------------------------------
+// binary+-
+// -------------------------------------------
+// TODO: remove rdof+-rdof when rdof_binary is available 
+#define _RHEOLEF_make_field_expr_v2_nonlinear_binary(FUNCTION,FUNCTOR)	\
+template<class Expr1, class Expr2>						\
+inline										\
+typename									\
+std::enable_if<									\
+     details::is_field_expr_v2_nonlinear_arg<Expr1>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr2>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr1>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr2>::value			\
+ ,details::field_expr_v2_nonlinear_node_binary<					\
+    FUNCTOR									\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type	\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type 	\
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type wrap1_t; \
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type wrap2_t; \
+  return details::field_expr_v2_nonlinear_node_binary <FUNCTOR,wrap1_t,wrap2_t> \
+	(FUNCTOR(), wrap1_t(expr1), wrap2_t(expr2)); 				\
+}										\
+template<class Expr1, class Expr2>						\
+inline										\
+typename 									\
+std::enable_if<									\
+       details::is_field_expr_v2_constant     <Expr1>::value			\
+  &&   details::is_field_expr_v2_nonlinear_arg<Expr2>::value			\
+  && ! details::is_field_expr_v2_constant     <Expr2>::value			\
+  && !(details::has_field_rdof_interface      <Expr2>::value			\
+       && details::is_rheolef_arithmetic      <Expr1>::value)			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    details::binder_first<							\
+      FUNCTOR									\
+     ,typename details::field_promote_first_argument<				\
+        Expr1									\
+       ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type::value_type \
+      >::type									\
+    >										\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_promote_first_argument<			\
+        Expr1									\
+       ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type::value_type \
+      >::type									\
+      value_type;								\
+  typedef details::binder_first<FUNCTOR,value_type> fun_t;			\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type wrap2_t; \
+  return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap2_t>(fun_t(FUNCTOR(), expr1), wrap2_t(expr2)); \
+}										\
+template<class Expr1, class Expr2>						\
+inline										\
+typename 									\
+std::enable_if<									\
+     details::is_field_expr_v2_constant     <Expr2>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr1>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr1>::value			\
+  && !(details::has_field_rdof_interface    <Expr1>::value			\
+       && details::is_rheolef_arithmetic    <Expr2>::value)			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    details::binder_second<							\
+      FUNCTOR									\
+     ,typename details::field_promote_second_argument<				\
+        typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type::value_type \
+       ,Expr2									\
+      >::type									\
+    >										\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_promote_second_argument<			\
+        typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type::value_type \
+       ,Expr2									\
+      >::type									\
+      value_type;								\
+  typedef details::binder_second<FUNCTOR,value_type> fun_t;			\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type wrap1_t; \
+  return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap1_t>(fun_t(FUNCTOR(), expr2), wrap1_t(expr1)); \
+}
+
+_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator+, details::plus)
+_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator-, details::minus)
+#undef _RHEOLEF_make_field_expr_v2_nonlinear_binary
+
+// -------------------------------------------
+// binary*
+// -------------------------------------------
+#define _RHEOLEF_make_field_expr_v2_nonlinear_binary(FUNCTION,FUNCTOR)	\
+template<class Expr1, class Expr2>						\
+inline										\
+typename									\
+std::enable_if<									\
+     details::is_field_expr_v2_nonlinear_arg<Expr1>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr2>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr1>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr2>::value			\
+ ,details::field_expr_v2_nonlinear_node_binary<					\
+    FUNCTOR									\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type	\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type 	\
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type wrap1_t; \
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type wrap2_t; \
+  return details::field_expr_v2_nonlinear_node_binary <FUNCTOR,wrap1_t,wrap2_t> \
+	(FUNCTOR(), wrap1_t(expr1), wrap2_t(expr2)); 				\
+}										\
+template<class Expr1, class Expr2>						\
+inline										\
+typename 									\
+std::enable_if<									\
+     details::is_field_expr_v2_constant     <Expr1>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr2>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr2>::value			\
+  && !(details::has_field_rdof_interface    <Expr2>::value			\
+       && details::is_rheolef_arithmetic    <Expr1>::value)			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    details::binder_first<							\
+      FUNCTOR									\
+     ,typename details::field_promote_first_argument<				\
+        Expr1									\
+       ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type::value_type \
+      >::type									\
+    >										\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_promote_first_argument<			\
+        Expr1									\
+       ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type::value_type \
+      >::type									\
+      value_type;								\
+  typedef details::binder_first<FUNCTOR,value_type> fun_t;			\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type wrap2_t; \
+  return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap2_t>(fun_t(FUNCTOR(), expr1), wrap2_t(expr2)); \
+}										\
+template<class Expr1, class Expr2>						\
+inline										\
+typename 									\
+std::enable_if<									\
+     details::is_field_expr_v2_constant     <Expr2>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr1>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr1>::value			\
+  && !(details::has_field_rdof_interface    <Expr1>::value			\
+       && details::is_rheolef_arithmetic    <Expr2>::value)			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    details::binder_second<							\
+      FUNCTOR									\
+     ,typename details::field_promote_second_argument<				\
+        typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type::value_type \
+       ,Expr2									\
+      >::type									\
+    >										\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_promote_second_argument<			\
+        typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type::value_type \
+       ,Expr2									\
+      >::type									\
+      value_type;								\
+  typedef details::binder_second<FUNCTOR,value_type> fun_t;			\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type wrap1_t; \
+  return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap1_t>(fun_t(FUNCTOR(), expr2), wrap1_t(expr1)); \
+}
+_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator*, details::multiplies)
+#undef _RHEOLEF_make_field_expr_v2_nonlinear_binary
+
+// -------------------------------------------
+// binary/
+// -------------------------------------------
+#define _RHEOLEF_make_field_expr_v2_nonlinear_binary(FUNCTION,FUNCTOR)	\
+template<class Expr1, class Expr2>						\
+inline										\
+typename									\
+std::enable_if<									\
+     details::is_field_expr_v2_nonlinear_arg<Expr1>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr2>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr1>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr2>::value			\
+ ,details::field_expr_v2_nonlinear_node_binary<					\
+    FUNCTOR									\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type	\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type 	\
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type wrap1_t; \
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type wrap2_t; \
+  return details::field_expr_v2_nonlinear_node_binary <FUNCTOR,wrap1_t,wrap2_t> \
+	(FUNCTOR(), wrap1_t(expr1), wrap2_t(expr2)); 				\
+}										\
+template<class Expr1, class Expr2>						\
+inline										\
+typename 									\
+std::enable_if<									\
+     details::is_field_expr_v2_constant     <Expr1>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr2>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr2>::value			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    details::binder_first<							\
+      FUNCTOR									\
+     ,typename details::field_promote_first_argument<				\
+        Expr1									\
+       ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type::value_type \
+      >::type									\
+    >										\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_promote_first_argument<			\
+        Expr1									\
+       ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type::value_type \
+      >::type									\
+      value_type;								\
+  typedef details::binder_first<FUNCTOR,value_type> fun_t;			\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr2>::type wrap2_t; \
+  return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap2_t>(fun_t(FUNCTOR(), expr1), wrap2_t(expr2)); \
+}										\
+template<class Expr1, class Expr2>						\
+inline										\
+typename 									\
+std::enable_if<									\
+     details::is_field_expr_v2_constant     <Expr2>::value			\
+  && details::is_field_expr_v2_nonlinear_arg<Expr1>::value			\
+  && ! details::is_field_expr_v2_constant   <Expr1>::value			\
+  && !(details::has_field_rdof_interface    <Expr1>::value			\
+       && details::is_rheolef_arithmetic    <Expr2>::value)			\
+ ,details::field_expr_v2_nonlinear_node_unary<					\
+    details::binder_second<							\
+      FUNCTOR									\
+     ,typename details::field_promote_second_argument<				\
+        typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type::value_type \
+       ,Expr2									\
+      >::type									\
+    >										\
+   ,typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type \
+  >										\
+>::type										\
+FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
+{										\
+  typedef typename details::field_promote_second_argument<			\
+        typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type::value_type \
+       ,Expr2									\
+      >::type									\
+      value_type;								\
+  typedef details::binder_second<FUNCTOR,value_type> fun_t;			\
+  typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr1>::type wrap1_t; \
+  return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap1_t>(fun_t(FUNCTOR(), expr2), wrap1_t(expr1)); \
+}
+_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator/, details::divides)
+#undef _RHEOLEF_make_field_expr_v2_nonlinear_binary
+
+// -------------------------------------------
+// std::maths
+// -------------------------------------------
 #define _RHEOLEF_make_field_expr_v2_nonlinear_binary(FUNCTION,FUNCTOR)	\
 template<class Expr1, class Expr2>						\
 inline										\
@@ -1075,15 +1392,6 @@ FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
   return details::field_expr_v2_nonlinear_node_unary<fun_t,wrap1_t>(fun_t(FUNCTOR(), expr2), wrap1_t(expr1)); \
 }
 
-_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator+, details::plus)
-_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator-, details::minus)
-_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator*, details::multiplies)
-_RHEOLEF_make_field_expr_v2_nonlinear_binary (operator/, details::divides)
-
-// -------------------------------------------
-// std::maths
-// -------------------------------------------
-
 #define _RHEOLEF_make_field_expr_v2_nonlinear_binary_function(FUNCTION)				\
         _RHEOLEF_make_field_expr_v2_nonlinear_binary (FUNCTION, details::FUNCTION##_) 								\
 
@@ -1094,6 +1402,7 @@ _RHEOLEF_make_field_expr_v2_nonlinear_binary_function (min)
 _RHEOLEF_make_field_expr_v2_nonlinear_binary_function (max)
 _RHEOLEF_make_field_expr_v2_nonlinear_binary_function (dot)
 _RHEOLEF_make_field_expr_v2_nonlinear_binary_function (ddot)
+_RHEOLEF_make_field_expr_v2_nonlinear_binary_function (dddot)
 
 #undef _RHEOLEF_make_field_expr_v2_nonlinear_binary_function
 #undef _RHEOLEF_make_field_expr_v2_nonlinear_binary
