@@ -56,7 +56,7 @@ template<class T>
 void
 field_expr_v2_nonlinear_terminal_function_base_rep<T>::initialize (
   const piola_on_pointset<float_type>&              pops,
-  const integrate_option&                           iopt) const
+  const integrate_option&                           iopt)
 {
   _pops = pops;
 }
@@ -65,7 +65,7 @@ void
 field_expr_v2_nonlinear_terminal_function_base_rep<T>::initialize (
   const space_basic<float_type,memory_type>& Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
   _pops = pops;
 }
@@ -130,7 +130,7 @@ template<class T>
 void
 field_expr_v2_nonlinear_terminal_function_rep<normal_pseudo_function<T> >::initialize (
   const piola_on_pointset<float_type>&              pops,
-  const integrate_option&                           iopt) const
+  const integrate_option&                           iopt)
 {
   base::initialize (pops, iopt);
   _is_on_interface          = iopt._is_on_interface;
@@ -141,7 +141,7 @@ void
 field_expr_v2_nonlinear_terminal_function_rep<normal_pseudo_function<T> >::initialize (
   const space_basic<float_type,memory_type>& Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
   base::initialize (Xh, pops, iopt);
   _is_on_interface          = iopt._is_on_interface;
@@ -208,7 +208,7 @@ template<class T>
 void
 field_expr_v2_nonlinear_terminal_function_rep<h_local_pseudo_function<T> >::initialize (
   const piola_on_pointset<float_type>&              pops,
-  const integrate_option&                           iopt) const
+  const integrate_option&                           iopt)
 {
   base::initialize (pops, iopt);
 }
@@ -217,7 +217,7 @@ void
 field_expr_v2_nonlinear_terminal_function_rep<h_local_pseudo_function<T> >::initialize (
   const space_basic<float_type,memory_type>& Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
   base::initialize (Xh, pops, iopt);
 }
@@ -243,33 +243,33 @@ field_expr_v2_nonlinear_terminal_function_rep<h_local_pseudo_function<T> >::eval
       value[loc_inod] = pow (abs(det_DF_i)/meas_hat_K, 1./K_map_d);
       trace_macro("h_local("<<omega_K.name()<<",K="<<K.name()<<K.dis_ie()<<")="<< value[loc_inod]);
     }
+    return;
+  }
+  // special case: d == 0 i.e. an "interface" between two edges in 1D
+  // then h_local = average of two edge length
+  size_type L_dis_ie[2] = {K.master(0), K.master(1)};
+  size_t n = (L_dis_ie[0] == std::numeric_limits<size_type>::max()) ? 0 :
+             (L_dis_ie[1] == std::numeric_limits<size_type>::max()) ? 1 : 2;
+  if (n == 0) {
+    // special 0d meshes:
+    //   dis_nelt_1d=0: special 0d mesh, e.g. omega["sides"] when omega is 1d
+    //   n=0:           isolated point(s) in a 0D mesh
+    // => h_local=1 by default
+    value.fill (result_type(1));
+    trace_macro("h_local("<<omega_K.name()<<",K="<<K.name()<<K.dis_ie()<<")=1");
   } else {
-    // special case: d == 0 i.e. an "interface" between two edges in 1D
-    // then h_local = average of two edge length
-    size_type L_dis_ie[2] = {K.master(0), K.master(1)};
-    size_t n = (L_dis_ie[0] == std::numeric_limits<size_type>::max()) ? 0 :
-               (L_dis_ie[1] == std::numeric_limits<size_type>::max()) ? 1 : 2;
-    if (n == 0) {
-      // special 0d meshes:
-      //   dis_nelt_1d=0: special 0d mesh, e.g. omega["sides"] when omega is 1d
-      //   n=0:           isolated point(s) in a 0D mesh
-      // => h_local=1 by default
-      value.fill (result_type(1));
-      trace_macro("h_local("<<omega_K.name()<<",K="<<K.name()<<K.dis_ie()<<")=1");
-    } else {
-      size_t dis_nelt_1d = omega_K.sizes().ownership_by_dimension[1].dis_size();
-      check_macro (dis_nelt_1d != 0, "h_local: invalid \""<<omega_K.name()<<"\" mesh with missing 1D connectivity");
-      size_t L_map_d = 1;
-      Float h_loc = 0;
-      for (size_type i = 0; i < n; ++i) {
-        const geo_element& Li = omega_K.dis_get_geo_element (L_map_d, L_dis_ie[i]);
-        const point_basic<float_type>& x0 = omega_K.dis_node (Li[0]);
-        const point_basic<float_type>& x1 = omega_K.dis_node (Li[1]);
-        h_loc += norm (x1-x0)/n;
-      }
-      value.fill (result_type(h_loc));
-      trace_macro("h_local("<<omega_K.name()<<",K="<<K.name()<<K.dis_ie()<<")="<< h_loc);
+    size_t dis_nelt_1d = omega_K.sizes().ownership_by_dimension[1].dis_size();
+    check_macro (dis_nelt_1d != 0, "h_local: invalid \""<<omega_K.name()<<"\" mesh with missing 1D connectivity");
+    size_t L_map_d = 1;
+    Float h_loc = 0;
+    for (size_type i = 0; i < n; ++i) {
+      const geo_element& Li = omega_K.dis_get_geo_element (L_map_d, L_dis_ie[i]);
+      const point_basic<float_type>& x0 = omega_K.dis_node (Li[0]);
+      const point_basic<float_type>& x1 = omega_K.dis_node (Li[1]);
+      h_loc += norm (x1-x0)/n;
     }
+    value.fill (result_type(h_loc));
+    trace_macro("h_local("<<omega_K.name()<<",K="<<K.name()<<K.dis_ie()<<")="<< h_loc);
   }
 }
 template<class T>
@@ -301,7 +301,7 @@ template<class T>
 void
 field_expr_v2_nonlinear_terminal_function_rep<penalty_pseudo_function<T> >::initialize (
   const piola_on_pointset<float_type>&              pops,
-  const integrate_option&                           iopt) const
+  const integrate_option&                           iopt)
 {
   base::initialize (pops, iopt);
 }
@@ -310,7 +310,7 @@ void
 field_expr_v2_nonlinear_terminal_function_rep<penalty_pseudo_function<T> >::initialize (
   const space_basic<float_type,memory_type>& Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
   base::initialize (Xh, pops, iopt);
 }
@@ -401,7 +401,7 @@ template<class T, class M, details::differentiate_option::type Diff>
 void
 field_expr_v2_nonlinear_terminal_field_rep<T,M,Diff>::initialize (
     const piola_on_pointset<T>&    pops,
-    const integrate_option&        iopt) const
+    const integrate_option&        iopt)
 {
     _uh.dis_dof_update();
     _u_test.initialize (pops, iopt);
@@ -411,7 +411,7 @@ void
 field_expr_v2_nonlinear_terminal_field_rep<T,M,Diff>::initialize (
   const space_basic<T,M>&                    Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
     check_macro (_uh.get_geo().get_background_geo().name() == Xh.get_geo().get_background_geo().name(),
 	"incompatible field on " << _uh.get_geo().get_background_geo().name() << " for evaluation on " << Xh.get_geo().get_background_geo().name());
@@ -499,7 +499,7 @@ template<class T, class M>
 void
 field_expr_v2_nonlinear_terminal_field_dg_rep<T,M>::initialize (
   const piola_on_pointset<float_type>&              pops,
-  const integrate_option&                           iopt) const
+  const integrate_option&                           iopt)
 {
   _expr0.initialize (pops, iopt);
   _expr1.initialize (pops, iopt);
@@ -509,7 +509,7 @@ void
 field_expr_v2_nonlinear_terminal_field_dg_rep<T,M>::initialize (
   const space_basic<float_type,memory_type>& Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
   _expr0.initialize (Xh, pops, iopt);
   _expr1.initialize (Xh, pops, iopt);
@@ -535,12 +535,11 @@ field_expr_v2_nonlinear_terminal_field_dg_rep<T,M>::evaluate (
   L_dis_ie1 = K.master(1);
   if (L_dis_ie1 == std::numeric_limits<size_type>::max()) {
     // K is a boundary side
-    // average (i.e. _c0==0.5): fix it on the boundary where c0=1 : average(v)=v on the boundary
-    Float c0 = (_c0 != 0.5) ? _c0 : 1;
+    // jump(v)=average(v)=inner(v)=outer(v)=v on the boundary
     // TODO: DVT_EIGEN_BLAS2 : pb when Value=point
     for (size_type loc_inod = 0, loc_nnod = value.rows(); loc_inod < loc_nnod; ++loc_inod) {
     for (size_type loc_jdof = 0, loc_ndof = value.cols(); loc_jdof < loc_ndof; ++loc_jdof) {
-      value(loc_inod,loc_jdof) = c0*value(loc_inod,loc_jdof);
+      value(loc_inod,loc_jdof) = value(loc_inod,loc_jdof);
     }}
   } else {
     // K is an internal side
@@ -560,7 +559,7 @@ field_expr_v2_nonlinear_terminal_field_dg_rep<T,M>::evaluate (
 template<class T, class M, class Value>
 void
 interpolate_pass2_valued (
-    const field_basic<T,M>&                uh,
+    const field_basic<T,M>&       uh,
     const disarray<point_basic<T>,M>&      x,
     const disarray<index_set,M>&           ie2dis_ix, // K -> list of ix
     const disarray<point_basic<T>,M>&      hat_y,     // ix -> hat_y
@@ -570,7 +569,7 @@ template<class T, class M>
 void
 field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::initialize (
   const piola_on_pointset<float_type>&              pops,
-  const integrate_option&                           iopt) const
+  const integrate_option&                           iopt)
 {
   // handle the case when omega (destination) is different from _X.get_displacement.get_geo (origin)
   // as in mesh adaptation loops
@@ -598,7 +597,7 @@ void
 field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::initialize ( 
   const space_basic<float_type,memory_type>& Xh,
   const piola_on_pointset<float_type>&       pops,
-  const integrate_option&                    iopt) const
+  const integrate_option&                    iopt)
 {
    fatal_macro ("characteristic: not supported with interpolate (HINT: use integrate with Gauss-Lobatto quadrature)");
 }
