@@ -93,10 +93,10 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _expr.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr.initialize (gh, pops, iopt);
   }
   // -------------
@@ -375,11 +375,11 @@ public:
 // mutable modifiers:
 
   // TODO: check that expr1 & expr2 have the same get_vf_space()
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _expr1.initialize (pops, iopt);
     _expr2.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr1.initialize (gh, pops, iopt);
     _expr2.initialize (gh, pops, iopt);
   }
@@ -974,11 +974,11 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _nl_expr.initialize (pops, iopt);
     _vf_expr.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _nl_expr.initialize (    pops, iopt);
     _vf_expr.initialize (gh, pops, iopt);
   }
@@ -1444,6 +1444,7 @@ _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides
 _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_right (operator/, details::divides)
 _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides       (dot,       details::dot_)
 _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides       (ddot,      details::ddot_)
+_RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides       (dddot,     details::dddot_)
 #undef _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_left
 #undef _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_right
 #undef _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides
@@ -1520,6 +1521,7 @@ _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_const
 _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_constant_right (operator/, details::divides)
 _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_constant       (dot,       details::dot_)
 _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_constant       (ddot,      details::ddot_)
+_RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_constant       (dddot,     details::dddot_)
 
 #undef _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_constant_right
 #undef _RHEOLEF_make_field_expr_v2_variational_binary_operator_multiplies_divides_constant_left
