@@ -115,14 +115,14 @@ public:
 
   void initialize (
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   { 
     _expr.initialize (pops, iopt);
   }
   void initialize (
     const band_basic<float_type,memory_type>&        gh,
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   {  
     _expr.initialize (gh, pops, iopt); 
   }
@@ -310,10 +310,10 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _expr.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr.initialize (gh, pops, iopt); 
   }
   template<class Result>
@@ -458,10 +458,10 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _expr.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr.initialize (gh, pops, iopt); 
   }
   template<class Result>
@@ -777,31 +777,21 @@ class field_expr_v2_variational_dg {
 public:
 // typedefs:
 
-  typedef typename Expr::size_type            size_type;
-  typedef typename Expr::memory_type          memory_type;
-  typedef typename Expr::value_type           value_type;
-  typedef typename Expr::scalar_type          scalar_type;
-  typedef typename Expr::float_type           float_type;
-  typedef typename Expr::space_type           space_type;
-  typedef typename Expr::vf_tag_type          vf_tag_type;
-  typedef typename details::dual_vf_tag<vf_tag_type>::type
-                                              vf_dual_tag_type;
-  typedef field_expr_v2_variational_dg<Expr>  self_type;
-  typedef field_expr_v2_variational_dg<typename Expr::dual_self_type>  
-                                              dual_self_type;
+  using size_type        = typename Expr::size_type;
+  using memory_type      = typename Expr::memory_type;
+  using value_type       = typename Expr::value_type;
+  using scalar_type      = typename Expr::scalar_type;
+  using float_type       = typename Expr::float_type;
+  using space_type       = typename Expr::space_type;
+  using vf_tag_type      = typename Expr::vf_tag_type;
+  using vf_dual_tag_type = typename details::dual_vf_tag<vf_tag_type>::type;
+  using self_type        = field_expr_v2_variational_dg<Expr>;
+  using dual_self_type   = field_expr_v2_variational_dg<typename Expr::dual_self_type>  ;
+  using is_elementwise   = std::false_type; // assembles two adjacents elements
 
 // alocators:
 
-  field_expr_v2_variational_dg (const Expr& expr, const float_type& c0, const float_type& c1) 
-    : _expr0(expr), 
-      _expr1(expr),
-      _c0(c0), 
-      _c1(c1),
-      _tilde0_L0(),
-      _tilde1_L1(),
-      _bgd_omega()
-   {
-   }
+  field_expr_v2_variational_dg (const Expr& expr, const float_type& c0, const float_type& c1);
 
 // accessors:
 
@@ -810,14 +800,12 @@ public:
   space_constant::valued_type valued_tag() const { return _expr0.valued_tag(); } 
   size_type n_derivative() const { return _expr0.n_derivative(); }
 
-// mutable modifiers:
-
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {
     _expr0.initialize (pops, iopt);
     _expr1.initialize (pops, iopt);
     _bgd_omega = get_vf_space().get_constitution().get_background_geo();
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr0.initialize (gh, pops, iopt);
     _expr1.initialize (gh, pops, iopt);
     fatal_macro ("unsupported discontinuous Galerkin on a band"); // how to define background mesh _bgd_omega ?
@@ -835,7 +823,6 @@ public:
 	<< " for jump or average operator (HINT: omit jump or average)");
     _expr0.template valued_check<Result>();
   }
-
 protected:
 // data:
   mutable Expr                              _expr0;
@@ -846,7 +833,25 @@ protected:
   mutable reference_element                 _tilde1_L1;
   mutable geo_basic<float_type,memory_type> _bgd_omega;
 };
+// concept:
 template<class Expr> struct is_field_expr_v2_variational_arg    <field_expr_v2_variational_dg<Expr> > : std::true_type {};
+ 
+// allocator:
+template<class Expr>
+inline
+field_expr_v2_variational_dg<Expr>::field_expr_v2_variational_dg (
+  const Expr&       expr,
+  const float_type& c0,
+  const float_type& c1) 
+: _expr0(expr), 
+  _expr1(expr),
+  _c0(c0), 
+  _c1(c1),
+  _tilde0_L0(),
+  _tilde1_L1(),
+  _bgd_omega()
+{
+}
 // ---------------------------------------------------------------------------
 // 5.2. evaluate
 // ---------------------------------------------------------------------------
@@ -873,10 +878,8 @@ trace_macro ("evaluate_dg: "<<K.name()<<K.dis_ie()<<"...")
   if (L_dis_ie1 == std::numeric_limits<size_type>::max()) {
     // K is a boundary side
     bool do_local_component_assembly = true;
+    // average(v)=jump(v)=inner(v)=outer(v)=v on the boundary
     _expr0.evaluate_on_side (omega_K, L0, sid0, value, do_local_component_assembly);
-    // outer(v) i.e. when c0==0 => fix it since outer(v)=0 on the boundary
-    // otherwise: average(v)=jump(v)=inner(v)=v on the boundary : no changes
-    if (_c0 == 0) { value.fill (Result()); }
   } else {
     // K is an internal side
     const geo_element& L1 = _bgd_omega.dis_get_geo_element (L_map_d, L_dis_ie1);
