@@ -26,7 +26,7 @@
 // date: 16 sept 2011
 //
 # include "rheolef/field.h"
-# include "rheolef/field_indirect.h"
+# include "rheolef/field_wdof_indirect.h"
 # include "rheolef/field_evaluate.h"
 # include "rheolef/piola_util.h"
 # include "rheolef/rheostream.h"
@@ -196,7 +196,7 @@ visu_gnuplot_scalar (odiststream& ods, const field_basic<T,sequential>& uh)
     subdivide = std::max(omega.order(), subdivide);
     subdivide = std::max(b.degree (), subdivide);
   }
-  basis_basic<T> subdivide_pointset ("P"+itos(subdivide));
+  basis_basic<T> subdivide_pointset ("P"+std::to_string(subdivide));
   piola_on_pointset<T> pops; pops.initialize (omega.get_piola_basis(), subdivide_pointset, integrate_option());
   fem_on_pointset<T>   fops; fops.initialize (b, pops);
 
@@ -428,7 +428,7 @@ visu_gnuplot_vector (odiststream& ods, const field_basic<T,sequential>& uh)
   size_type d     = omega.dimension();
   T diam_omega = norm (omega.xmax() - omega.xmin()); // characteristic length in omega
   T h_moy = diam_omega/pow(n_elt,1./d);
-  space_basic<T,sequential> Xh (uh.get_geo(), "P"+itos(uh.get_space().degree()));
+  space_basic<T,sequential> Xh (uh.get_geo(), "P"+std::to_string(uh.get_space().degree()));
   field_basic<T,sequential> norm_uh = interpolate(Xh, norm(uh));
   T norm_max_uh = norm_uh.max_abs();      // get max vector length
   if (norm_max_uh + 1 == 1) norm_max_uh = 1;
