@@ -111,10 +111,10 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _expr.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr.initialize (gh, pops, iopt);
   }
   template<class Result>
@@ -236,11 +236,11 @@ public:
 // mutable modifiers:
 
   // TODO: at init, check that exp1 & expr2 has the same test & trial spaces
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _expr1.initialize (pops, iopt);
     _expr2.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _expr1.initialize (gh, pops, iopt);
     _expr2.initialize (gh, pops, iopt);
   }
@@ -413,7 +413,7 @@ public:
 
   void initialize (
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   {
     _expr1.initialize (pops, iopt);
     _expr2.initialize (pops, iopt);
@@ -421,7 +421,7 @@ public:
   void initialize (
     const band_basic<float_type,memory_type>&        gh,
     const piola_on_pointset<float_type>&             pops,
-    const integrate_option&                          iopt) const
+    const integrate_option&                          iopt)
   {  
     _expr1.initialize (gh, pops, iopt);
     _expr2.initialize (gh, pops, iopt);
@@ -438,7 +438,7 @@ public:
       // expr1 is trial and expr2 is test
       Eigen::Matrix<Arg2,Eigen::Dynamic,Eigen::Dynamic> v_test;  _expr2.evaluate (omega_K, K, v_test);
       Eigen::Matrix<Arg1,Eigen::Dynamic,Eigen::Dynamic> u_trial; _expr1.evaluate (omega_K, K, u_trial);
-      check_macro(u_trial.rows() == v_test.rows(), "invalid sizes u_trial("
+      check_macro(u_trial.rows() == v_test.rows(), "mult: invalid sizes u_trial("
         <<u_trial.rows()<<","<<u_trial.cols() <<") and v_test("
         <<v_test.rows() <<","<<v_test.cols()<<")");
       eig_idx_t nq = u_trial.rows();
@@ -650,6 +650,7 @@ FUNCTION (const Expr1& expr1, const Expr2& expr2)				\
 _RHEOLEF_form_expr_v2_variational_binary_field (operator*, details::multiplies)
 _RHEOLEF_form_expr_v2_variational_binary_field (dot,       details::dot_)
 _RHEOLEF_form_expr_v2_variational_binary_field (ddot,      details::ddot_)
+_RHEOLEF_form_expr_v2_variational_binary_field (dddot,     details::dddot_)
 
 #undef _RHEOLEF_form_expr_v2_variational_binary_field 
 
@@ -713,11 +714,11 @@ public:
 
 // mutable modifiers:
 
-  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const { 
+  void initialize (const piola_on_pointset<float_type>& pops, const integrate_option& iopt) { 
     _nl_expr.initialize (pops, iopt);
     _vf_expr.initialize (pops, iopt);
   }
-  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) const {  
+  void initialize (const band_basic<float_type,memory_type>& gh, const piola_on_pointset<float_type>& pops, const integrate_option& iopt) {  
     _nl_expr.initialize (    pops, iopt);
     _vf_expr.initialize (gh, pops, iopt);
   }
@@ -840,6 +841,7 @@ _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides
 _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_right (operator/, details::divides)
 _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides       (dot,       details::dot_)
 _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides       (ddot,      details::ddot_)
+_RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides       (dddot,     details::dddot_)
 #undef _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_left
 #undef _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_right
 #undef _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides
@@ -916,6 +918,7 @@ _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_consta
 _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_constant_right (operator/, details::divides)
 _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_constant       (dot,       details::dot_)
 _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_constant       (ddot,      details::ddot_)
+_RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_constant       (dddot,     details::dddot_)
 
 #undef _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_constant_right
 #undef _RHEOLEF_make_form_expr_v2_variational_binary_operator_multiplies_divides_constant_left
