@@ -119,14 +119,14 @@ to a mesh container:
                 geo_domain_rep<T,M>          : data + methods for compacted geometry on domain
 */
 
-#include "rheolef/geo_element.h"
-#include "rheolef/disarray.h"
+#include "rheolef/iorheo.h"
+#include "rheolef/diststream.h"
+#include "rheolef/linalg.h"
+#include "rheolef/basis.h"
 #include "rheolef/hack_array.h"
 #include "rheolef/geo_size.h"
-#include "rheolef/point.h"
 #include "rheolef/domain_indirect.h"
 #include "rheolef/geo_header.h"
-#include "rheolef/basis.h"
 #include "rheolef/space_constant.h"
 #include "rheolef/geo_locate.h"
 #include "rheolef/geo_trace_ray_boundary.h"
@@ -1653,6 +1653,7 @@ operator<< (odiststream& ops, const geo_basic<T,M>& omega)
 
 #ifdef _RHEOLEF_GEO_DEMO_TST_CC
 // demo for the geo class documentation
+#include "rheolef/environment.h"
 using namespace rheolef;
 using namespace std;
 int main(int argc, char**argv) {
