@@ -382,10 +382,15 @@ geo_locate_rep<T,M,D>::dis_locate (
   const point_basic<T>&     x,
   size_type                 dis_ie_guest) const
 {
+  // mpi::reduce with std::minimum handles unsigned=size_t as signed=long
+  // so use here long to reduce, otherwise leads to a bug
+  using signed_size_type = long; 
+  const signed_size_type signed_large = -1;
   size_type dis_ie = seq_locate (omega, x, dis_ie_guest);
 #ifdef _RHEOLEF_HAVE_MPI
   if (omega.comm().size() > 1 && is_distributed<M>::value) {
-    dis_ie = mpi::all_reduce (omega.comm(), dis_ie, mpi::minimum<size_type>());
+    // fix for numeric_limits<size_t> == -1 with long int
+    dis_ie = mpi::all_reduce (omega.comm(), signed_size_type(dis_ie), mpi::maximum<signed_size_type>());
   }
 #endif // _RHEOLEF_HAVE_MPI
   return dis_ie;
@@ -439,9 +444,12 @@ geo_rep<T,distributed>::locate (
 	// dis_ie(ix) can contains a guest for x in K=omega[dis_ie(ix)]
   bool do_check) const
 {
-trace_macro ("locate...");
-  const size_type large = std::numeric_limits<size_type>::max();
-  const T         infty = std::numeric_limits<T>::max();
+  // mpi::reduce with std::minimum handles unsigned=size_t as signed=long
+  // so use here long to reduce, otherwise leads to a bug
+  using signed_size_type = long;
+  const signed_size_type signed_large = -1;
+  const        size_type        large = std::numeric_limits<size_type>::max();
+  const T                       infty = std::numeric_limits<T>::max();
   // 1) scan x and locate into the local mesh partition ; list when failed
   distributor ownership = x.ownership();
   if (dis_ie.ownership() != ownership) dis_ie.resize (ownership);
@@ -480,7 +488,7 @@ trace_macro ("locate done(1)");
         id_pt_minimum<T>());
 
   // 3) run the locator on all failed points ON ALL PROCS, skipping local queries (already failed)
-  std::vector<size_type> massive_result (fld_dis_size, large);
+  std::vector<signed_size_type> massive_result (fld_dis_size, signed_large);
   // 3a) range [0:first[
   for (size_type fld_dis_i = 0; fld_dis_i < first_fld_dis_i; ++fld_dis_i) {
     massive_result [fld_dis_i] = base::_locator.seq_locate (*this, massive_query[fld_dis_i].second);
@@ -490,13 +498,13 @@ trace_macro ("locate done(1)");
     massive_result [fld_dis_i] = base::_locator.seq_locate (*this, massive_query[fld_dis_i].second);
   }
   // 4) send & merge the results to all
-  std::vector<size_type> massive_merged (fld_dis_size, large);
+  std::vector<signed_size_type> massive_merged (fld_dis_size, signed_large);
   mpi::all_reduce (
         comm,
         massive_result.begin().operator->(),
         massive_result.size(),
         massive_merged.begin().operator->(),
-        mpi::minimum<size_type>());
+        mpi::maximum<signed_size_type>());
 
   // 5) store the local range into the distributed disarray dis_ie:
   for (size_type fld_dis_i = first_fld_dis_i; fld_dis_i < last_fld_dis_i; ++fld_dis_i, ++iter) {
