@@ -330,7 +330,7 @@ geo_put_vtk_old (
   // 4) put cells
   //
   string opt_d = my_numb.is_discontinuous() ? "d" : "";
-  string cell_numb_name = "P"+itos(my_numb.degree())+opt_d;
+  string cell_numb_name = "P"+std::to_string(my_numb.degree())+opt_d;
   basis_basic<T> cell_numb (cell_numb_name); // my_numb could be vector-valued
   vtk << "CELLS " << ncell << " " << ndata << endl;
   for (size_type ie = 0, ne = omega.size(); ie < ne; ie++) {
@@ -476,7 +476,7 @@ geo_put_vtk_high (
   // 4) put cells
   //
   string opt_d = my_numb.is_discontinuous() ? "d" : "";
-  string cell_numb_name = "P"+itos(my_numb.degree())+opt_d;
+  string cell_numb_name = "P"+std::to_string(my_numb.degree())+opt_d;
   basis_basic<T> cell_numb (cell_numb_name); // my_numb could be vector-valued
   vtk << "CELLS " << ncell << " " << ndata << endl;
   for (size_type ie = 0, ne = omega.size(subgeo_dim); ie < ne; ie++) {
