@@ -322,7 +322,7 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   ofstream gdat;
   if (verbose) clog << "! file \"" << filename << "\" created." << endl;
 
-  basis_basic<T> subdivide_pointset ("P"+itos(subdivide));
+  basis_basic<T> subdivide_pointset ("P"+std::to_string(subdivide));
   basis_on_pointset<T> pointset (subdivide_pointset, omega.get_piola_basis());
 
   plot << "#!gnuplot" << endl
