@@ -151,7 +151,7 @@ Implementation
 // Implementation note
 // -------------------
 // SUMMARY:
-// 1. numeric integration
+// 1. scalar-result integration
 //    1.1. general integration of a nonlinear expression
 //    1.2. measure of the domain
 //    1.3. when the valued result type is undetermined
@@ -164,6 +164,14 @@ Implementation
 //    3.2. missing domain
 //    3.3. subdomain by its name
 // 4. variational integration: on a band
+// 5. lazy-field-result integration of a variational expression
+//    5.1. general call
+//    5.2. missing domain
+//    5.3. subdomain by its name
+// 6. lazy-form-result integration of a variational expression
+//    6.1. general call
+//    6.2. missing domain
+//    6.3. subdomain by its name
 //
 #include "rheolef/field_expr.h"
 #include "rheolef/field_expr_variational.h"
@@ -174,13 +182,14 @@ Implementation
 #include "rheolef/form_vf_assembly.h"
 #include "rheolef/form_expr_quadrature.h"
 #include "rheolef/field_expr_quadrature.h"
+#include "rheolef/form_lazy_expr.h"
 
 #include "rheolef/functor.h" // used to convert functions to functors
 
 namespace rheolef { 
 
 // ---------------------------------------------------
-// 1. numeric integration
+// 1. scalar-result integration
 // ---------------------------------------------------
 // 1.1. general integration of a nonlinear expression
 // ---------------------------------------------------
@@ -267,7 +276,7 @@ integrate (
   const integrate_option& iopt = integrate_option())
 {
   field_basic<T,M> lh;
-  lh.assembly (domain, expr, iopt);
+  lh.do_integrate (domain, expr, iopt);
   return lh;
 }
 template <class T, class M, class Expr>
@@ -304,7 +313,7 @@ integrate (
   field_basic <typename Expr::scalar_type, typename Expr::memory_type> lh;
   const geo_basic <typename Expr::scalar_type, typename Expr::memory_type>&
     dom = expr.get_vf_space().get_constitution().get_geo();
-  lh.assembly (dom, expr, iopt);
+  lh.do_integrate (dom, expr, iopt);
   return lh;
 }
 template <class Expr>
@@ -341,7 +350,7 @@ integrate (
   field_basic <typename Expr::scalar_type, typename Expr::memory_type> lh;
   const geo_basic <typename Expr::scalar_type, typename Expr::memory_type>&
     dom = expr.get_vf_space().get_constitution().get_geo() [domname];
-  lh.assembly (dom, expr, iopt);
+  lh.do_integrate (dom, expr, iopt);
   return lh;
 }
 template <class Expr>
@@ -379,7 +388,7 @@ integrate (
   const integrate_option& fopt = integrate_option())
 {
   form_basic<T,M> a;
-  a.assembly (domain, expr, fopt);
+  a.do_integrate (domain, expr, fopt);
   return a;
 }
 template <class T, class M, class Expr>
@@ -435,7 +444,7 @@ integrate (
 	<< "\" and \"" << dom_test.name() << "\"");
   }
   trace_macro ("dom_trial="<<dom_trial.name()<<" dom_test="<<dom_test.name()<<" -> dom="<<dom.name());
-  a.assembly (dom, expr, fopt);
+  a.do_integrate (dom, expr, fopt);
   return a;
 }
 template <class Expr>
@@ -472,7 +481,7 @@ integrate (
   form_basic <typename Expr::scalar_type, typename Expr::memory_type> a;
   const geo_basic <typename Expr::scalar_type, typename Expr::memory_type>&
     dom = expr.get_trial_space().get_constitution().get_background_geo()[domname];
-  a.assembly (dom, expr, fopt);
+  a.do_integrate (dom, expr, fopt);
   return a;
 }
 template <class Expr>
@@ -508,7 +517,7 @@ integrate (
   const integrate_option& iopt = integrate_option())
 {
   field_basic <typename Expr::scalar_type, typename Expr::memory_type> lh;
-  lh.assembly (gh, expr, iopt);
+  lh.do_integrate (gh, expr, iopt);
   return lh;
 }
 template <class T, class M, class Expr>
@@ -542,7 +551,7 @@ integrate (
   const integrate_option& fopt = integrate_option())
 {
   form_basic <typename Expr::scalar_type, typename Expr::memory_type> a;
-  a.assembly (gh, expr, fopt);
+  a.do_integrate (gh, expr, fopt);
   return a;
 }
 template <class T, class M, class Expr>
@@ -561,6 +570,241 @@ integrate (
   details::form_expr_quadrature_on_element<Expr> expr_quad(expr);
   return integrate (gh, expr_quad, fopt);
 }
+#ifdef TO_CLEAN
+// -------------------------------------------------------
+// 5. field-result integration of a variational expression
+// -------------------------------------------------------
+// 5.1. general call
+// -------------------------------------------------------
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_field_expr_quadrature_arg<Expr>::value
+ ,details::field_lazy_terminal_integrate <Expr>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const typename Expr::geo_type& domain, 
+  const Expr&                    expr,
+  const integrate_option&        iopt = integrate_option())
+{
+  return details::field_lazy_terminal_integrate<Expr> (domain, expr, iopt);
+}
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_field_expr_v2_variational_arg<Expr>::value
+ ,details::field_lazy_terminal_integrate <details::field_expr_quadrature_on_element<Expr>>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const geo_basic<typename Expr::scalar_type, typename Expr::memory_type>& domain, 
+  const Expr& expr,
+  const integrate_option& iopt = integrate_option())
+{
+  details::field_expr_quadrature_on_element<Expr> expr_quad(expr);
+  return lazy_integrate (domain, expr_quad, iopt);
+}
+// ----------------------------------------------
+// 5.2. missing domain
+// ----------------------------------------------
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_field_expr_quadrature_arg<Expr>::value
+ ,details::field_lazy_terminal_integrate <Expr>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  return details::field_lazy_terminal_integrate<Expr> (expr, iopt);
+}
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_field_expr_v2_variational_arg<Expr>::value
+ ,details::field_lazy_terminal_integrate <details::field_expr_quadrature_on_element<Expr>>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  details::field_expr_quadrature_on_element<Expr> expr_quad(expr);
+  return lazy_integrate (expr_quad, fopt);
+}
+// ----------------------------------------------
+// 5.3. subdomain by its name
+// ----------------------------------------------
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_field_expr_quadrature_arg<Expr>::value
+ ,details::field_lazy_terminal_integrate <Expr>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const std::string& domname, 
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  return details::field_lazy_terminal_integrate<Expr> (domname, expr, iopt);
+}
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_field_expr_v2_variational_arg<Expr>::value
+ ,details::field_lazy_terminal_integrate <details::field_expr_quadrature_on_element<Expr>>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const std::string& domname, 
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  details::field_expr_quadrature_on_element<Expr> expr_quad(expr);
+  return lazy_integrate (domname, expr_quad, fopt);
+}
+#endif // TO_CLEAN
+// -------------------------------------------------------
+// 6. lazy_form-result integration of a variational expression
+// -------------------------------------------------------
+// 6.1. general call
+// -------------------------------------------------------
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_form_expr_quadrature_arg<Expr>::value
+ ,details::form_lazy_terminal_integrate <Expr>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const geo_basic<typename Expr::scalar_type, typename Expr::memory_type>& domain, 
+  const Expr& expr,
+  const integrate_option& iopt = integrate_option())
+{
+  return details::form_lazy_terminal_integrate<Expr> (domain, expr, iopt);
+}
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_form_expr_v2_variational_arg<Expr>::value
+ ,details::form_lazy_terminal_integrate <details::form_expr_quadrature_on_element<Expr>>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const geo_basic<typename Expr::scalar_type, typename Expr::memory_type>& domain, 
+  const Expr& expr,
+  const integrate_option& iopt = integrate_option())
+{
+  details::form_expr_quadrature_on_element<Expr> expr_quad(expr);
+  return lazy_integrate (domain, expr_quad, iopt);
+}
+// ----------------------------------------------
+// 6.2. missing domain
+// ----------------------------------------------
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_form_expr_quadrature_arg<Expr>::value
+ ,details::form_lazy_terminal_integrate <Expr>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  // TODO: improve the automatic determination of the domain
+  //       by an union that operates recrusively
+  constexpr bool has_on_local_sides = details::is_form_expr_quadrature_on_side_arg<Expr>::value;
+  geo_basic <typename Expr::scalar_type, typename Expr::memory_type>
+    dom_trial = expr.get_trial_space().get_constitution().get_geo(),
+    dom_test  = expr. get_test_space().get_constitution().get_geo(),
+    dom;
+  // dom = intersection of trial & test domain definition
+  if (dom_trial.is_broken() && dom_test.is_broken() &&
+      expr.get_trial_space().get_constitution().is_hierarchical() &&
+      expr. get_test_space().get_constitution().is_hierarchical() ) {
+    dom = dom_test.get_background_geo();
+  } else if (dom_trial.name() == dom_test.name() ||
+      dom_trial.name() == dom_test.get_background_geo().name() ||
+      dom_trial.is_broken()) {
+    dom = has_on_local_sides ? dom_trial : dom_test;
+  } else if (dom_test.name() == dom_trial.get_background_geo().name() ||
+             dom_test.is_broken()) {
+    dom = has_on_local_sides ? dom_test : dom_trial;
+  } else {
+    error_macro("integrate: incompatible domains: trial \""<<dom_trial.name()
+	<< "\" and \"" << dom_test.name() << "\"");
+  }
+  trace_macro("Expr="<<pretty_typename_macro(Expr));
+  trace_macro ("space_trial="<<expr.get_trial_space().name()<<" space_test="<<expr. get_test_space().name());
+  trace_macro ("dom_trial="<<dom_trial.name()<<" dom_test="<<dom_test.name()<<" -> dom="<<dom.name());
+  return lazy_integrate (dom, expr, fopt);
+}
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_form_expr_v2_variational_arg<Expr>::value
+ ,details::form_lazy_terminal_integrate <details::form_expr_quadrature_on_element<Expr>>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  details::form_expr_quadrature_on_element<Expr> expr_quad(expr);
+  return lazy_integrate (expr_quad, fopt);
+}
+// ----------------------------------------------
+// 6.3. subdomain by its name
+// ----------------------------------------------
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_form_expr_quadrature_arg<Expr>::value
+ ,details::form_lazy_terminal_integrate <Expr>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const std::string& domname, 
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  form_basic <typename Expr::scalar_type, typename Expr::memory_type> a;
+  const geo_basic <typename Expr::scalar_type, typename Expr::memory_type>&
+    dom = expr.get_trial_space().get_constitution().get_background_geo()[domname];
+  return lazy_integrate (dom, expr, fopt);
+}
+template <class Expr>
+inline
+typename
+std::enable_if<
+  details::is_form_expr_v2_variational_arg<Expr>::value
+ ,details::form_lazy_terminal_integrate <details::form_expr_quadrature_on_element<Expr>>
+>::type
+//! @brief see the @ref integrate_3 page for the full documentation
+lazy_integrate (
+  const std::string& domname, 
+  const Expr& expr,
+  const integrate_option& fopt = integrate_option())
+{
+  details::form_expr_quadrature_on_element<Expr> expr_quad(expr);
+  return lazy_integrate (domname, expr_quad, fopt);
+}
 
 }// namespace rheolef
 #endif // _RHEO_INTEGRATE_H
