@@ -156,9 +156,74 @@ det_jacobian_piola_transformation (const tensor_basic<T>& DF, size_t d , size_t
         return 0;
     }
 }
-//
-// application:
-//
+// ------------
+// normal
+// ------------
+template<class T, class M>
+static
+point_basic<T>
+normal_from_piola_transformation_1d (
+    const geo_basic<T,M>&  omega,
+    const geo_element&     S,
+    const tensor_basic<T>& DF,
+    size_t                 d)
+{
+  // point in 1D: DF[1][0] is empty, so scan S[0] node connectivity 
+  typedef typename geo_basic<T,M>::size_type size_type;
+  if (S.dimension() + 1 == omega.map_dimension()) {
+    size_type dis_ie = S.master(0);
+    check_macro (dis_ie != std::numeric_limits<size_type>::max(), "normal: requires neighbours initialization");
+    const geo_element& K = omega.dis_get_geo_element (S.dimension()+1, dis_ie);
+    Float sign = (S[0] == K[1]) ? 1 : -1;
+    return point_basic<T>(sign);
+  }
+  // omega is a domain of sides, as "boundary" or "internal_sides": 
+  // for the side orient, we need to go back to its backgound volumic mesh
+  if (omega.variant() == geo_abstract_base_rep<T>::geo_domain_indirect) {
+    size_type       dis_isid = S.dis_ie();
+    size_type first_dis_isid = omega.sizes().ownership_by_dimension[S.dimension()].first_index();
+    size_type           isid = dis_isid - first_dis_isid;
+    check_macro (dis_isid >= first_dis_isid, "unexpected dis_index "<<dis_isid<<": out of local range");
+    const geo_basic<T,M>* ptr_bgd_omega = 0;
+    if (omega.get_background_geo().map_dimension() == 1) {
+      const geo_basic<T,M>& bgd_omega = omega.get_background_geo();
+      const geo_element&    bgd_S     = bgd_omega.get_geo_element(0, isid);
+      size_type bgd_dis_ie = bgd_S.master(0);
+      check_macro (bgd_dis_ie != std::numeric_limits<size_type>::max(),
+	"normal: bgd_S.dis_ie={"<<bgd_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
+      const geo_element& bgd_K = bgd_omega.dis_get_geo_element (bgd_S.dimension()+1, bgd_dis_ie);
+      Float sign = (bgd_S[0] == bgd_K[1]) ? 1 : -1;
+      return point_basic<T>(sign);
+    } else {
+      // get a 1D geometry at a higher depth, e.g. for HDG 0D "boundary" domain in "square[sides]" 0D geo_domain
+      const geo_basic<T,M>&  bgd_omega =     omega.get_background_geo();
+      const geo_basic<T,M>& bgd2_omega = bgd_omega.get_background_geo();
+      check_macro (bgd2_omega.dimension() == 1, "unsupported depth for "<<omega.name()<<" in background domain "<<bgd_omega.name());
+      const geo_element&    bgd_S      = bgd_omega.get_geo_element(0, isid);
+      const geo_element&    bgd2_S     = bgd_omega.dom2bgd_geo_element (bgd_S);
+      size_type bgd2_dis_ie = bgd2_S.master(0);
+      check_macro (bgd2_dis_ie != std::numeric_limits<size_type>::max(),
+	"normal: bgd2_S.dis_ie={"<<bgd2_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd2_omega.name());
+      const geo_element& bgd2_K = bgd2_omega.dis_get_geo_element (bgd2_S.dimension()+1, bgd2_dis_ie);
+      Float sign = (bgd2_S[0] == bgd2_K[1]) ? 1 : -1;
+      return point_basic<T>(sign);
+    }
+  }
+  // omega.variant() != geo_abstract_base_rep<T>::geo_domain_indirect
+  size_type       dis_isid = S.dis_ie();
+  size_type first_dis_isid = omega.sizes().ownership_by_dimension[S.dimension()].first_index();
+  size_type           isid = dis_isid - first_dis_isid;
+  check_macro (dis_isid >= first_dis_isid, "unexpected dis_index "<<dis_isid<<": out of local range");
+  const geo_basic<T,M>& bgd_omega = omega.get_background_geo();
+  const geo_basic<T,M>& bgd_dom   = omega.get_background_domain();
+  const geo_element&    bgd_S     = bgd_dom[isid]; // TODO: pas clair, differe du cas precedent ?
+  size_type bgd_dis_ie = bgd_S.master(0);
+  check_macro (bgd_dis_ie != std::numeric_limits<size_type>::max(),
+      "normal: bgd_S.dis_ie={"<<bgd_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
+  const geo_element& bgd_K = bgd_omega.dis_get_geo_element (bgd_S.dimension()+1, bgd_dis_ie);
+  Float sign = (bgd_S[0] == bgd_K[1]) ? 1 : -1;
+  return point_basic<T>(sign);
+}
 template<class T, class M>
 point_basic<T>
 normal_from_piola_transformation (
@@ -167,81 +232,30 @@ normal_from_piola_transformation (
     const tensor_basic<T>& DF,
     size_t                 d)
 {
-    switch (d) {
-      case 1: { // point in 1D: DF[1][0] is empty, so scan S[0] node connectivity 
-         typedef typename geo_basic<T,M>::size_type size_type;
-          if (S.dimension() + 1 == omega.map_dimension()) {
-            size_type dis_ie = S.master(0);
-	    check_macro (dis_ie != std::numeric_limits<size_type>::max(), "normal: requires neighbours initialization");
-            const geo_element& K = omega.dis_get_geo_element (S.dimension()+1, dis_ie);
-            Float sign = (S[0] == K[1]) ? 1 : -1;
-            return point_basic<T>(sign);
-          }
-          // omega is a domain of sides, as "boundary" or "internal_sides": 
-          // for the side orient, we need to go back to its backgound volumic mesh
-          if (omega.variant() == geo_abstract_base_rep<T>::geo_domain_indirect) {
-            size_type       dis_isid = S.dis_ie();
-            size_type first_dis_isid = omega.sizes().ownership_by_dimension[S.dimension()].first_index();
-            size_type           isid = dis_isid - first_dis_isid;
-            check_macro (dis_isid >= first_dis_isid, "unexpected dis_index "<<dis_isid<<": out of local range");
-            const geo_basic<T,M>* ptr_bgd_omega = 0;
-            if (omega.get_background_geo().map_dimension() == 1) {
-              const geo_basic<T,M>& bgd_omega = omega.get_background_geo();
-              const geo_element&    bgd_S     = bgd_omega.get_geo_element(0, isid);
-              size_type bgd_dis_ie = bgd_S.master(0);
-	      check_macro (bgd_dis_ie != std::numeric_limits<size_type>::max(),
-	        "normal: bgd_S.dis_ie={"<<bgd_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
-              const geo_element& bgd_K = bgd_omega.dis_get_geo_element (bgd_S.dimension()+1, bgd_dis_ie);
-              Float sign = (bgd_S[0] == bgd_K[1]) ? 1 : -1;
-              return point_basic<T>(sign);
-            } else {
-  	      // get a 1D geometry at a higher depth, e.g. for HDG 0D "boundary" domain in "square[sides]" 0D geo_domain
-              const geo_basic<T,M>&  bgd_omega =     omega.get_background_geo();
-              const geo_basic<T,M>& bgd2_omega = bgd_omega.get_background_geo();
-              check_macro (bgd2_omega.dimension() == 1, "unsupported depth for "<<omega.name()<<" in background domain "<<bgd_omega.name());
-              const geo_element&    bgd_S      = bgd_omega.get_geo_element(0, isid);
-              const geo_element&    bgd2_S     = bgd_omega.dom2bgd_geo_element (bgd_S);
-              size_type bgd2_dis_ie = bgd2_S.master(0);
-	      check_macro (bgd2_dis_ie != std::numeric_limits<size_type>::max(),
-	        "normal: bgd2_S.dis_ie={"<<bgd2_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd2_omega.name());
-              const geo_element& bgd2_K = bgd2_omega.dis_get_geo_element (bgd2_S.dimension()+1, bgd2_dis_ie);
-              Float sign = (bgd2_S[0] == bgd2_K[1]) ? 1 : -1;
-              return point_basic<T>(sign);
-            }
-          } else {
-            size_type       dis_isid = S.dis_ie();
-            size_type first_dis_isid = omega.sizes().ownership_by_dimension[S.dimension()].first_index();
-            size_type           isid = dis_isid - first_dis_isid;
-            check_macro (dis_isid >= first_dis_isid, "unexpected dis_index "<<dis_isid<<": out of local range");
-            const geo_basic<T,M>& bgd_omega = omega.get_background_geo();
-            const geo_basic<T,M>& bgd_dom   = omega.get_background_domain();
-            const geo_element&    bgd_S     = bgd_dom[isid]; // TODO: pas clair, differe du cas precedent ?
-            size_type bgd_dis_ie = bgd_S.master(0);
-	    check_macro (bgd_dis_ie != std::numeric_limits<size_type>::max(),
-	      "normal: bgd_S.dis_ie={"<<bgd_S.dis_ie()<<"} without neighbours; requires neighbours initialization for mesh " << bgd_omega.name());
-            const geo_element& bgd_K = bgd_omega.dis_get_geo_element (bgd_S.dimension()+1, bgd_dis_ie);
-            Float sign = (bgd_S[0] == bgd_K[1]) ? 1 : -1;
-            return point_basic<T>(sign);
-          }
-      }
-      case 2: { // edge in 2D
-          // 2D: S=edge(a,b) then t=b-a, DF=[t] and n = (t1,-t0) => det(n,1)=1 : (n,t) is direct
-          // and the normal goes outside on a boundary edge S, when the associated element K is well oriented
-          point_basic<T> t = DF.col(0);
-          t /= norm(t);
-          return point_basic<T>(t[1], -t[0]);
-      }
-      case 3: { // 3D: S=triangle(a,b,c) then t0=b-a, t1=c-a, DF=[t0,t1] and n = t0^t1/|t0^t1|.
-          point_basic<T> t0 = DF.col(0);
-          point_basic<T> t1 = DF.col(1);
-          point_basic<T> n = vect(t0,t1);
-          n /= norm(n);
-          return n;
-      }
-      default:
-          error_macro ("normal: unsupported " << d << "D mesh.");
-          return point_basic<T>();
+  switch (d) {
+    case 1: {
+      // special case:
+      return normal_from_piola_transformation_1d (omega, S, DF, d);
     }
+    case 2: { // edge in 2D
+      // 2D: S=edge(a,b) then t=b-a, DF=[t] and n = (t1,-t0) => det(n,1)=1 : (n,t) is direct
+      // and the normal goes outside on a boundary edge S, when the associated element K is well oriented
+      point_basic<T> t = DF.col(0);
+      t /= norm(t);
+      return point_basic<T>(t[1], -t[0]);
+    }
+    case 3: { // 3D: S=triangle(a,b,c) then t0=b-a, t1=c-a, DF=[t0,t1] and n = t0^t1/|t0^t1|.
+      point_basic<T> t0 = DF.col(0);
+      point_basic<T> t1 = DF.col(1);
+      point_basic<T> n = vect (t0,t1);
+      n /= norm(n);
+      return n;
+    }
+    default: {
+      error_macro ("normal: unsupported " << d << "D mesh.");
+      return point_basic<T>();
+    }
+  }
 }
 // The pseudo inverse extend inv(DF) for face in 3d or edge in 2d
 //  i.e. useful for Laplacian-Beltrami and others surfacic forms.
