@@ -190,14 +190,14 @@ public:
 
     std::string name() const; /// e.g. "P1(square)", for field_expr<Expr> checks
 
-    void block  (const domain_indirect_basic<M>& dom) { no_freeze_guard(); _constit.block  (dom); }
-    void unblock(const domain_indirect_basic<M>& dom) { no_freeze_guard(); _constit.unblock(dom);}
+    void block  (const domain_indirect_basic<M>& dom) { no_freeze_check(); _constit.block  (dom); }
+    void unblock(const domain_indirect_basic<M>& dom) { no_freeze_check(); _constit.unblock(dom);}
 
-    void block_n  (const domain_indirect_basic<M>& dom) { no_freeze_guard(); _constit.block_n  (dom); }
-    void unblock_n(const domain_indirect_basic<M>& dom) { no_freeze_guard(); _constit.unblock_n(dom);}
+    void block_n  (const domain_indirect_basic<M>& dom) { no_freeze_check(); _constit.block_n  (dom); }
+    void unblock_n(const domain_indirect_basic<M>& dom) { no_freeze_check(); _constit.unblock_n(dom);}
 
-    bool                 is_blocked (size_type idof) const { freeze_guard(); return _idof2blk_dis_iub [idof].is_blocked(); }
-    size_type               dis_iub (size_type idof) const { freeze_guard(); return _idof2blk_dis_iub [idof].dis_iub(); }
+    bool                 is_blocked (size_type idof) const { freeze_check(); return _idof2blk_dis_iub [idof].is_blocked(); }
+    size_type               dis_iub (size_type idof) const { freeze_check(); return _idof2blk_dis_iub [idof].dis_iub(); }
     const point_basic<T>& xdof (size_type idof) const { return _xdof [idof]; }
     const disarray<point_basic<T>,M >& get_xdofs() const { return _xdof; }
 
@@ -216,10 +216,10 @@ public:
     template <class Function>
     tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const { return f (xdof(idof)); }
 
-    disarray<size_type, M> build_indirect_array (
+    disarray<size_type, M> build_dom_dis_idof2bgd_dis_idof (
     	const space_base_rep<T,M>& Wh, const std::string& dom_name) const;
 
-    disarray<size_type, M> build_indirect_array (
+    disarray<size_type, M> build_dom_dis_idof2bgd_dis_idof (
         const space_base_rep<T,M>& Wh, const geo_basic<T,M>& bgd_gamma) const;
 
 // comparator:
@@ -230,6 +230,16 @@ public:
     friend bool are_compatible (const space_base_rep<T,M>& V1, const space_base_rep<T,M>& V2) {
     	return V1._constit.operator==(V2._constit); }
 
+// for lazy (un-assembled) on geo_domains:
+
+    void parent_subgeo_owner_check() const {
+      check_macro (_parent_subgeo_owner_initialized, "parent_subgeo_owner_guard() should be called before local accessors");
+    }
+    bool parent_subgeo_owner_guard() const;
+    size_type get_parent_subgeo_owner (size_type dis_idof) const;
+    template <class Set>
+    void get_parent_subgeo_owner_dis_indexes (Set& ext_dis_idofs) const;
+
 protected:
     template <class T1, class M1> friend class field_basic;
 // internal:
@@ -239,7 +249,10 @@ protected:
     	_have_freezed = true;
     	freeze_body();
     }
-    void no_freeze_guard() const {
+    void freeze_check() const {
+    	check_macro (_have_freezed, "space should be freezed before calling local accessors");
+    }
+    void no_freeze_check() const {
     	check_macro (!_have_freezed, "freezed space cannot accept new (un)blocked domains");
     }
     void base_freeze_body() const;
@@ -253,7 +266,24 @@ protected:
     mutable disarray<point_basic<T>,M>     _normal;        // when block_{nt} ; use ownership
     mutable distributor                    _iu_ownership;  // unknown values distribution
     mutable distributor                    _ib_ownership;  // blocked values distribution
+    mutable bool                           _parent_subgeo_owner_initialized;
+    mutable bool                           _parent_subgeo_owner_reattribution_required;
+    mutable disarray<size_type,M>          _parent_subgeo_owner;
 };
+template <class T, class M>
+template <class Set>
+void
+space_base_rep<T,M>::get_parent_subgeo_owner_dis_indexes (Set& ext_dis_idofs) const
+{
+  parent_subgeo_owner_guard();
+  if (! _parent_subgeo_owner_reattribution_required) {
+    ext_dis_idofs = Set();
+    return;
+  }
+  _parent_subgeo_owner.get_dis_indexes (ext_dis_idofs);
+}
+// ---------------------------------------------------------------------
+// space_rep
 // ---------------------------------------------------------------------
 template <class T, class M> class space_rep {};
 
@@ -428,10 +458,10 @@ public:
     template <class Function>
     tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const;
 
-    disarray<size_type, sequential> build_indirect_array (
+    disarray<size_type, sequential> build_dom_dis_idof2bgd_dis_idof (
     	const space_basic<T,sequential>& Wh, const std::string& dom_name) const;
 
-    disarray<size_type, sequential> build_indirect_array (
+    disarray<size_type, sequential> build_dom_dis_idof2bgd_dis_idof (
         const space_basic<T,sequential>& Wh, const geo_basic<T,sequential>& bgd_gamma) const;
 
     const std::set<size_type>& ext_iu_set() const { return base::data().ext_iu_set(); }
@@ -443,6 +473,14 @@ public:
     bool operator!= (const space_basic<T,sequential>& V2) const { return ! operator== (V2); }
     friend bool are_compatible (const space_basic<T,sequential>& V1, const space_basic<T,sequential>& V2) {
 	return are_compatible (V1.data(), V2.data()); }
+
+// for lazy (un-assembled) on geo_domains:
+
+    template <class Set>
+    void get_parent_subgeo_owner_dis_indexes (Set& ext_dis_idofs) const
+        {        base::data().get_parent_subgeo_owner_dis_indexes (ext_dis_idofs); }
+    size_type get_parent_subgeo_owner (size_type dis_idof) const
+        { return base::data().get_parent_subgeo_owner (dis_idof); }
 };
 // [verbatim_space_basic]
 template<class T>
@@ -825,10 +863,10 @@ public:
     template <class Function>
     tensor_basic<T> tensor_momentum (const Function& f, size_type idof) const;
 
-    disarray<size_type, distributed> build_indirect_array (
+    disarray<size_type, distributed> build_dom_dis_idof2bgd_dis_idof (
     	const space_basic<T,distributed>& Wh, const std::string& dom_name) const;
 
-    disarray<size_type, distributed> build_indirect_array (
+    disarray<size_type, distributed> build_dom_dis_idof2bgd_dis_idof (
         const space_basic<T,distributed>& Wh, const geo_basic<T,distributed>& bgd_gamma) const;
 
     const std::set<size_type>& ext_iu_set() const { return base::data().ext_iu_set(); }
@@ -840,6 +878,14 @@ public:
     bool operator!= (const space_basic<T,distributed>& V2) const { return ! operator== (V2); }
     friend bool are_compatible (const space_basic<T,distributed>& V1, const space_basic<T,distributed>& V2) {
 	return are_compatible (V1.data(), V2.data()); }
+
+// for lazy (un-assembled) on geo_domains:
+
+    template <class Set>
+    void get_parent_subgeo_owner_dis_indexes (Set& ext_dis_idofs) const
+        {        base::data().get_parent_subgeo_owner_dis_indexes (ext_dis_idofs); }
+    size_type get_parent_subgeo_owner (size_type dis_idof) const
+        { return base::data().get_parent_subgeo_owner (dis_idof); }
 };
 //>verbatim:
 
@@ -1144,32 +1190,32 @@ space_basic<T,distributed>::tensor_momentum (const Function& f, size_type idof)
 #endif // _RHEOLEF_HAVE_MPI
 
 // only valid when M=sequential or M=distributed => use a macro
-#define _RHEOLEF_space_build_indirect_array(M)						\
+#define _RHEOLEF_space_build_dom_dis_idof2bgd_dis_idof(M)						\
 template<class T>									\
 inline											\
 disarray<typename space_basic<T,M>::size_type, M>					\
-space_basic<T,M>::build_indirect_array (						\
+space_basic<T,M>::build_dom_dis_idof2bgd_dis_idof (						\
 	const space_basic<T,M>& Wh,							\
 	const std::string& dom_name) const						\
 {											\
-    return base::data().build_indirect_array (Wh.data(), dom_name);			\
+    return base::data().build_dom_dis_idof2bgd_dis_idof (Wh.data(), dom_name);			\
 }											\
 template<class T>									\
 inline											\
 disarray<typename space_basic<T,M>::size_type, M>					\
-space_basic<T,M>::build_indirect_array (						\
+space_basic<T,M>::build_dom_dis_idof2bgd_dis_idof (						\
 	const space_basic<T,M>& Wh,							\
 	const geo_basic<T,M>&   bgd_gamma) const					\
 {											\
-    return base::data().build_indirect_array (Wh.data(), bgd_gamma);			\
+    return base::data().build_dom_dis_idof2bgd_dis_idof (Wh.data(), bgd_gamma);			\
 }
-_RHEOLEF_space_build_indirect_array(sequential)
+_RHEOLEF_space_build_dom_dis_idof2bgd_dis_idof(sequential)
 
 #ifdef _RHEOLEF_HAVE_MPI
-_RHEOLEF_space_build_indirect_array(distributed)
+_RHEOLEF_space_build_dom_dis_idof2bgd_dis_idof(distributed)
 #endif // _RHEOLEF_HAVE_MPI
 
-#undef _RHEOLEF_space_build_indirect_array
+#undef _RHEOLEF_space_build_dom_dis_idof2bgd_dis_idof
 
 } // namespace rheolef
 #endif // _RHEOLEF_SPACE_H
