@@ -29,7 +29,8 @@
 // 5. output
 // 6. do_act: block & unblock on a domain
 // 7. ios accessors
-// 8. dis_idof, for assembly: moved to space_constitution_assembly.cc
+// 8. comp_dis_idof2dis_idof : for wdof_sliced
+// 9. dis_idof, for assembly: moved to space_constitution_assembly.cc
 //
 #include "rheolef/geo_domain.h"
 #include "rheolef/space.h"
@@ -45,7 +46,7 @@ namespace rheolef {
 // 1. allocators
 // ======================================================================
 template <class T, class M>
-space_scalar_constitution_rep<T,M>::space_scalar_constitution_rep(
+space_constitution_terminal_rep<T,M>::space_constitution_terminal_rep(
 		const geo_basic<T,M>&    omega,
 		std::string              approx)
   : _acts(),
@@ -71,7 +72,7 @@ space_scalar_constitution_rep<T,M>::space_scalar_constitution_rep(
 }
 template <class T, class M>
 void
-space_scalar_constitution_rep<T,M>::do_act (const space_act& act)
+space_constitution_terminal_rep<T,M>::do_act (const space_act& act)
 {
   check_macro (get_geo().map_dimension() < get_geo().dimension() ||
               !get_basis().have_compact_support_inside_element(),
@@ -85,8 +86,8 @@ space_constitution_rep<T,M>::do_act (const space_act& act)
 {
   typedef distributor::size_type size_type;
   if (! is_hierarchical()) {
-    space_scalar_constitution<T,M>& scalar_constit = get_scalar();
-    scalar_constit.do_act (act);
+    space_constitution_terminal<T,M>& terminal_constit = get_terminal();
+    terminal_constit.do_act (act);
     return;
   }
   // hierarchical case:
@@ -100,7 +101,7 @@ space_constitution_rep<T,M>::do_act (const space_act& act)
 // -----------------------------------------------------------------------
 template <class T, class M>
 void
-space_scalar_constitution_rep<T,M>::build_blocked_flag (
+space_constitution_terminal_rep<T,M>::build_blocked_flag (
   disarray<size_type,M>& blocked_flag, // disarray<bool,M> not supported
   const distributor&  comp_ownership,
   const distributor&  start_by_flattened_component) const
@@ -179,8 +180,8 @@ space_constitution_rep<T,M>::build_blocked_flag_recursive (
   size_type&                         i_flat_comp) const
 {
   if (! is_hierarchical()) {
-    const space_scalar_constitution<T,M>& scalar_constit = get_scalar();
-    scalar_constit.data().build_blocked_flag (blocked_flag, ownership(), start_by_flattened_component [i_flat_comp]);
+    const space_constitution_terminal<T,M>& terminal_constit = get_terminal();
+    terminal_constit.data().build_blocked_flag (blocked_flag, ownership(), start_by_flattened_component [i_flat_comp]);
     i_flat_comp++;
     return;
   }
@@ -208,7 +209,7 @@ const geo_basic<T,M>&
 space_constitution_rep<T,M>::get_geo() const
 {
   if (! is_hierarchical()) {
-    return get_scalar().get_geo();
+    return get_terminal().get_geo();
   }
   // heterogeneous: get as geo the maximum domain of definition
   // => it is the intersection of all domain definition
@@ -233,7 +234,7 @@ const geo_basic<T,M>&
 space_constitution_rep<T,M>::get_background_geo() const
 {
   if (! is_hierarchical()) {
-    return get_scalar().get_background_geo();
+    return get_terminal().get_background_geo();
   }
   // component have the same background mesh: assume it without check (TODO: constit.check_have_same_bgd_geo())
   check_macro (_hier_constit.size() > 0, "get_background_geo: empty space product");
@@ -246,7 +247,7 @@ const basis_basic<T>&
 space_constitution_rep<T,M>::get_basis() const
 {
   check_macro(! is_hierarchical(), "get_basis: undefined for heterogeneous space products");
-  return get_scalar().get_basis();
+  return get_terminal().get_basis();
 }
 // ======================================================================
 // 3. inquire
@@ -256,7 +257,7 @@ bool
 space_constitution_rep<T,M>::have_compact_support_inside_element() const
 {
   if (! is_hierarchical()) {
-    return get_scalar().get_basis().have_compact_support_inside_element();
+    return get_terminal().get_basis().have_compact_support_inside_element();
   }
   bool has = true;
   for (const_iterator iter = _hier_constit.begin(), last = _hier_constit.end(); iter != last; ++iter) {
@@ -270,7 +271,7 @@ bool
 space_constitution_rep<T,M>::is_discontinuous() const
 {
   if (! is_hierarchical()) {
-    return get_scalar().get_basis().is_discontinuous();
+    return get_terminal().get_basis().is_discontinuous();
   }
   bool is = true;
   for (const_iterator iter = _hier_constit.begin(), last = _hier_constit.end(); iter != last; ++iter) {
@@ -279,30 +280,9 @@ space_constitution_rep<T,M>::is_discontinuous() const
   }
   return is;
 }
-template <class T, class M>
-space_constitution_rep<T,M>::space_constitution_rep (
-    const geo_basic<T,M>&    omega,
-    std::string              approx)
- : _is_initialized(false),
-   _flattened_size(0),
-   _start_by_flattened_component(),
-   _start_by_component(),
-   _ownership(),
-   _valued_tag(space_constant::scalar),
-   _is_hier(false),
-   _scalar_constit(),
-   _hier_constit(),
-   _loc_ndof()
-{
-  _loc_ndof.fill (std::numeric_limits<size_type>::max());
-  _scalar_constit = scalar_type (omega, approx);
-  if (_scalar_constit.get_basis().is_initialized()) {
-    _valued_tag = _scalar_constit.get_basis().valued_tag();
-  }
-  initialize();
-}
 // build a space::constitution hierrachy from a list of spaces
 template <class T, class M>
+inline
 space_constitution_rep<T,M>::space_constitution_rep(const space_mult_list<T,M>& expr)
  : _is_initialized(false),
    _flattened_size(0),
@@ -311,7 +291,7 @@ space_constitution_rep<T,M>::space_constitution_rep(const space_mult_list<T,M>&
    _ownership(),
    _valued_tag(space_constant::mixed),
    _is_hier(true),
-   _scalar_constit(),
+   _terminal_constit(),
    _hier_constit(expr.size()),
    _loc_ndof()
 {
@@ -328,7 +308,7 @@ bool
 space_constitution_rep<T,M>::operator== (const space_constitution_rep<T,M>& V2) const
 {
   if (_is_hier != V2._is_hier) { return false; }
-  if (!_is_hier) { return (_scalar_constit == V2._scalar_constit); }
+  if (!_is_hier) { return (_terminal_constit == V2._terminal_constit); }
   // here, two hierarchies:
   if (_hier_constit.size() != V2._hier_constit.size()) return false;
   for (const_iterator iter1 = _hier_constit.begin(), iter2 = V2._hier_constit.begin(), last1 = _hier_constit.end(); iter1 != last1; ++iter1, ++iter2) {
@@ -485,8 +465,8 @@ space_constitution_rep<T,M>::compute_external_dofs (
 	size_type&                      i_flat_comp) const
 {
   if (! is_hierarchical()) {
-    const space_scalar_constitution<T,M>& scalar_constit = get_scalar();
-    append_external_dof (scalar_constit.get_geo(), ext_dof_set, dof_ownership, start_by_flattened_component [i_flat_comp]);
+    const space_constitution_terminal<T,M>& terminal_constit = get_terminal();
+    append_external_dof (terminal_constit.get_geo(), ext_dof_set, dof_ownership, start_by_flattened_component [i_flat_comp]);
     i_flat_comp++;
     return;
   }
@@ -512,9 +492,9 @@ void
 space_constitution_rep<T,M>::put (std::ostream& out, size_type level) const
 {
   if (! is_hierarchical()) {
-    const space_scalar_constitution<T,M>& scalar_constit = get_scalar();
-    if (!scalar_constit.get_basis().is_initialized()) return;
-    out << scalar_constit.get_basis().name() << "{" << scalar_constit.get_geo().name() << "}";
+    const space_constitution_terminal<T,M>& terminal_constit = get_terminal();
+    if (!terminal_constit.get_basis().is_initialized()) return;
+    out << terminal_constit.get_basis().name() << "{" << terminal_constit.get_geo().name() << "}";
   } else {
     if (level > 0) out << "(";
     typename space_constitution<T,M>::hierarchy_type::const_iterator x = get_hierarchy().begin();
@@ -542,7 +522,7 @@ typename space_constitution_rep<T,M>::size_type
 space_constitution_rep<T,M>::degree_max() const
 {
   if (! is_hierarchical()) {
-    return get_scalar().get_basis().degree();
+    return get_terminal().get_basis().degree();
   }
   size_type degree_max = 0;
   for (const_iterator iter = _hier_constit.begin(), last = _hier_constit.end(); iter != last; ++iter) {
@@ -558,7 +538,7 @@ space_constitution_rep<T,M>::neighbour_guard() const
   if (! is_hierarchical()) {
     if (get_geo().dimension() == get_geo().map_dimension()) {
       // 3d surface mesh or 2d lineique mesh are not yet treated for neighbours
-      get_scalar().neighbour_guard();
+      get_terminal().neighbour_guard();
     }
     return;
   }
@@ -575,8 +555,8 @@ typename space_constitution_rep<T,M>::size_type
 space_constitution_rep<T,M>::ios_ndof () const
 {
   if (!_is_hier) {
-    communicator comm =_scalar_constit.get_geo().comm();
-    size_type dis_ndof = space_numbering::dis_ndof (_scalar_constit.get_basis(), _scalar_constit.get_geo().sizes(), _scalar_constit.get_geo().map_dimension());
+    communicator comm =_terminal_constit.get_geo().comm();
+    size_type dis_ndof = space_numbering::dis_ndof (_terminal_constit.get_basis(), _terminal_constit.get_geo().sizes(), _terminal_constit.get_geo().map_dimension());
     // TODO: memorize ios_ownership : avoid comms & risks of errors
     distributor ios_ownership (dis_ndof, comm, distributor::decide);
     return ios_ownership.size();
@@ -590,7 +570,7 @@ space_constitution_rep<T,M>::ios_ndof () const
 }
 template <class T, class M>
 void
-space_scalar_constitution_rep<T,M>::set_ios_permutations (
+space_constitution_terminal_rep<T,M>::set_ios_permutations (
         disarray<size_type,M>& idof2ios_dis_idof,
         disarray<size_type,M>& ios_idof2dis_idof) const
 {
@@ -609,7 +589,7 @@ space_constitution_rep<T,M>::set_ios_permutation_recursion (
     disarray<size_type,M> comp_ios_idof2dis_idof; 
     // TODO: avoid allocating comp_idof2ios_dis_idof: numbering supports directly comp_start_{dis_}idof
     // TODO: avoid invert permut here: numbering support no invert perm arg
-    _scalar_constit.set_ios_permutations (comp_idof2ios_dis_idof, comp_ios_idof2dis_idof);
+    _terminal_constit.set_ios_permutations (comp_idof2ios_dis_idof, comp_ios_idof2dis_idof);
     // then shift
     size_type     comp_ndof = comp_idof2ios_dis_idof.size();
     size_type comp_dis_ndof = comp_idof2ios_dis_idof.dis_size();
@@ -641,7 +621,7 @@ space_constitution_rep<T,M>::set_ios_permutations (
 {
   if (!_is_hier) {
     // non-hierarchical case: direct
-    _scalar_constit.set_ios_permutations (idof2ios_dis_idof, ios_idof2dis_idof);
+    _terminal_constit.set_ios_permutations (idof2ios_dis_idof, ios_idof2dis_idof);
     return;
   }
   // hierarchical case:
@@ -664,15 +644,42 @@ space_constitution_rep<T,M>::set_ios_permutations (
   ios_idof2dis_idof.resize (ios_dof_ownership, std::numeric_limits<size_type>::max());
   idof2ios_dis_idof.reverse_permutation (ios_idof2dis_idof);
 }
+// ======================================================================
+// 8. comp_dis_idof2dis_idof : for wdof_sliced
+// ======================================================================
+template <class T, class M>
+typename space_constitution_rep<T,M>::size_type
+space_constitution_rep<T,M>::comp_dis_idof2dis_idof (
+    size_type i_comp,
+    size_type comp_dis_idof) const
+{
+  if (! is_hierarchical()) {
+    // component of a "vector" or "tensor" valued space
+    size_type n_comp = get_terminal().get_basis().size();
+    size_type dis_idof = comp_dis_idof*n_comp + i_comp;
+    return dis_idof;
+  }
+  // here: any space product such as Zh=Xh*Yh
+  const distributor& comp_ownership = _hier_constit [i_comp].ownership();
+  size_type iproc = comp_ownership.find_owner (comp_dis_idof);
+  size_type first_comp_dis_idof = comp_ownership.first_index (iproc);
+  check_macro (comp_dis_idof >= first_comp_dis_idof, "comp_dis_idof="<<comp_dis_idof << " is out of range");
+  size_type comp_idof = comp_dis_idof - first_comp_dis_idof;
+  size_type comp_start_idof = _start_by_flattened_component[i_comp].size (iproc);
+  size_type idof = comp_start_idof + comp_idof;
+  size_type first_dis_idof = _ownership.first_index (iproc);
+  size_type dis_idof = first_dis_idof + idof;
+  return dis_idof;
+}
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-template class space_scalar_constitution_rep<Float,sequential>;
+template class space_constitution_terminal_rep<Float,sequential>;
 template class space_constitution_rep<Float,sequential>;
 template class space_constitution<Float,sequential>;
 
 #ifdef _RHEOLEF_HAVE_MPI
-template class space_scalar_constitution_rep<Float,distributed>;
+template class space_constitution_terminal_rep<Float,distributed>;
 template class space_constitution_rep<Float,distributed>;
 template class space_constitution<Float,distributed>;
 #endif // _RHEOLEF_HAVE_MPI
