@@ -74,11 +74,11 @@ protected:
     act_type    _act;
 };
 // =====================================================================
-// space_scalar_constitution = a table of acts
+// space_constitution_terminal = a table of acts
 // =====================================================================
 
 template <class T, class M>
-class space_scalar_constitution_rep {
+class space_constitution_terminal_rep {
 public:
     typedef typename  std::vector<space_act>         container_type;
     typedef typename  container_type::size_type      size_type;
@@ -86,17 +86,17 @@ public:
 
 // allocators:
 
-    space_scalar_constitution_rep()
+    space_constitution_terminal_rep()
       : _acts(), _omega(), _fem_basis() {}
 
-    space_scalar_constitution_rep(
+    space_constitution_terminal_rep(
 		const geo_basic<T,M>&    omega,
 		std::string              approx);
 
-    space_scalar_constitution_rep (const space_scalar_constitution_rep<T,M>& scr)
+    space_constitution_terminal_rep (const space_constitution_terminal_rep<T,M>& scr)
       : _acts(scr._acts), _omega(scr._omega), _fem_basis(scr._fem_basis)
     {
-	trace_macro ("physical copy of space_scalar_constitution_rep: size="<< size());
+	trace_macro ("physical copy of space_constitution_terminal_rep: size="<< size());
     }
 
 // accessors:
@@ -131,7 +131,7 @@ public:
 
 // comparator:
 
-    bool operator== (const space_scalar_constitution_rep<T,M>& V2) const { return _omega == V2._omega && _fem_basis.name() == V2._fem_basis.name(); }
+    bool operator== (const space_constitution_terminal_rep<T,M>& V2) const { return _omega == V2._omega && _fem_basis.name() == V2._fem_basis.name(); }
 
 // internal:
     void build_blocked_flag (
@@ -145,20 +145,20 @@ protected:
     basis_basic<T>         _fem_basis;
 };
 template <class T, class M>
-class space_scalar_constitution : public smart_pointer<space_scalar_constitution_rep<T,M> > {
+class space_constitution_terminal : public smart_pointer<space_constitution_terminal_rep<T,M> > {
 public:
 
-    typedef space_scalar_constitution_rep<T,M>   rep;
+    typedef space_constitution_terminal_rep<T,M>   rep;
     typedef smart_pointer<rep>                   base;
     typedef typename  rep::size_type             size_type;
     typedef typename  rep::const_iterator        const_iterator;
 
 // allocators:
 
-    space_scalar_constitution()
+    space_constitution_terminal()
      : smart_pointer<rep>(new_macro(rep)) {}
 
-    space_scalar_constitution(
+    space_constitution_terminal(
 		const geo_basic<T,M>&	 omega,
 		std::string              approx)
      : smart_pointer<rep>(new_macro(rep (omega,approx))) {}
@@ -188,7 +188,7 @@ public:
 
 // comparator:
 
-    bool operator== (const space_scalar_constitution<T,M>& V2) const { return base::data().operator==(V2.data()); }
+    bool operator== (const space_constitution_terminal<T,M>& V2) const { return base::data().operator==(V2.data()); }
 
 // modifiers
 
@@ -210,7 +210,7 @@ public:
     typedef space_constitution_rep<T,M>                this_type;
     typedef space_constitution<T,M>                    value_type;
     typedef std::vector<value_type>                    hierarchy_type;
-    typedef space_scalar_constitution<T,M>             scalar_type;
+    typedef space_constitution_terminal<T,M>             scalar_type;
     typedef typename  hierarchy_type::size_type        size_type;
     typedef typename  hierarchy_type::iterator         iterator;
     typedef typename  hierarchy_type::const_iterator   const_iterator;
@@ -246,7 +246,7 @@ public:
     const std::string& valued()     const       { return space_constant::valued_name (_valued_tag); }
     bool is_hierarchical() const                { return _is_hier; }
     void set_hierarchy (bool hier)              { _is_hier = hier; }
-    
+ 
 // inquiries:
 
     bool have_compact_support_inside_element() const;
@@ -256,8 +256,8 @@ public:
 
 // scalar accessors & modifiers:
 
-    const scalar_type& get_scalar() const { scalar_guard(); return _scalar_constit; }
-    scalar_type&       get_scalar()       { scalar_guard(); return _scalar_constit; }
+    const scalar_type& get_terminal() const { scalar_guard(); return _terminal_constit; }
+    scalar_type&       get_terminal()       { scalar_guard(); return _terminal_constit; }
 
 // hierarchy accessors & modifiers:
 
@@ -268,6 +268,7 @@ public:
     const space_constitution<T,M>& operator[] (size_type i_comp) const { return get_hierarchy() [i_comp]; }
 
     size_type flattened_size() const { return _flattened_size; }
+    size_type comp_dis_idof2dis_idof (size_type i_comp, size_type comp_dis_idof) const;
 
 // utility:
 
@@ -333,9 +334,9 @@ protected:
     mutable distributor              _ownership;
     valued_type                      _valued_tag;
     bool		             _is_hier;
-    scalar_type                      _scalar_constit;
+    scalar_type                      _terminal_constit;
     hierarchy_type                   _hier_constit;
-    mutable std::array<size_type, reference_element::max_variant> _loc_ndof;
+    mutable std::array<size_type, reference_element::max_variant> _loc_ndof; // working array
 };
 // ----------------------------------------------------------------------------
 // inlined
@@ -351,7 +352,7 @@ space_constitution_rep<T,M>::space_constitution_rep()
    _ownership(),
    _valued_tag(space_constant::mixed),
    _is_hier(false),
-   _scalar_constit(),
+   _terminal_constit(),
    _hier_constit(),
    _loc_ndof()
 {
@@ -367,12 +368,35 @@ space_constitution_rep<T,M>::space_constitution_rep (const space_constitution_re
    _ownership(x._ownership),
    _valued_tag(x._valued_tag),
    _is_hier(x._is_hier),
-   _scalar_constit(x._scalar_constit),
+   _terminal_constit(x._terminal_constit),
    _hier_constit(x._hier_constit),
    _loc_ndof()
 {
   _loc_ndof.fill (std::numeric_limits<size_type>::max());
 }
+template <class T, class M>
+inline
+space_constitution_rep<T,M>::space_constitution_rep (
+    const geo_basic<T,M>&    omega,
+    std::string              approx)
+ : _is_initialized(false),
+   _flattened_size(0),
+   _start_by_flattened_component(),
+   _start_by_component(),
+   _ownership(),
+   _valued_tag(space_constant::scalar),
+   _is_hier(false),
+   _terminal_constit(),
+   _hier_constit(),
+   _loc_ndof()
+{
+  _loc_ndof.fill (std::numeric_limits<size_type>::max());
+  _terminal_constit = scalar_type (omega, approx);
+  if (_terminal_constit.get_basis().is_initialized()) {
+    _valued_tag = _terminal_constit.get_basis().valued_tag();
+  }
+  initialize();
+}
 // ----------------------------------------------------------------------------
 // space_constitution
 // ----------------------------------------------------------------------------
@@ -440,8 +464,8 @@ public:
 
 // scalar accessors & modifiers:
 
-    const space_scalar_constitution<T,M>& get_scalar() const { return base::data().get_scalar(); }
-    space_scalar_constitution<T,M>&       get_scalar()       { return base::data().get_scalar(); }
+    const space_constitution_terminal<T,M>& get_terminal() const { return base::data().get_terminal(); }
+    space_constitution_terminal<T,M>&       get_terminal()       { return base::data().get_terminal(); }
 
 // hierarchy accessors & modifiers:
 
@@ -456,6 +480,8 @@ public:
     space_constitution<T,M>&       operator[] (size_type i_comp)       { return base::data().operator[] (i_comp); }
     const space_constitution<T,M>& operator[] (size_type i_comp) const { return base::data().operator[] (i_comp); }
     size_type flattened_size() const { return base::data().flattened_size(); }
+    size_type comp_dis_idof2dis_idof (size_type i_comp, size_type comp_dis_idof) const
+                                   { return base::data().comp_dis_idof2dis_idof (i_comp, comp_dis_idof); }
 
 // utility:
 
