@@ -104,7 +104,7 @@ bool is_dg_restricted_to_interface (
   const geo_basic<T,M>&              omega_K,
   const geo_element&                 K)
 {
-  return constit.get_basis().option().is_restricted_to_sides()
+  return constit.get_basis().option().is_trace_n()
       && constit.get_geo().get_background_geo().map_dimension() == omega_K.map_dimension()
       && omega_K.map_dimension() == K.dimension() + 1;
 }
