@@ -64,7 +64,7 @@ template <class T, class M>
 void
 test_rep<T,M>::initialize (
   const piola_on_pointset<float_type>&             pops,
-  const integrate_option&                          iopt) const
+  const integrate_option&                          iopt)
 {
   _is_on_band = false;
   _is_inside_on_local_sides = iopt._is_inside_on_local_sides;
@@ -75,7 +75,7 @@ void
 test_rep<T,M>::initialize (
   const space_basic<float_type,memory_type>&       Xh,
   const piola_on_pointset<float_type>&             pops,
-  const integrate_option&                          iopt) const
+  const integrate_option&                          iopt)
 {
   _is_on_band = false;
   _fops.initialize (get_vf_space().get_basis(), pops);
@@ -85,7 +85,7 @@ void
 test_rep<T,M>::initialize (
   const band_basic<float_type,M>&                  gh,
   const piola_on_pointset<float_type>&             pops,
-  const integrate_option&                          iopt) const
+  const integrate_option&                          iopt)
 {
   _is_on_band = true;
   _gh = gh;
