@@ -27,7 +27,7 @@
 namespace rheolef { namespace details {
 
 // =========================================================================
-// field_component
+// test_component
 // =========================================================================
 template <class T, class M, class VfTag>
 class test_component_rep {
@@ -61,16 +61,16 @@ public:
 
   void initialize (
     const piola_on_pointset<T>& pops,
-    const integrate_option&     iopt) const
+    const integrate_option&     iopt) 
       { _u_comp.initialize (pops, iopt); }
   void initialize (
     const band_basic<float_type,memory_type>& gh,
     const piola_on_pointset<T>&               pops,
-    const integrate_option&                   iopt) const
+    const integrate_option&                   iopt)
       { _u_comp.initialize (gh, pops, iopt); _is_on_band = true; }
   void initialize (
     const space_basic<float_type,memory_type>& Xh,
-    const integrate_option&                    iopt) const
+    const integrate_option&                    iopt) 
       { _u_comp.initialize (Xh, iopt); }
 
 // evaluators:
@@ -399,7 +399,7 @@ trace_macro("local_dg_merge_on_side: omega_K="<<omega_K.name()<<", S="<<S.name()
 trace_macro("local_dg_merge_on_side: omega_K="<<omega_K.name()<<", S="<<S.name()<<S.dis_ie()<<" done");
 }
 // =========================================================================
-// field_component
+// test_component
 // =========================================================================
 template <class T, class M, class VfTag>
 class test_component: public smart_pointer<test_component_rep<T,M,VfTag> > {
@@ -446,16 +446,16 @@ public:
 
   void initialize (
     const piola_on_pointset<T>& pops,
-    const integrate_option&     iopt) const
+    const integrate_option&     iopt)
       { base::data().initialize (pops, iopt); }
   void initialize (
     const band_basic<float_type,memory_type>& gh,
     const piola_on_pointset<T>&               pops,
-    const integrate_option&                   iopt) const
+    const integrate_option&                   iopt)
       { base::data().initialize (gh, pops, iopt); }
   void initialize (
     const space_basic<float_type,memory_type>& Xh,
-    const integrate_option&                    iopt) const
+    const integrate_option&                    iopt)
       { base::data().initialize (Xh, iopt); }
 
 // evaluators:
