@@ -130,6 +130,7 @@ Implementation
 } // namespace rheolef
 
 #include "scatch.icc"
+#include "rheolef/compiler.h"
 #include "rheolef/index_set_header.icc"
 #include "rheolef/index_set_body.icc"
 #include <iostream>
@@ -367,7 +368,7 @@ void bamg2geo(istream& bamg, istream& dmn, string syscoord) {
     exit (1);
   }
   // 5.3) convert edge_boundary into an index in the edge[] table with orient
-  struct edge_orient_type { size_t index; int orient; };
+  struct edge_orient_type { long index; int orient; };
   vector<list<edge_orient_type> > edge_domain (edge_ndom);
   for (size_t ieb = 0, neb = edge_boundary_bamg_dom_id.size(); ieb < neb; ieb++) {
     size_t bamg_dom_id = edge_boundary_bamg_dom_id [ieb];
