@@ -29,7 +29,7 @@ int main (int argc, char**argv) {
   lambda.boundary(); // guard
 #endif // TO_CLEAN
   space Xh (lambda, "P1");
-  field phi_h = interpolate(Xh, phi);
+  field phi_h = lazy_interpolate(Xh, phi);
   level_set_option opts;
   opts.epsilon = 1e-7;
 warning_macro("main(1)");
