@@ -30,7 +30,7 @@ int main(int argc, char**argv) {
   field one (Xh, 1);
   form dm (Xh, Xh, "lumped_mass");
   field dh = diag(dm);
-  field inv_dh = interpolate (Xh, 1./dh);
+  field inv_dh = lazy_interpolate (Xh, 1./dh);
   form inv_dm = diag(inv_dh);
   field eh = (inv_dm*dm)*one - one;
   Float err = dm (eh, eh);
