@@ -29,7 +29,7 @@ NPROC_MAX=${NPROC_MAX-"3"}
 
 status=0
 
-loop_mpirun "./field_comp_assign_tst $SRCDIR/carre-v2.geo 2>/dev/null >/dev/null"
+loop_mpirun "./field_comp_assign_tst $SRCDIR/carre-dom-v2.geo 2>/dev/null >/dev/null"
 if test $? -ne 0; then status=1; fi
 
 exit $status
