@@ -21,6 +21,8 @@
 # -------------------------------------------------------------------------
 TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
 SRCDIR=${SRCDIR-"$TOP_SRCDIR/main/tst"}
+BINDIR=${BINDIR-"../bin"}
+SBINDIR=${SBINDIR-"../sbin"}
 NPROC_MAX=${NPROC_MAX-"8"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
@@ -28,7 +30,8 @@ NPROC_MAX=${NPROC_MAX-"8"}
 #exit 0
 
 status=0
-run "mkgeo_grid -t 5 2>/dev/null > mesh-2d-t.geo 2>/dev/null"
+
+run "$SBINDIR/mkgeo_grid_2d -v4 -t 5 2>/dev/null | $BINDIR/geo -upgrade - > mesh-2d-t.geo 2>/dev/null"
 if test $? -ne 0; then status=1; fi
 
 loop_mpirun "./field_comp_mpi_tst mesh-2d-t.geo >/dev/null 2>/dev/null"
