@@ -30,7 +30,7 @@ int main(int argc, char**argv) {
   string dom_name = (argc > 3) ? argv[3] : "right";
   Float prec = (argc > 4) ? atof(argv[4]) : 1e-10;
   space Wh (omega[dom_name], argv[2]);
-  field fh = interpolate(Vh, g);
+  field fh = lazy_interpolate(Vh, g);
   field gh (Wh);
   gh = fh[dom_name];
   dout << round (gh, prec);
