@@ -31,7 +31,7 @@ int main(int argc, char**argv) {
   string dom_name = (argc > 3) ? argv[3] : "left";
   Float prec = (argc > 4) ? atof(argv[4]) : 1e-10;
   N = omega.dimension();
-  field fh = interpolate(Vh, f);
+  field fh = lazy_interpolate(Vh, f);
   fh[dom_name] = 0;
   dout << round (fh, prec);
 }
