@@ -33,6 +33,6 @@ int main (int argc, char **argv) {
   space Xh2 (omega2, "P1");
   trial u2(Xh2);
   test  v2(Xh2);
-  field fh2 = interpolate(Xh2,1.*fh1);
+  field fh2 = lazy_interpolate(Xh2,1.*fh1);
   form m2 = integrate(u2*v2);
 }
