@@ -21,22 +21,3 @@
 // demo for the geo class documentation
 #define _RHEOLEF_GEO_DEMO_TST_CC
 #include "rheolef/geo.h"
-
-#ifdef TO_CLEAN
-using namespace rheolef;
-using namespace std;
-int main(int argc, char**argv) {
-  environment rheolef (argc, argv);
-  geo omega (argv[1]);
-  cout << omega.size() << " " << omega.n_node() << endl;
-  for (size_t i = 0, n = omega.size(); i < n; ++i) {
-    const geo_element& K = omega[i];
-    cout << K.name();
-    for (size_t j = 0, m = K.size(); j < m; ++j)
-      cout << " " << K[j];
-    cout << endl;
-  }
-  for (size_t jv = 0, nv = omega.n_node(); jv < nv; ++jv)
-    cout << omega.node(jv) << endl;
-}
-#endif // TO_CLEAN
