@@ -820,10 +820,16 @@ def paraview_branch_2d_scalar_bicolor_discrete (paraview, basename, filelist, op
       title_show = Show()
       title_show.Color      = [0,0,0]
       title_show.FontFamily = 'Times'
-      title_show.FontSize   = 12
+      title_show.FontSize   = 16
       title_show.Justification = 'Center'
-      title_show.WindowLocation = 'AnyLocation'
       title_show.Position   = [0.5, 0.95]
+      try:
+        title_show.WindowLocation = 'Any Location'
+      except:
+        try:
+          title_show.WindowLocation = 'AnyLocation'
+        except:
+          0;
     # --------------------------- 
     # negative part, in backgroud
     # --------------------------- 
@@ -844,6 +850,7 @@ def paraview_branch_2d_scalar_bicolor_discrete (paraview, basename, filelist, op
     if option['color'] != 'color': 
       negative_show.Visibility = 0
     negative_show.SetScalarBarVisibility(render, False)
+    negative_show.Opacity = 0.5
     negative_show.UpdatePipeline()
     # ----------------------------------------
     # positive part, in foregroud, with a mask
@@ -858,6 +865,7 @@ def paraview_branch_2d_scalar_bicolor_discrete (paraview, basename, filelist, op
 
     positive_show = Show()
     positive_show.SelectionPointFieldDataArrayName = 'Result'
+    #positive_show.Opacity = 0.5
     if option['color'] == 'color': 
       positive_show.ColorArrayName = 'Result'
       positive_show.ScalarOpacityFunction = positive_color_opacity
@@ -1145,12 +1153,12 @@ def paraview_field_scalar (paraview, basename, option):
 # ==========================================================================
 # 3.1. vector field visualization: deformation
 # --------------------------------------------------------------------------
-def paraview_field_vector_deformation (paraview, basename, option):
+def paraview_field_vector_deformation (paraview, basename, filelist, option):
     from paraview.simple import LegacyVTKReader, \
 	Show, WarpByVector, Outline, GetRenderView, SetActiveSource, Outline
 
     paraview.simple._DisableFirstRenderCameraReset()
-    data = LegacyVTKReader(FileNames=[basename+".vtk"])
+    data = LegacyVTKReader(FileNames=filelist)
     x_min = option['bbox'][0][0]
     x_max = option['bbox'][1][0]
     y_min = option['bbox'][0][1]
@@ -1161,8 +1169,11 @@ def paraview_field_vector_deformation (paraview, basename, option):
     f_max = option['range'][1]
     xg = [(x_max+x_min)/2., (y_max+y_min)/2., (z_max+z_min)/2.]
     dx = [x_max-x_min, y_max-y_min, z_max-z_min]
+    if option['mark'] == '':
+       option['mark'] = "vector"
     if option['label'] == '':
-      option['label'] = '|deformation|'
+       option['label'] = "|" + option['mark'] + "|"
+    print ("deformation: mark = ", option['mark']);
 
     color_bar = make_color_bar (option)
     color_map = color_bar.GetProperty("LookupTable").GetData()
@@ -1178,7 +1189,7 @@ def paraview_field_vector_deformation (paraview, basename, option):
     
     SetActiveSource(data)
     deformation = WarpByVector()
-    deformation.Vectors = 'vector'
+    deformation.Vectors = option['mark']
     if (f_max-f_min != 0):
       # adjust the deformation scale to 10% of the domain characteristic length	
       # can be adjusted by the "-scale" command line option, or interactively
@@ -1192,8 +1203,8 @@ def paraview_field_vector_deformation (paraview, basename, option):
       deformation_show.Representation = 'Wireframe'
     else:
       deformation_show.Representation = 'Surface'
-    deformation_show.SelectionPointFieldDataArrayName = 'vector_norm'
-    deformation_show.ColorArrayName = 'vector_norm'
+    deformation_show.SelectionPointFieldDataArrayName = option['mark'] + '_norm'
+    deformation_show.ColorArrayName = option['mark'] + '_norm'
     deformation_show.LookupTable           = color_map
     deformation_show.ScalarOpacityFunction = color_opa
     deformation_show.ScalarOpacityUnitDistance = 0.05547965123845249
@@ -1211,12 +1222,12 @@ def paraview_field_vector_deformation (paraview, basename, option):
 # --------------------------------------------------------------------------
 # 3.2. vector field visualization: arrow
 # --------------------------------------------------------------------------
-def paraview_field_vector_arrow    (paraview, basename, option):
+def paraview_field_vector_arrow    (paraview, basename, filelist, option):
     from paraview.simple import LegacyVTKReader, \
         SetActiveSource, Show, Glyph, Outline, GetRenderView, GetDisplayProperties
     
     paraview.simple._DisableFirstRenderCameraReset()
-    data = LegacyVTKReader(FileNames=[basename+".vtk"])
+    data = LegacyVTKReader(FileNames=filelist)
     x_min = option['bbox'][0][0]
     x_max = option['bbox'][1][0]
     y_min = option['bbox'][0][1]
@@ -1225,8 +1236,10 @@ def paraview_field_vector_arrow    (paraview, basename, option):
     z_max = option['bbox'][1][2]
     xg = [(x_max+x_min)/2., (y_max+y_min)/2., (z_max+z_min)/2.]
     dx = [x_max-x_min, y_max-y_min, z_max-z_min]
+    if option['mark'] == '':
+       option['mark'] = "vector"
     if option['label'] == '':
-      name = '|vector|'
+       option['label'] = "|" + option['mark'] + "|"
     
     color_bar = make_color_bar (option)
     color_map = color_bar.GetProperty("LookupTable").GetData()
@@ -1236,8 +1249,8 @@ def paraview_field_vector_arrow    (paraview, basename, option):
       data_show = Show()
       data_show.ScaleFactor = 1;
       data_show.Representation = 'Surface'
-      data_show.SelectionPointFieldDataArrayName = 'vector_norm'
-      data_show.ColorArrayName = 'vector_norm'
+      data_show.SelectionPointFieldDataArrayName = option['mark'] + '_norm'
+      data_show.ColorArrayName = option['mark'] + '_norm'
       data_show.LookupTable           = color_map
       data_show.ScalarOpacityFunction = color_opa
       data_show.ScalarOpacityUnitDistance = 0.05547965123845249
@@ -1250,13 +1263,13 @@ def paraview_field_vector_arrow    (paraview, basename, option):
     arrow = Glyph()
     try:
       # paraview 5.7:
-      arrow.OrientationArray = ['POINTS', 'vector']
-      arrow.ScaleArray       = ['POINTS', 'vector_norm']
+      arrow.OrientationArray = ['POINTS', option['mark']]
+      arrow.ScaleArray       = ['POINTS', option['mark'] + '_norm']
     except:
       # paraview older:
       try:
-        arrow.Scalars = 'vector_norm'
-        arrow.Vectors = 'vector'
+        arrow.Scalars   = option['mark'] + '_norm'
+        arrow.Vectors   = option['mark']
         arrow.ScaleMode = 'vector'
       except: 0;           
     if option['view_2d'] == 1: 
@@ -1273,21 +1286,21 @@ def paraview_field_vector_arrow    (paraview, basename, option):
     except: 0;           
     # new paraview-5.x:
     try:
-      arrow.ScaleFactor    = h_average*option['scale'];
-      arrow.ScaleMode = 'vector'
-      #arrow.ScaleMode = 'vector_components';
+      arrow.ScaleFactor = h_average*option['scale'];
+      arrow.ScaleMode   = 'vector'
+      #arrow.ScaleMode  = 'vector_components';
     except: 0;          
     #arrow.RandomMode = 0
     #arrow.MaskPoints = 0
 
     arrow_show = Show()
-    arrow_show.SelectionPointFieldDataArrayName = 'vector_norm'
+    arrow_show.SelectionPointFieldDataArrayName = option['mark'] + '_norm'
     arrow_show.LookupTable = color_map
     if option['fill'] == 1:
       arrow_show.ColorArrayName = ''
       arrow_show.DiffuseColor         = [0, 0, 0]
     else:
-      arrow_show.ColorArrayName = 'vector_norm'
+      arrow_show.ColorArrayName = option['mark'] + '_norm'
       arrow_show.DiffuseColor         = [0, 0, 0]
     arrow_show.AmbientColor         = [0, 0, 0]
    #arrow_show.CubeAxesColor        = [0, 0, 0]
@@ -1302,18 +1315,22 @@ def paraview_field_vector_arrow    (paraview, basename, option):
 # --------------------------------------------------------------------------
 # 3.3. vector field visualization
 # --------------------------------------------------------------------------
-def paraview_field_vector (paraview, basename, option):
+def paraview_branch_vector (paraview, basename, filelist, option):
     if option['style'] == 'deformation': 
-      paraview_field_vector_deformation (paraview, basename, option)
+      paraview_field_vector_deformation (paraview, basename, filelist, option)
     else:
-      paraview_field_vector_arrow       (paraview, basename, option)
+      paraview_field_vector_arrow       (paraview, basename, filelist, option)
+
+def paraview_field_vector (paraview, basename, option):
+    filelist = [basename+".vtk"]
+    paraview_branch_vector (paraview, basename, filelist, option)
 
 # ==========================================================================
 # 4. tensor field visualization
 # ==========================================================================
 # warning: requieres the "TensorGlyph" plugin that should be compiled separately
 # TODO: distribute it with rheolef, if it can be compiled with paraview-dev ?
-def paraview_field_tensor (paraview, basename, option):
+def paraview_branch_tensor (paraview, basename, filelist, option):
     from paraview.simple import LegacyVTKReader, \
 	Show, GetRenderView, SetActiveSource, Outline, \
 	GetLookupTableForArray, Render
@@ -1325,7 +1342,7 @@ def paraview_field_tensor (paraview, basename, option):
       exit(1)
 
     paraview.simple._DisableFirstRenderCameraReset()
-    data = LegacyVTKReader(FileNames=[basename+".vtk"])
+    data = LegacyVTKReader(FileNames=filelist)
     x_min = option['bbox'][0][0]
     x_max = option['bbox'][1][0]
     y_min = option['bbox'][0][1]
@@ -1336,8 +1353,10 @@ def paraview_field_tensor (paraview, basename, option):
     f_max = option['range'][1]
     xg = [(x_max+x_min)/2., (y_max+y_min)/2., (z_max+z_min)/2.]
     dx = [x_max-x_min, y_max-y_min, z_max-z_min]
+    if option['mark'] == '':
+       option['mark'] =  'tensor'
     if option['label'] == '':
-      option['label'] = '|tensor|'
+       option['label'] = "|" + option['mark'] + "|"
 
     color_bar = make_color_bar (option)
     color_map = color_bar.GetProperty("LookupTable").GetData()
@@ -1352,8 +1371,8 @@ def paraview_field_tensor (paraview, basename, option):
 
     SetActiveSource(data)
     tensor_norm = Show()
-    tensor_norm.SelectionPointFieldDataArrayName = 'tensor_norm'
-    tensor_norm.ColorArrayName                   = 'tensor_norm'
+    tensor_norm.SelectionPointFieldDataArrayName = option['mark'] + "_norm"
+    tensor_norm.ColorArrayName                   = option['mark'] + "_norm"
     tensor_norm.LookupTable = color_map
     tensor_norm.ScalarOpacityFunction = color_opa
     tensor_norm.ScalarOpacityUnitDistance = 0.2418271175121958
@@ -1368,18 +1387,19 @@ def paraview_field_tensor (paraview, basename, option):
     tensor_glyph.GlyphType = "Sphere"
     tensor_glyph.ColorGlyphs = 1
     tensor_glyph.ExtractEigenvalues = 1
-    tensor_glyph.Scalars = 'tensor_norm'
-    tensor_glyph.Tensors = 'tensor'
+    tensor_glyph.Scalars = option['mark'] + "_norm"
+    #tensor_glyph.Tensors = ['POINTS', option['label']]
+    tensor_glyph.Tensors = option['mark']
     h_average = 0.1; # TODO: compute element average length
     tensor_glyph.ScaleFactor = 1.5*h_average*option['scale'];
     tensor_glyph.LimitScalingByEigenvalues = 0
     
     tensor_glyph_show = Show()
-    tensor_glyph_show.SelectionPointFieldDataArrayName = 'tensor_norm'
+    tensor_glyph_show.SelectionPointFieldDataArrayName = option['mark'] + "_norm"
     if option['view_2d'] == 1:
       tensor_glyph_show.ColorArrayName = ''
     else:
-      tensor_glyph_show.ColorArrayName = 'tensor_norm'
+      tensor_glyph_show.ColorArrayName = option['mark'] + "_norm"
     tensor_glyph_show.LookupTable = color_map
     tensor_glyph_show.ScaleFactor = 1
     gray = 11./12.
@@ -1394,6 +1414,10 @@ def paraview_field_tensor (paraview, basename, option):
       render.Representations.append(color_bar)
     do_render(paraview, basename, option)
 
+def paraview_field_tensor (paraview, basename, option):
+    filelist = [basename+".vtk"]
+    paraview_branch_tensor (paraview, basename, filelist, option)
+
 # ==========================================================================
 # 5. geo visualization
 # ==========================================================================
@@ -1462,20 +1486,32 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
       title_show = Show()
       title_show.Color      = [0,0,0]
       title_show.FontFamily = 'Times'
-      title_show.FontSize   = 10
+      title_show.FontSize   = 16
       title_show.Justification = 'Left'
-      title_show.WindowLocation = 'AnyLocation'
       title_show.Position   = [0.025, 0.955]
+      try:
+        title_show.WindowLocation = 'Any Location'
+      except:
+        try:
+          title_show.WindowLocation = 'AnyLocation'
+        except:
+          0;
     if option['showlabel'] == 1 and option['color'] != 'black_and_white' and idx != 0:
       title = Text()
       title.Text = dom_name
       title_show = Show()
       title_show.Color = color
       title_show.FontFamily = 'Times'
-      title_show.FontSize   = 10
+      title_show.FontSize   = 16
       title_show.Justification = 'Left'
-      title_show.WindowLocation = 'AnyLocation'
       title_show.Position   = [0.025, 0.955 - 0.040*idx]
+      try:
+        title_show.WindowLocation = 'Any Location'
+      except:
+        try:
+          title_show.WindowLocation = 'AnyLocation'
+        except:
+          0;
 
     SetActiveSource(data)
     #print("dom_name=",dom_name)
