@@ -11,6 +11,8 @@
  
  This file is part of Freefem++
  
+ Copyright (C) 1998-2018 F. Hecht <Frederic.Hecht@Inria.fr>
+ 
  Freefem++ is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
@@ -850,7 +852,7 @@ void Geometry::AfterRead()
         R2 v10  =  edges[i].v[1]->r -  edges[i].v[0]->r;
         Real8 lv10 = Norme2(v10);
         if(lv10 == 0) {
-          cerr << "The length  of " <<i<< "th Egde is 0 " << endl ;
+          cerr << "The length  of " <<i<< "th Edge is 0 " << endl ;
           MeshError(1);}
         eangle[i] = atan2(v10.y,v10.x)  ; // angle in [ -Pi,Pi ]
 	if(verbosity>9) 
