@@ -11,6 +11,8 @@
  
  This file is part of Freefem++
  
+ Copyright (C) 1998-2018 F. Hecht <Frederic.Hecht@Inria.fr>
+ 
  Freefem++ is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
@@ -74,7 +76,7 @@ void Triangles::Write(const char * filename,const TypeFileMesh typein )
        case mshMesh    :  cout << " msh "      ; break;
 	default: 
 	  cerr << endl 
-	       <<  " Unkown type mesh file " << (int) type << " for Writing " << filename <<endl;
+	       <<  " Unknown type mesh file " << (int) type << " for Writing " << filename <<endl;
 	  MeshError(1);
        }     
      Int4 NbOfTria =  nbt-2*NbOfQuad-NbOutT ;
@@ -114,12 +116,12 @@ void Triangles::Write(const char * filename,const TypeFileMesh typein )
        case ftqMesh    :  Write_ftq(f)   ; break;
        case mshMesh    :  Write_msh(f)   ; break;
 	default: 
-	  cerr << " Unkown type mesh file " << (int) type << " for Writing " << filename <<endl;
+	  cerr << " Unknown type mesh file " << (int) type << " for Writing " << filename <<endl;
 	  MeshError(1);
        }
    else
      {
-       cerr << " Error openning file " << filename << endl;
+       cerr << " Error opening file " << filename << endl;
        MeshError(1);
      }
    if(verbosity>5)
@@ -631,7 +633,7 @@ ostream& operator <<(ostream& f, const   Triangles & Th)
 	 f << "# BEGIN of the include geometry file because geometry is not on the disk"
 	   << Th.Gh << endl;
 	 f << "End" << endl 
-	   << "# END of the include geometrie file because geometry is not on the disk"
+	   << "# END of the include geometry file because geometry is not on the disk"
 	   << endl ;
        }
    }
