@@ -12,6 +12,8 @@
  
  This file is part of Freefem++
  
+ Copyright (C) 1998-2018 F. Hecht <Frederic.Hecht@Inria.fr>
+ 
  Freefem++ is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
@@ -417,7 +419,7 @@ void initgraphique()
   display = XOpenDisplay(NULL);
   if (!display) 
     {
-      cerr << " Erreur openning  display " << endl;
+      cerr << " Erreur opening  display " << endl;
       exit(2);
     }
   colortable=0;
@@ -1112,7 +1114,7 @@ void openPS(const char *filename )
     fprintf(psfile," 1 setlinewidth\n");
   }
   else 
-    cerr << " Err openning postscript file " << fps << endl;
+    cerr << " Err opening postscript file " << fps << endl;
 }
 void closePS(void)
 {
