@@ -12,6 +12,8 @@
 /*
  
  This file is part of Bamg or FreeFEm++
+
+ Copyright (C) 1998-2018 F. Hecht <Frederic.Hecht@Inria.fr>
  
  Freefem++ is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
@@ -80,7 +82,7 @@ inline int access( char *fileName, int mode)
 
 void NewHandler();
 void NewHandler()
-{ cerr << " Not enought memory " << endl;
+{ cerr << " Not enough memory " << endl;
   exit(1);
 }
 void forDebug();
@@ -359,7 +361,7 @@ int main(int argc, char **argv)
 	cout << "" << endl;
 	cout << "     -thetamax (double)   change the angular limit for a corner in degre " << endl;
 	cout << "                       the angle is defined from 2 normals of 2 concecutives edges " << endl;
-	cout << "                       if no geomtry cf reading an  am_fmt, amdba, nopo .. file " << endl;
+	cout << "                       if no geometry cf reading an  am_fmt, amdba, nopo .. file " << endl;
 
 
 	cout << "" << endl;
