@@ -58,11 +58,15 @@ AUTHORS:
 DATE: 15 december 2010
 End:
 */
+} // namespace rheolef
 
-#define _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
-#ifdef  _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#ifndef  _RHEOLEF_USE_HEAP_ALLOCATOR
+namespace rheolef {
 template<class T> using heap_allocator = std::allocator<T>;
-#else // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+} // namespace rheolef
+#else // _RHEOLEF_USE_HEAP_ALLOCATOR
+
+namespace rheolef {
 
 //<verbatim:
 template <typename T>
@@ -224,7 +228,43 @@ heap_allocator<T>::handler_type::~handler_type()
     heap.erase (heap.begin(), heap.end());
 }
 
-#endif // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
-
 }// namespace rheolef
+
+// ==========================================================================
+// std::allocator_traits 
+// ==========================================================================
+namespace std {
+
+template <class T>
+struct allocator_traits<rheolef::heap_allocator<T>> {
+// typedefs
+
+  using allocator_type = rheolef::heap_allocator<T>;
+  using value_type     = T;
+  using pointer        = T*;
+  using const_pointer      = typename std::pointer_traits<pointer>::rebind<const value_type>;
+  using void_pointer       = typename std::pointer_traits<pointer>::rebind<void>;
+  using const_void_pointer = typename std::pointer_traits<pointer>::rebind<const void>;
+  using difference_type    = typename std::pointer_traits<pointer>::difference_type;
+  using size_type          = typename std::make_unsigned<difference_type>::type;
+  using propagate_on_container_copy_assignment = std::false_type;
+  using propagate_on_container_move_assignment = std::false_type;
+  using propagate_on_container_swap            = std::false_type;
+  using is_always_equal    = typename std::is_empty<rheolef::heap_allocator<T>>::type;
+  template <class U>
+  using rebind_alloc = rheolef::heap_allocator<U>;
+
+// members
+
+   static pointer allocate (allocator_type& a, size_type n) { return a.allocate(n); }
+   static void  deallocate (allocator_type& a, pointer p, size_type n) { a.deallocate (p, n); }
+   static void construct   (allocator_type& a, pointer p) { a.construct (p); }
+   static void construct   (allocator_type& a, pointer p, const T& c) { a.construct (p,c); }
+   template <class U>
+   static void destroy     (allocator_type& a, U* p) {}
+   static size_type max_size(const allocator_type& a ) { return std::numeric_limits<size_type>::mqx(); }allocator_type&
+};
+
+} // namespace std
+#endif // _RHEOLEF_USE_HEAP_ALLOCATOR
 #endif // _RHEOLEF_HEAP_ALLOCATOR_H
