@@ -73,11 +73,7 @@ iorheo::flag_type iorheo::globals_;
 //
 // initialization of static data member
 //
-#ifdef  _RHEOLEF_HAVE_GCC_3_0_2
-#define IORHEO_PREFIX iorheo::
-#else
 #define IORHEO_PREFIX
-#endif
 iorheo::force_initialization::force_initialization() {
 
 	IORHEO_PREFIX default_f [verbose] = true;
@@ -121,7 +117,6 @@ iorheo::force_initialization::force_initialization() {
 	IORHEO_PREFIX format_field [gnuplot] = true;
 	IORHEO_PREFIX format_field [plotmtv] = true;
 	IORHEO_PREFIX format_field [vtk] = true;
-	IORHEO_PREFIX format_field [mayavi] = true;
 	IORHEO_PREFIX format_field [paraview] = true;
 	IORHEO_PREFIX format_field [geomview] = true;
 	IORHEO_PREFIX format_field [x3d] = true;
@@ -143,7 +138,8 @@ iorheo::force_initialization::force_initialization() {
 	IORHEO_PREFIX render_field [velocity] = true;
 	IORHEO_PREFIX render_field [deformation] = true;
 	IORHEO_PREFIX render_field [lattice] = true;
-	IORHEO_PREFIX render_field [label] = true;
+	IORHEO_PREFIX render_field [showlabel] = true;
+	IORHEO_PREFIX render_field [skipvtk] = false;
 	IORHEO_PREFIX render_field [reader_on_stdin] = true;
 
         IORHEO_PREFIX globals_ = default_f & static_field;
@@ -166,12 +162,14 @@ iorheo::iorheo()
     basename_(string("")),
     image_format_(string("")),
     mark_(string("")),
-    isovalue_(),
+    label_(string("")),
+    isovalue_(std::numeric_limits<Float>::max()),
     n_isovalue_(15),
     n_isovalue_negative_(0),
     vectorscale_(1),
     anglecorner_(0),
     rounding_precision_(0),
+    branch_counter_(0),
     flags_()
 {
     // initialized may be called before main() starts
