@@ -175,49 +175,5 @@ template <> struct promote<long double, long double > { typedef long double type
   template <> struct promote<float128, float128 > { typedef float128 type; };
 #endif // _RHEOLEF_HAVE_FLOAT128
 
-#ifdef _RHEOLEF_HAVE_QD
-  template <> struct promote<char, dd_real > { typedef dd_real type; };
-  template <> struct promote<unsigned char, dd_real > { typedef dd_real type; };
-  template <> struct promote<short unsigned int, dd_real > { typedef dd_real type; };
-  template <> struct promote<int, dd_real > { typedef dd_real type; };
-  template <> struct promote<unsigned int, dd_real > { typedef dd_real type; };
-  template <> struct promote<long, dd_real > { typedef dd_real type; };
-  template <> struct promote<unsigned long, dd_real > { typedef dd_real type; };
-  template <> struct promote<float, dd_real > { typedef dd_real type; };
-  template <> struct promote<double, dd_real > { typedef dd_real type; };
-  template <> struct promote<dd_real, char > { typedef dd_real type; };
-  template <> struct promote<dd_real, unsigned char > { typedef dd_real type; };
-  template <> struct promote<dd_real, short int > { typedef dd_real type; };
-  template <> struct promote<dd_real, short unsigned int > { typedef dd_real type; };
-  template <> struct promote<dd_real, int > { typedef dd_real type; };
-  template <> struct promote<dd_real, unsigned int > { typedef dd_real type; };
-  template <> struct promote<dd_real, long > { typedef dd_real type; };
-  template <> struct promote<dd_real, unsigned long > { typedef dd_real type; };
-  template <> struct promote<dd_real, float > { typedef dd_real type; };
-  template <> struct promote<dd_real, double > { typedef dd_real type; };
-  template <> struct promote<dd_real, dd_real > { typedef dd_real type; };
-
-  template <> struct promote<char, qd_real > { typedef qd_real type; };
-  template <> struct promote<unsigned char, qd_real > { typedef qd_real type; };
-  template <> struct promote<short unsigned int, qd_real > { typedef qd_real type; };
-  template <> struct promote<int, qd_real > { typedef qd_real type; };
-  template <> struct promote<unsigned int, qd_real > { typedef qd_real type; };
-  template <> struct promote<long, qd_real > { typedef qd_real type; };
-  template <> struct promote<unsigned long, qd_real > { typedef qd_real type; };
-  template <> struct promote<float, qd_real > { typedef qd_real type; };
-  template <> struct promote<double, qd_real > { typedef qd_real type; };
-  template <> struct promote<qd_real, char > { typedef qd_real type; };
-  template <> struct promote<qd_real, unsigned char > { typedef qd_real type; };
-  template <> struct promote<qd_real, short int > { typedef qd_real type; };
-  template <> struct promote<qd_real, short unsigned int > { typedef qd_real type; };
-  template <> struct promote<qd_real, int > { typedef qd_real type; };
-  template <> struct promote<qd_real, unsigned int > { typedef qd_real type; };
-  template <> struct promote<qd_real, long > { typedef qd_real type; };
-  template <> struct promote<qd_real, unsigned long > { typedef qd_real type; };
-  template <> struct promote<qd_real, float > { typedef qd_real type; };
-  template <> struct promote<qd_real, double > { typedef qd_real type; };
-  template <> struct promote<qd_real, qd_real > { typedef qd_real type; };
-#endif // _RHEOLEF_HAVE_QD
-
 } // namespace rheolef
 #endif /* _RHEOLEF_PROMOTE_H */
