@@ -151,7 +151,12 @@ Implementation
 }// namespace rheolef
 
 #include "rheolef/compiler.h"
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wparentheses"
 #include <boost/iostreams/filtering_stream.hpp>
+#pragma GCC diagnostic pop
 
 namespace rheolef {
 
@@ -203,10 +208,6 @@ protected:
 // [verbatim_orheostream_cont]
 
 // [verbatim_functions]
-//! @brief itos: see the @ref rheostream_7 page for the full documentation
-// integer-to-string conversion
-std::string itos (std::string::size_type i);
-
 //! @brief itof: see the @ref rheostream_7 page for the full documentation
 // float-to-string conversion
 std::string ftos (const Float& x);
@@ -268,5 +269,8 @@ Float to_float (const std::string&);
 std::string get_tmpdir();
 // [verbatim_functions]
 
+// integer-to-string conversion (backward compatibility)
+inline std::string itos (std::size_t i) { return std::to_string(i); }
+
 }// namespace rheolef
 #endif // _RHEOLEF_STREAM_H
