@@ -19,6 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-echo "      $RUN ./flags_tst"
-$RUN ./flags_tst >/dev/null 2>/dev/null
+TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+. "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+run "./flags_tst >/dev/null 2>/dev/null"
+status=$?
+exit $status
