@@ -19,5 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-echo "      ${RUN} ./iorheo_tst"
-${RUN} ./iorheo_tst 2>/dev/null
+TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+. "${TOP_SRCDIR}/config/loop_mpirun.sh"
+
+run "./iorheo_tst 2>/dev/null"
+status=$?
+exit $status
